<?php
/*
 * Exit if accessed directly
 */
if (!defined('ABSPATH')) {
    exit;
}

function ualpIpInfo($ip = NULL, $purpose = "location", $deep_detect = TRUE) {
    $output = NULL;
    if (filter_var($ip, FILTER_VALIDATE_IP) === FALSE) {
        $ip = $_SERVER["REMOTE_ADDR"];
        if ($deep_detect) {
            if (filter_var(@$_SERVER['HTTP_X_FORWARDED_FOR'], FILTER_VALIDATE_IP))
                $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
            if (filter_var(@$_SERVER['HTTP_CLIENT_IP'], FILTER_VALIDATE_IP))
                $ip = $_SERVER['HTTP_CLIENT_IP'];
        }
    }
    $purpose    = str_replace(array("name", "\n", "\t", " ", "-", "_"), NULL, strtolower(trim($purpose)));
    $support    = array("country", "countrycode", "state", "region", "city", "location");
    $continents = array(
        "AF" => "Africa",
        "AN" => "Antarctica",
        "AS" => "Asia",
        "EU" => "Europe",
        "OC" => "Australia (Oceania)",
        "NA" => "North America",
        "SA" => "South America"
    );
    if (filter_var($ip, FILTER_VALIDATE_IP) && in_array($purpose, $support)) {
        $ipdat = @json_decode(file_get_contents("http://www.geoplugin.net/json.gp?ip=" . $ip));
        if (@strlen(trim($ipdat->geoplugin_countryCode)) == 2) {
            switch ($purpose) {
                case "location":
                    $output = array(
                        "city"           => @$ipdat->geoplugin_city,
                        "state"          => @$ipdat->geoplugin_regionName,
                        "country"        => @$ipdat->geoplugin_countryName,
                        "country_code"   => @$ipdat->geoplugin_countryCode,
                        "continent"      => @$continents[strtoupper($ipdat->geoplugin_continentCode)],
                        "continent_code" => @$ipdat->geoplugin_continentCode
                    );
                    break;
                case "city":
                    $output = @$ipdat->geoplugin_city;
                    break;
                case "state":
                    $output = @$ipdat->geoplugin_regionName;
                    break;
                case "region":
                    $output = @$ipdat->geoplugin_regionName;
                    break;
                case "country":
                    $output = @$ipdat->geoplugin_countryName;
                    break;
                case "countrycode":
                    $output = @$ipdat->geoplugin_countryCode;
                    break;
            }
        }
    }
    return $output;
}

/*
 * Enqueue admin scripts
 */
if (!function_exists('ualpAdminScripts')) {

    function ualpAdminScripts() { ?>
        <script>
            var ajaxurl = "<?php echo admin_url('admin-ajax.php'); ?>";
        </script>
        <?php
        $screen = get_current_screen();
        $plugin_data = get_plugin_data(WP_PLUGIN_DIR . '/user-activity-log-pro/user_activity_log_pro.php', $markup = true, $translate = true);
        $current_version = $plugin_data['Version'];
        $old_version = get_option('ual_version');
        if ($old_version != $current_version) {
            update_option('ual_version', $current_version);
        }
        if($screen->id == 'dashboard' || (isset($_GET['page']) && ($_GET['page'] == 'ual_pro' || $_GET['page'] == 'ualp_settings' || $_GET['page'] == 'ualp_db_integration' ))){
            wp_enqueue_script('jquery');
            wp_enqueue_script('password-strength-meter', array('jquery'));
            wp_enqueue_script('select2-js',UALP_PLUGIN_URL.'assets/js/select2.js', array('jquery'));
            wp_enqueue_script('jquery-ui-dialog', array('jquery'));
            wp_enqueue_script('jquery-ui-datepicker');
            wp_enqueue_script('ualp-script', UALP_PLUGIN_URL.'assets/js/ualp_script.js',array('select2-js','jquery-ui-datepicker','jquery-ui-dialog','password-strength-meter'));
            wp_localize_script('ualp-script', 'ualpJSObject', array(
                'is_rtl' => is_rtl() ? 'rtl' : 'ltr',
                'reset_confirm' => esc_html__('Are you sure to reset password?', 'user_activity_log_pro'),
                'note_for_uncheck' => esc_html__('If you uncheck this option, it will not keep log for', 'user_activity_log_pro'),
                'select_option_delete_log' => esc_html__('Select any one option to delete log.', 'user_activity_log_pro'),
                'file_save_success' => esc_html__('File Saved successfully in uploads folder and log deleted successfully.', 'user_activity_log_pro'),
                'email_send_error' => esc_html__('Error in sending email.', 'user_activity_log_pro'),
                'file_save_and_error_email' => esc_html__('File Saved successfully in uploads folder, But error in sending email.', 'user_activity_log_pro'),
                'email_send_and_log_delete' => esc_html__('Email sent successfully and log deleted successfully.', 'user_activity_log_pro'),
                'file_save_and_send_email' => esc_html__('File Saved successfully in uploads folder, Email sent successfully and log deleted successfully', 'user_activity_log_pro'),
                'enter_valid_pwd' => esc_html__('Enter valid password.', 'user_activity_log_pro'),
                'select_option_for_delete_log' => esc_html__('Select any one option to delete log', 'user_activity_log_pro'),
                'file_save_and_log_delete_success' => esc_html__('File Saved successfully in uploads folder and log deleted successfully', 'user_activity_log_pro'),
                'email_send_and_delete_success' => esc_html__('Email sent successfully and log deleted successfully', 'user_activity_log_pro'),
                'file_save_email_send_and_success_delete_log' => esc_html__('File Saved successfully in uploads folder, Email sent successfully and log deleted successfully', 'user_activity_log_pro'),
                'please_select_start_date' => esc_html__('Please first select start date.', 'user_activity_log_pro'),
                'submit' => esc_html__('Submit', 'user_activity_log_pro'),
                'cancel' => esc_html__('Cancel', 'user_activity_log_pro'),
                'log_delete' => esc_html__('Select Logs to delete', 'user_activity_log_pro')
            ));
        }
        wp_enqueue_script('thickbox');
        wp_enqueue_style('thickbox');
    }

}

/*
 * Enqueue admin styles
 */
if (!function_exists('ualpAdminStyles')) {

    function ualpAdminStyles() {
        $screen = get_current_screen();
        if($screen->id == 'dashboard' || (isset($_GET['page']) && ($_GET['page'] == 'ual_pro' || $_GET['page'] == 'ualp_settings' || $_GET['page'] == 'ualp_license_key' || $_GET['page'] == 'ualp_db_integration'))){
            wp_enqueue_style('jquery-ui', UALP_PLUGIN_URL.'assets/css/jquery-ui.css');
            wp_enqueue_style('select2-css',UALP_PLUGIN_URL.'assets/css/select2.min.css');
            wp_enqueue_style('ualp-style', UALP_PLUGIN_URL.'assets/css/ualp_style.css');
        }
        if (is_rtl()) {
            wp_enqueue_style('ualp-style-rtl', UALP_PLUGIN_URL.'assets/css/ualp_style_rtl.css');
        }
    }

}

/*
 * start session if not
 */
if (!function_exists('ualpSessionStart')) {

    function ualpSessionStart() {
        if (session_id() == '') {
            session_start();
        }
    }

}

/*
 * Destroy logged in user session
 */
if (!function_exists('ualpSessionExpire')) {

    function ualpSessionExpire() {
        $t_session = (isset($_POST['t_session']) && $_POST['t_session'] != '') ? $_POST['t_session'] : "";
        $id = (isset($_POST['userID']) && $_POST['userID'] != '') ? $_POST['userID'] : "";
        $except = (isset($_POST['except']) && $_POST['except'] != '') ? $_POST['except'] : "";
        if($t_session == '') {
            delete_user_meta($id, 'session_tokens', '');
            global $wpdb;
                $logged_in_users = $wpdb->get_results("Select * from ".UALP_LOGIN_TABLENAME." order by time_login desc");
                foreach($logged_in_users as $logged_in_user) {
                    $time_logout = current_time('mysql');
                    if($user_login_status == 'login' && $login_status =='logout') {
                        $userloginstatus = $wpdb->query("UPDATE ".UALP_LOGIN_TABLENAME." SET time_logout = '".$time_logout."' WHERE user_id = '".$id."'")."<br>";
                    }
            }
        }
        else {            
            $enc_token = ualpGetCurrentToken($t_session);
            $session_tokens = get_user_meta($id, 'session_tokens', true);
            if($session_tokens) {
                if($except == 'yes') {
                    foreach($session_tokens as $session_token_key => $session_token_val) {
                        if($enc_token != $session_token_key) {
                            unset($session_tokens[$session_token_key]);
                        }
                    }
                }
                else {
                    if(isset($session_tokens[$enc_token])) {
                        unset($session_tokens[$enc_token]);                        
                    }
                }
                update_user_meta($id, 'session_tokens', $session_tokens);
            }
        }
        exit;
    }

}

/*
 * Add Admin Dashboard Widget - News from Solwin Infotech
 */
if (!function_exists('latest_news_solwin_feed')) {

    function latest_news_solwin_feed() {
        // Register the new dashboard widget with the 'wp_dashboard_setup' action
        add_action('wp_dashboard_setup', 'solwin_latest_news_with_product_details');
        if (!function_exists('solwin_latest_news_with_product_details')) {

            function solwin_latest_news_with_product_details() {
                add_screen_option('layout_columns', array('max' => 3, 'default' => 2));
                add_meta_box('wp_ualp_dashboard_widget', esc_html__('News From Solwin Infotech', 'user_activity_log_pro'), 'solwin_dashboard_widget_news', 'dashboard', 'normal', 'high');
            }

        }
        if (!function_exists('solwin_dashboard_widget_news')) {

            function solwin_dashboard_widget_news() {
                echo '<div class="rss-widget">'
                . '<div class="solwin-news"><p><strong>' . esc_html__('Solwin Infotech News', 'user_activity_log_pro') . '</strong></p>';
                wp_widget_rss_output(array(
                    'url' => 'https://www.solwininfotech.com/feed/',
                    'title' => esc_html__('News From Solwin Infotech', 'user_activity_log_pro'),
                    'items' => 5,
                    'show_summary' => 0,
                    'show_author' => 0,
                    'show_date' => 1
                ));
                echo '</div>';
                $title = $link = $thumbnail = "";
                //get Latest product detail from xml file

                $file = 'https://www.solwininfotech.com/documents/assets/latest_product.xml';
                if(!defined('LATEST_PRODUCT_FILE'))
                    define('LATEST_PRODUCT_FILE', $file);
                echo '<div class="display-product">'
                . '<div class="product-detail"><p><strong>' . esc_html__('Latest Product', 'user_activity_log_pro') . '</strong></p>';
                $response = wp_remote_post(LATEST_PRODUCT_FILE);
                if (is_wp_error($response)) {
                    $error_message = $response->get_error_message();
                    echo "<p>" . esc_html__('Something went wrong', 'user_activity_log_pro') . " : $error_message" . "</p>";
                } else {
                    $body = wp_remote_retrieve_body($response);
                    $xml = simplexml_load_string($body);
                    $title = $xml->item->name;
                    $thumbnail = $xml->item->img;
                    $link = $xml->item->link;

                    $allProducttext = $xml->item->viewalltext;
                    $allProductlink = $xml->item->viewalllink;
                    $moretext = $xml->item->moretext;
                    $needsupporttext = $xml->item->needsupporttext;
                    $needsupportlink = $xml->item->needsupportlink;
                    $customservicetext = $xml->item->customservicetext;
                    $customservicelink = $xml->item->customservicelink;
                    $joinproductclubtext = $xml->item->joinproductclubtext;
                    $joinproductclublink = $xml->item->joinproductclublink;


                    echo '<div class="product-name"><a href="' . $link . '" target="_blank">'
                    . '<img alt="' . $title . '" src="' . $thumbnail . '"> </a>'
                    . '<a href="' . $link . '" target="_blank">' . $title . '</a>'
                    . '<p><a href="' . $allProductlink . '" target="_blank" class="button button-default">' . $allProducttext . ' &RightArrow;</a></p>'
                    . '<hr>'
                    . '<p><strong>' . $moretext . '</strong></p>'
                    . '<ul>'
                    . '<li><a href="' . $needsupportlink . '" target="_blank">' . $needsupporttext . '</a></li>'
                    . '<li><a href="' . $customservicelink . '" target="_blank">' . $customservicetext . '</a></li>'
                    . '<li><a href="' . $joinproductclublink . '" target="_blank">' . $joinproductclubtext . '</a></li>'
                    . '</ul>'
                    . '</div>';
                }
                echo '</div></div><div class="clear"></div>'
                . '</div>';
            }

        }
    }

}

/*
 * Add Footer link
 */
if (!function_exists('ualpFooterAdv')) {

    function ualpFooterAdv() {

        if((isset($_GET['page']) && ($_GET['page'] == 'ual_pro' || $_GET['page'] == 'ualp_settings'))){
            add_filter('admin_footer_text', 'ualpFooterAdminAdv'); //change admin footer text
        }
    }

}

/*
 * Add rating html at footer of admin
 * @return html rating
 */
if (!function_exists('ualpFooterAdminAdv')) {

    function ualpFooterAdminAdv() {
        ob_start();
        ?>
        <p id="footer-left" class="alignleft">
            <?php esc_html_e('If you like', 'user_activity_log_pro'); ?>&nbsp;
            <a href="<?php echo esc_url('http://www.solwininfotech.com/product/wordpress-plugins/user-activity-log-pro'); ?>" target="_blank">
                <strong><?php esc_html_e('User Activity Log PRO', 'user_activity_log_pro'); ?></strong>
            </a>
            <?php esc_html_e('please leave us a', 'user_activity_log_pro'); ?>
            <a class="bdp-rating-link" data-rated="Thanks :)" target="_blank" href="<?php echo esc_url('https://codecanyon.net/item/user-activity-log-pro-for-wordpress/reviews/18201203'); ?>">&#x2605;&#x2605;&#x2605;&#x2605;&#x2605;</a>
            <?php esc_html_e('rating. A heartly thank you from Solwin Infotech in advance!', 'user_activity_log_pro'); ?>
        </p>
        <?php
        return ob_get_clean();
    }

}

/**
 * Display success or error message
 *
 * @param string $class
 * @param string $message
 */
if (!function_exists('ualpAdminNoticeMessage')) {

    function ualpAdminNoticeMessage($class, $message) {
        ?>
        <div class="<?php echo $class; ?> is-dismissible ualpAdminNotice notice settings-error below-h1">
            <p><?php echo $message; ?></p>
        </div>
        <?php
    }

}

/*
 * Create log table when activate plugin
 */
if (!function_exists('ualpCreateTable')) {

    function ualpCreateTable() {
        global $wpdb, $externaldb;
        $plugin_data = get_plugin_data(WP_PLUGIN_DIR . '/user-activity-log-pro/user_activity_log_pro.php', $markup = true, $translate = true);
        $current_version = $plugin_data['Version'];
        $table_not_updated = ualpCheckifTableUpdated();
        //table is not created. you may create the table here.
        if ($wpdb->get_var("SHOW TABLES LIKE '".UALP_TABLENAME."'") != UALP_TABLENAME) {
            if(!$table_not_updated) {
                $create_table_query = "CREATE TABLE ".UALP_TABLENAME." ("
                    . "uactid bigint(20) unsigned NOT NULL auto_increment,"
                    . "post_id int(20) unsigned,"
                    . "favorite int(1) default '0',"
                    . "post_title varchar(250),"
                    . "user_id bigint(20) unsigned default '0',"
                    . "user_name varchar(250),"
                    . "user_role varchar(250),"
                    . "user_email varchar(250),"
                    . "ip_address varchar(50),"
                    . "country varchar(150),"
                    . "user_agent text,"
                    . "modified_date datetime default '0000-00-00 00:00:00',"
                    . "object_type varchar(50) default 'post',"
                    . "action varchar(50),"
                    . "hook varchar(100),"
                    . "description varchar(255),"
                    . "t_session varchar(255),"
                    . "PRIMARY KEY (uactid))
                        CHARACTER SET utf8 COLLATE utf8_unicode_ci";
                require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
                dbDelta($create_table_query);
            }
       }
        else if($table_not_updated == 'country') {
            $wpdb->query( "ALTER TABLE ".UALP_TABLENAME." ADD `country` TEXT NULL AFTER `ip_address`" );
        }
        else if($table_not_updated == 'user_agent') {
            $wpdb->query( "ALTER TABLE ".UALP_TABLENAME." ADD `user_agent` TEXT NULL AFTER `country`" );
            $wpdb->query( "ALTER TABLE ".UALP_TABLENAME." ADD `t_session` varchar(200) NULL AFTER `description`" );
        }
        
        $login_table_not_updated = ualpCheckifLoginTableUpdated();
        if(!$login_table_not_updated) {
            $create_login_table_query = "CREATE TABLE ".UALP_LOGIN_TABLENAME." ("
                    . "uacltid bigint(20) unsigned NOT NULL auto_increment,"
                    . "user_id bigint(20) unsigned default '0',"
                    . "user_name varchar(250),"
                    . "user_role varchar(250),"
                    . "user_email varchar(250),"                    
                    . "expiration varchar(250),"
                    . "session_token varchar(250),"
                    . "time_login datetime,"
                    . "time_logout datetime,"
                    . "time_last_seen datetime,"
                    . "ip_address varchar(50),"
                    . "country varchar(150),"
                    . "user_agent text,"
                    . "login_status varchar(50),"
                    . "PRIMARY KEY (uacltid))
                        CHARACTER SET utf8 COLLATE utf8_unicode_ci";
                require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
                dbDelta($create_login_table_query);
        }
        
        update_option('ualp_version',$current_version);
    }

}

/*
 * Create log table in external database
 */
if (!function_exists('ualpCreateExternalTable')) {

    function ualpCreateExternalTable() {
        global $wpdb, $externaldb;
        $tableprefix    = '';
        $tableprefix    = get_option('table_prefix');
        //table is not created. you may create the table here.
        if ($externaldb->get_var("SHOW TABLES LIKE '". $tableprefix ."ualp_user_activity'") != $tableprefix.'ualp_user_activity') {
            $create_table_query = "CREATE TABLE ".$tableprefix."ualp_user_activity ("
                . "uactid bigint(20) unsigned NOT NULL auto_increment,"
                . "post_id int(20) unsigned,"
                . "favorite int(1) default '0',"
                . "post_title varchar(250),"
                . "user_id bigint(20) unsigned default '0',"
                . "user_name varchar(250),"
                . "user_role varchar(250),"
                . "user_email varchar(250),"
                . "ip_address varchar(50),"
                . "country varchar(150),"
                . "modified_date datetime default '0000-00-00 00:00:00',"
                . "object_type varchar(50) default 'post',"
                . "action varchar(50),"
                . "hook varchar(100),"
                . "description varchar(255),"
                . "t_session varchar(255),"
                . "PRIMARY KEY (uactid))
                    CHARACTER SET utf8 COLLATE utf8_unicode_ci";
            require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
            $externaldb->query($create_table_query);
        }
    }

}

/*
 * Add country column in table.
 */
if(!function_exists('ualpCheckifTableUpdated')) {
    function ualpCheckifTableUpdated() {
        global $externaldb;
        if ($externaldb->get_var("SHOW TABLES LIKE '".UALP_TABLENAME."'") == UALP_TABLENAME) {
            if ($externaldb->get_var("SHOW COLUMNS FROM ".UALP_TABLENAME." LIKE 'country'") != 'country') {
                return 'country';
            }
            else if ($externaldb->get_var("SHOW COLUMNS FROM ".UALP_TABLENAME." LIKE 'user_agent'") != 'user_agent') {
                return 'user_agent';
            }
        }
        else{
            return false;
        }
        return false;
    }
}


/*
 * Check if login table exists
 */
if(!function_exists('ualpCheckifLoginTableUpdated')) {
    function ualpCheckifLoginTableUpdated() {
        global $externaldb;
        if ($externaldb->get_var("SHOW TABLES LIKE '".UALP_LOGIN_TABLENAME."'") == UALP_LOGIN_TABLENAME) {
            return true;
        }
        else {
            return false;
        }
        return false;
    }
}

/*
 * Run the database updater
 */
if(!function_exists('ualpDatabaseUpgrade')) {
    function ualpDatabaseUpgrade() {
        global $wpdb, $externaldb;
        $table_not_updated = ualpCheckifTableUpdated();
        if($table_not_updated) {
            ?>
            <div class="updated">
                <p>
                    <strong>
                        <?php esc_html_e( 'User Activity Log Data Update', 'user_activity_log_pro' ); ?>
                    </strong> &#8211; <?php esc_html_e( 'We need to update your database to the latest version.', 'user_activity_log_pro' ); ?>
                </p>
                <p class="submit">
                    <a href="<?php echo esc_url( add_query_arg( 'do_update_ualp', 'do', admin_url( 'admin.php?page=ualp_settings' ) ) ); ?>" class="ualp-update-now button-primary">
                        <?php esc_html_e( 'Run the updater', 'user_activity_log_pro' ); ?>
                    </a>
                </p>
            </div>
            <script type="text/javascript">
                jQuery( '.ualp-update-now' ).click( 'click', function() {
                    return window.confirm( '<?php echo esc_js( esc_html__( 'It is strongly recommended that you backup your database before proceeding. Are you sure you wish to run the updater now?', 'user_activity_log_pro' ) ); ?>' );
                });
            </script>
            <?php
        }
    }
}

/*
 * Create log detail table when activate plugin
 */
if (!function_exists('ualpCreateDetailTable')) {

    function ualpCreateDetailTable() {
        global $wpdb;
        //table is not created. you may create the table here.
        if ($wpdb->get_var("SHOW TABLES LIKE '".UALP_DETAIL_TABLENAME."'") != UALP_DETAIL_TABLENAME) {
            $create_table_query = "CREATE TABLE ".UALP_DETAIL_TABLENAME." ("
                . "uactd_id int(20) NOT NULL auto_increment,"
                . "uactid int(20),"
                . "uactd_key varchar(200),"
                . "uactd_value text,"
                . "PRIMARY KEY (uactd_id)) CHARACTER SET utf8 COLLATE utf8_unicode_ci";
            require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
            dbDelta($create_table_query);
        }
    }

}

/*
 * Create log detail table in external database
 */
if (!function_exists('ualpCreateDetailExternalTable')) {

    function ualpCreateDetailExternalTable() {
        global $externaldb;
        //table is not created. you may create the table here.
        $tableprefix    = '';
        $tableprefix    = get_option('table_prefix');
        if ($externaldb->get_var("SHOW TABLES LIKE '".$tableprefix."ualp_user_activity_detail'") != $tableprefix.'ualp_user_activity_detail') {
            $create_table_query = "CREATE TABLE ".$tableprefix."ualp_user_activity_detail ("
                . "uactd_id int(20) NOT NULL auto_increment,"
                . "uactid int(20),"
                . "uactd_key varchar(200),"
                . "uactd_value text,"
                . "PRIMARY KEY (uactd_id)) CHARACTER SET utf8 COLLATE utf8_unicode_ci";
            require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
            $externaldb->query($create_table_query);
        }

    }

}

/**
 *
 * @param $links for take a action for redirection setting
 * @return action for setting link
 */
if (!function_exists('ualpAddSettingsLink')) {

    function ualpAddSettingsLink($links) {
        $settings_link = '<a href="' . admin_url('admin.php?page=ualp_settings') . '">' . esc_html__( 'Settings' , 'user_activity_log_pro') . '</a>';
        array_push( $links, $settings_link );
        return $links;
    }

}


/*
 * Filter user Roles
 */
if (!function_exists('ualpFilterUserRole')) {

    function ualpFilterUserRole() {
        $paged = 1;
        $admin_url = get_admin_url();
        $display = $search = '';
        if (isset($_POST['user_role'])) {
            $display = $_POST['user_role'];
        }
        if (isset($_POST['btn_filter_user_role'])) {
            $display = $_POST['user_role'];
            wp_redirect(admin_url('admin.php?page=ualp_settings')."&paged=$paged&display=$display&txtsearch=$search");
            exit();
        }
        if (isset($_POST['btnSearch_user_role'])) {
            $search = $_POST['txtSearchinput'];
            wp_redirect(admin_url('admin.php?page=ualp_settings')."&paged=$paged&display=$display&txtsearch=$search");
            exit();
        }
    }

}

/*
 * Compare password to delete logs
 */
if (!function_exists('ualpCompareLogPassword')) {

    function ualpCompareLogPassword() {
        $ualpDeleteLogPwd = get_option('ualp_delete_log_pwd');
        if (isset($_POST['logPwd'])) {
            $ualpGetDeleteLogPwd = $_POST['logPwd'];
            $ualpGetDeleteLogPwd = md5($ualpGetDeleteLogPwd);
            if ($ualpDeleteLogPwd == $ualpGetDeleteLogPwd) {
                echo 'valid';
            } else {
                echo 'in_valid';
            }
        }
        exit();
    }

}

/*
 * Reset user activity database
 */
if(!function_exists('ualpDeleteUalpTable')){
    function ualpDeleteUalpTable() {
        global $wpdb, $externaldb;
        if(isset($_POST['downloadLogs']) && $_POST['downloadLogs'] == 'true') {
            ualpGenerateCsvAttachment();
            echo "downloadLogs";
            $externaldb->query('TRUNCATE ' . UALP_TABLENAME);
            $externaldb->query('TRUNCATE ' . UALP_DETAIL_TABLENAME);
        }
        if(isset($_POST['sendLog']) && $_POST['sendLog'] == 'true') {
            $sent = ualpSendCsvInEmail();
            if($sent) {
                echo "sendLog";
                $externaldb->query('TRUNCATE ' . UALP_TABLENAME);
                $externaldb->query('TRUNCATE ' . UALP_DETAIL_TABLENAME);
            }
            else {
                echo "mailnotsent";
            }
        }
        exit();
    }
}

/*
 * Delete single logs
 */
if(!function_exists('ualpDeleteSingleLog')){
    function ualpDeleteSingleLog() {
        global $wpdb, $externaldb;
        $delete_id = $_POST['logid'];
        if(isset($_POST['downloadLogs']) && $_POST['downloadLogs'] == 'true') {
            ualpGenerateCsvAttachment();
            $uactdIdList = $externaldb->get_results("SELECT uactd_id FROM ".UALP_TABLENAME." left join ".UALP_DETAIL_TABLENAME." on ".UALP_DETAIL_TABLENAME.".uactid = ".UALP_TABLENAME.".uactid WHERE ".UALP_TABLENAME.".favorite = 0 AND ".UALP_DETAIL_TABLENAME.".uactid = $delete_id",ARRAY_A);
            foreach($uactdIdList as $uactdId){
                $externaldb->query($externaldb->prepare("DELETE FROM ".UALP_DETAIL_TABLENAME." WHERE uactid = %d AND uactd_id = %d",$delete_id,$uactdId['uactd_id']));
            }
            $externaldb->query( $externaldb->prepare( "DELETE FROM ".UALP_TABLENAME." WHERE uactid = %d AND favorite = %d",$delete_id, '0' ));
            echo "downloadLogs";
        }
        if(isset($_POST['sendLog']) && $_POST['sendLog'] == 'true') {
            $sent = ualpSendCsvInEmail();
            if($sent) {
                $externaldb->query( $externaldb->prepare( "DELETE FROM ".UALP_TABLENAME." WHERE uactid = %d AND favorite = %d",$delete_id, '0' ));
                echo "sendLog";
            }
            else {
                echo "mailnotsent";
            }
        }
        exit();
    }
}

/*
 * Delete bulk logs
 */
if(!function_exists('ualpDeleteBulkLog')){
    function ualpDeleteBulkLog() {
        global $wpdb, $externaldb;
        $delete_ids = $_POST['logid'];
        if(isset($_POST['downloadLogs']) && $_POST['downloadLogs'] == 'true') {
            ualpGenerateCsvAttachment();
            foreach($delete_ids as $delete_id){
                $uactdIdList = $externaldb->get_results("SELECT uactd_id FROM ".UALP_TABLENAME." left join ".UALP_DETAIL_TABLENAME." on ".UALP_DETAIL_TABLENAME.".uactid = ".UALP_TABLENAME.".uactid WHERE ".UALP_TABLENAME.".favorite = 0 AND ".UALP_DETAIL_TABLENAME.".uactid = $delete_id",ARRAY_A);
                foreach($uactdIdList as $uactdId){
                    $externaldb->query($externaldb->prepare("DELETE FROM ".UALP_DETAIL_TABLENAME." WHERE uactid = %d AND uactd_id = %d",$delete_id,$uactdId['uactd_id']));
                }
                $externaldb->query( $externaldb->prepare( "DELETE FROM ".UALP_TABLENAME." WHERE uactid = %d AND favorite = %d",$delete_id, '0' ));
            }
            echo "downloadLogs";
        }
        if(isset($_POST['sendLog']) && $_POST['sendLog'] == 'true') {
            $sent = ualpSendCsvInEmail();
            if($sent) {
                foreach($delete_ids as $delete_id){
                    $externaldb->query( $externaldb->prepare( "DELETE FROM ".UALP_TABLENAME." WHERE uactid = %d AND favorite = %d",$delete_id, '0' ));
                }
                echo "sendLog";
            }
            else {
                echo "mailnotsent";
            }
        }
        exit();
    }
}

/*
 * Display dialog box
 */
if(!function_exists('ualpDialogboxContent')){
    function ualpDialogboxContent() {
        if((isset($_GET['page']) && ($_GET['page'] == 'ual_pro' || $_GET['page'] == 'ualp_settings'))){ ?>
            <div class="ualp_view_details_ajax" title="<?php esc_attr_e('Log Details', 'user_activity_log_pro'); ?>"></div>
            <div id="dialogPassword" title="<?php esc_attr_e('Are you sure to delete activity logs?','user_activity_log_pro'); ?>" style="display:none">
                <div id="dialog-form" title="<?php esc_attr_e('Delete activity logs','user_activity_log_pro'); ?>">
                    <form method="POST" action="<?php echo admin_url('admin.php').$_SERVER['QUERY_STRING']; ?>">
                        <fieldset>
                            <br/>
                            <label for="deleteLogPassword"><?php esc_html_e('Enter Password','user_activity_log_pro'); ?></label>
                            <input type="password" name="deleteLogPassword" id="deleteLogPassword" value="" class="text ui-widget-content ui-corner-all">
                            <p class="pwdErrorMsg red"></p>
                        </fieldset>
                    </form>
                </div>
            </div>
            <div id="dialogSinglePassword" title="<?php esc_attr_e('Are you sure to delete activity log?','user_activity_log_pro'); ?>" style="display:none">
                <form method="POST" action="<?php echo admin_url('admin.php').$_SERVER['QUERY_STRING']; ?>">
                    <fieldset>
                        <br/>
                        <label for="deleteSingleLogPassword"><?php esc_html_e('Enter Password','user_activity_log_pro'); ?></label>
                        <input type="password" name="deleteLogPassword" id="deleteSingleLogPassword" value="" class="text ui-widget-content ui-corner-all">
                        <p class="pwdErrorMsg red"></p>
                    </fieldset>
                </form>
            </div>
            <div id="dialogDownload" title="<?php esc_attr_e('Download Activity Logs','user_activity_log_pro'); ?>" style="display:none">
                <form method="POST" action="<?php echo admin_url('admin.php').$_SERVER['QUERY_STRING']; ?>">
                    <fieldset>
                        <label for="downloadLog">
                            <input checked="" type="checkbox" name="downloadLogs" value="downloadLog" id="downloadLog">
                            <?php esc_html_e('Download Log file','user_activity_log_pro'); ?>
                        </label>
                    </fieldset>
                    <fieldset>
                        <label for="sendLog">
                            <input type="checkbox" name="sendLog" value="sendLog" id="sendLog">
                            <?php esc_html_e('Send me log file in email','user_activity_log_pro'); ?>
                        </label>
                    </fieldset>
                    <p class="pwdErrorMsg red"></p>
                </form>
            </div>
            <div id="setDeletePassword" title="<?php esc_attr_e('Set Password for delete log','user_activity_log_pro'); ?>" style="display:none">
                <p>
                    <?php
                    esc_html_e("To delete the user activity log, you need to set the password. You can set the password using",'user_activity_log_pro');
                    ?>&nbsp;
                    <a href='<?php echo admin_url("admin.php?page=ualp_settings"); ?>'>
                        <b><?php esc_html_e('password settings','user_activity_log_pro'); ?></b>
                    </a>
                </p>
            </div><?php
        }
    }
}

/**
 * Get term without knowing it's taxonomy.
 *
 * @uses type $wpdb
 * @uses get_term()
 * @param int|object $term
 * @param string $output
 * @param string $filter
 */
if(!function_exists('ualpGetTermById')){
    function ualpGetTermById($term, $output = ARRAY_A, $filter = 'raw') {
        global $wpdb;
        $null = null;
        if ( empty($term) ) {
            $error = new WP_Error('invalid_term', esc_html__('Empty Term'));
            return $error;
        }
        $_tax = $wpdb->get_row( $wpdb->prepare( "SELECT t.* FROM $wpdb->term_taxonomy AS t WHERE t.term_id = $term LIMIT 1"));
        $taxonomy = $_tax->taxonomy;
        return get_term($term, $taxonomy, $output, $filter);
    }
}

/*
 * Update database and deactivate user activity plugin
 */
if(!function_exists('ualpDeactivateUal')){
    function ualpDeactivateUal(){
        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        global $wpdb, $externaldb;
        if ($externaldb->get_var("SHOW TABLES LIKE '".UALP_DETAIL_TABLENAME."'") == UALP_DETAIL_TABLENAME) {
            $hookResult = $externaldb->query("SHOW COLUMNS FROM ". UALP_TABLENAME ." LIKE 'hook'");
            if($hookResult == 0){
                $alter_table_query = $externaldb->query("ALTER TABLE " . UALP_TABLENAME
                    . " ADD COLUMN hook varchar(100)"
                    . " AFTER action");
            }
            $favoriteResult = $externaldb->query("SHOW COLUMNS FROM ". UALP_TABLENAME ." LIKE 'favorite'");
            if($favoriteResult == 0){
                $alter_table_query = $externaldb->query("ALTER TABLE " . UALP_TABLENAME
                    . " ADD COLUMN favorite int(1) DEFAULT '0'"
                    . " AFTER post_id");
            }
            $descriptionResult = $externaldb->query("SHOW COLUMNS FROM ". UALP_TABLENAME ." LIKE 'description'");
            if($descriptionResult == 0){
                $alter_table_query = $externaldb->query("ALTER TABLE " . UALP_TABLENAME
                    . " ADD COLUMN description varchar(255)"
                    . " AFTER hook");
            }
            $countryResult = $externaldb->query("SHOW COLUMNS FROM ". UALP_TABLENAME ." LIKE 'country'");
            if($countryResult == 0){
                $alter_table_query = $externaldb->query("ALTER TABLE " . UALP_TABLENAME
                    . " ADD COLUMN country TEXT"
                    . " AFTER ip_address");
            }
        }
        if (is_plugin_active('user-activity-log/user_activity_log.php')) {
            deactivate_plugins('user-activity-log/user_activity_log.php');
        }

    }
}

/*
 * Redirect to settings page on plugin activation
 */
if(!function_exists('ualpRedirect')) {
    function ualpRedirect($plugin, $network_activation) {
        if($plugin == 'user-activity-log-pro/user_activity_log_pro.php'){
            wp_redirect( admin_url( 'admin.php?page=ualp_settings' ) );
            exit();
        }
    }
}

/*
 * Reset database integration settings
 */
if(!function_exists('ualpResetDatabaseSettings')){
    function ualpResetDatabaseSettings(){
        if(isset($_GET['do_update_ualp']) && $_GET['do_update_ualp'] == 'do') {
            global $wpdb, $externaldb;
            $plugin_data = get_plugin_data(WP_PLUGIN_DIR . '/user-activity-log-pro/user_activity_log_pro.php', $markup = true, $translate = true);
            $current_version = $plugin_data['Version'];
            $externaldb->query( "ALTER TABLE ".UALP_TABLENAME." ADD `country` TEXT NULL AFTER `ip_address`" );
            $externaldb->query( "ALTER TABLE ".UALP_TABLENAME." ADD `user_agent` TEXT NULL AFTER `country`" );
            $externaldb->query( "ALTER TABLE ".UALP_TABLENAME." ADD `t_session` varchar(200) NULL AFTER `description`" );
            update_option('ualp_version',$current_version);
            $mail_msg = get_option('ualpEmailMessage',true);
            $mail_msg = str_replace('Following user is logged in your site','Following user has done some activity in your site',$mail_msg);
            update_option('ualpEmailMessage',$mail_msg);
            wp_redirect(admin_url('admin.php?page=ual_pro'));
            exit();
        }
        if(isset($_POST['btnResetDbData'])){
            update_option('table_prefix'        , '');
            update_option('database_name'       , '');
            update_option('database_hostname'   , '');
            update_option('database_username'   , '');
            update_option('database_password'   , '');
            wp_redirect(admin_url('admin.php?page=ualp_db_integration'));
            exit();
        }
    }
}

/*
 * Get current admin password
 */
if(!function_exists('ulapGetAdminPwd')) {
    function ulapGetAdminPwd() {
        $current_user = wp_get_current_user();
        $admin_pass = $current_user->user_pass;
        ?>
        <script type="text/javascript">
            var adminPwd = '<?php echo $admin_pass; ?>';
            var currentpwd = '<?php echo get_option('ualp_delete_log_pwd'); ?>';
        </script>
        <?php
    }
}

/**
 * Send email when selected user login
 *
 * @param string $login current username when login
 */
if (!function_exists('ualpSendEmailNotification')) {

    function ualpSendEmailNotification($login,$activity) {
        if(get_option('ualpEnableEmailNotify') == 1){
            $enable_unm = get_option('enable_user_list',true);
            if($login){
                $current_user1 = get_user_by('login', $login);
                $current_user = !empty($current_user1->user_login) ? $current_user1->user_login : "";
                for ($i = 0; $i < count($enable_unm); $i++) {
                    if ($enable_unm[$i] == $current_user) {
                        $firstname = ucfirst($current_user1->user_firstname);
                        $lastname = ucfirst($current_user1->user_lastname);
                        $user_firstnm = !empty($firstname) ? ucfirst($firstname) : "-";
                        $user_lastnm = !empty($lastname) ? $lastname : "-";
                        $user_email = !empty($current_user1->user_email) ? $current_user1->user_email : "-";
                        $current_user = ucfirst($current_user);

                        ualpEmailBody($current_user,$user_firstnm,$user_lastnm,$user_email,$activity);
                    }
                }
            } else {
                ualpEmailBody('Guest','','','',$activity);
            }
        }
    }

}

if(!function_exists('ualpEmailBody')){
    function ualpEmailBody($current_user,$user_firstnm,$user_lastnm,$user_email,$activity){
        if(ualpAllowIp()) {
            $ip = $_SERVER['REMOTE_ADDR'];
        }
        else {
            $ip = '';
        }
        $modified_date = current_time('mysql');
        $modified_date = strtotime($modified_date);

        $date_format = get_option('date_format');
        $time_format = get_option('time_format');

        $date = date($date_format, $modified_date);
        $time = date($time_format, $modified_date);

        $user_reg = $date. " " .$time;
        ob_start();
        ?>
        <table cellspacing='0' style='margin-top:30px;border: 1px solid #cccccc;border-collapse: collapse;'>
            <tr>
                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'><?php echo esc_html__('Username', 'user_activity_log_pro'); ?></th>
                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'><?php echo esc_html__('Firstname', 'user_activity_log_pro'); ?></th>
                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'><?php echo esc_html__('Lastname', 'user_activity_log_pro'); ?></th>
                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'><?php echo esc_html__('E-mail', 'user_activity_log_pro'); ?></th>
                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'><?php echo esc_html__('Date Time', 'user_activity_log_pro'); ?></th>
                <?php if(ualpAllowIp()) { ?>
                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'><?php echo esc_html__('IP Address', 'user_activity_log_pro'); ?></th>
                <?php } ?>
                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;'><?php echo esc_html__('Activity', 'user_activity_log_pro'); ?></th>
            </tr>
            <tr>
                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'><?php echo $current_user; ?></td>
                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'><?php echo $user_firstnm; ?></td>
                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'><?php echo $user_lastnm; ?></td>
                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'><?php echo $user_email; ?></td>
                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'><?php echo $user_reg; ?></td>
                <?php if(ualpAllowIp()) { ?>
                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'><?php echo $ip; ?></td>
                <?php } ?>
                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'><?php echo $activity; ?></td>
            </tr>
        </table>
        <br/>
        <br/>
        <?php
//        $user_details = "<table cellspacing='0' style='margin-top:30px;border: 1px solid #cccccc;border-collapse: collapse;'>
//            <tr>
//                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'>" . esc_html__('Username', 'user_activity_log_pro') . "</th>
//                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'>" . esc_html__('Firstname', 'user_activity_log_pro') . "</th>
//                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'>" . esc_html__('Lastname', 'user_activity_log_pro') . "</th>
//                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'>" . esc_html__('E-mail', 'user_activity_log_pro') . "</th>
//                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'>" . esc_html__('Date Time', 'user_activity_log_pro') . "</th>
//                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;border-right: 1px solid #cccccc;'>" . esc_html__('IP Address', 'user_activity_log_pro') . "</th>
//                <th style='padding:5px 10px;border-bottom: 1px solid #cccccc;'>" . esc_html__('Activity', 'user_activity_log_pro') . "</th>
//            </tr>
//            <tr>
//                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'>$current_user</td>
//                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'>$user_firstnm</td>
//                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'>$user_lastnm</td>
//                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'>$user_email</td>
//                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'>$user_reg</td>
//                <td style='padding:5px 10px;border-right: 1px solid #cccccc;'>$ip</td>
//                <td style='padding:5px 10px;'>$activity</td>
//            </tr>
//        </table>
//        <br/><br/>";
        $user_details = ob_get_clean();
        $to_email = get_option('ualpToEmail');
        $from_email = get_option('ualpFromEmail');
        $mail_msg = get_option('ualpEmailMessage');
        $mail_msg = str_replace('[user_details]', $user_details, $mail_msg);

        if (isset($to_email) && $to_email != '' && $from_email != '' && $mail_msg != '') {
            $headers = "From: " . strip_tags($from_email) . "\r\n";
            $headers .= "Reply-To: " . strip_tags($from_email) . "\r\n";
            $headers .= "MIME-Version: 1.0\r\n";
            $headers .= "Content-Type: text/html; charset=ISO-8859-1\r\n";
            $to_email_array = explode(',', $to_email);
            for($i = 0; $i < sizeof($to_email_array);$i++){
                $to_mail = trim($to_email_array[$i],' ');
                wp_mail($to_mail, esc_html__('User activity Notification', 'user_activity_log_pro'), $mail_msg, $headers);
            }
        }
    }
}


/**
 * Enable user notification of email at login
 *
 * @param int $user_id user ID
 */
if (!function_exists('ualpEnableUserForNotification')) {

    function ualpEnableUserForNotification($user_id) {
        $user_info = get_userdata($user_id);
        $user_role = $user_info->roles[0];
        $user_role_enable = get_option('enable_role_list');
        if($user_role_enable == '') {
            $user_role_enable = array();
        }
        $user_enabled = get_option('enable_user_list');
        if($user_enabled == '') {
            $user_enabled = array();
        }
        for ($i = 0; $i < count($user_role_enable); $i++) {
            if ($user_role_enable[$i] == $user_role) {
                array_push($user_enabled, $user_info->user_login);
                update_option('enable_user_list', $user_enabled);
            }
        }
    }

}

/*
 * Set default role manager
 */
if (!function_exists('ualpSetRoleManager')) {

    function ualpSetRoleManager() {
        $ualpRoleAccessList = get_option('ualpRoleAccessList');
        $ualpRoleAccessList1 = array(0 => "administrator");

        if(empty($ualpRoleAccessList)){
            $ualpRoleAccessList = array(0 => "administrator", 1 => "editor",  2 => "author", 3 => "contributor", 4 => "subscriber");
        }
        if (!in_array('administrator', $ualpRoleAccessList)) {
            $ualpRoleAccessList = array_merge($ualpRoleAccessList, $ualpRoleAccessList1);
        }
        update_option('ualpRoleAccessList', $ualpRoleAccessList);
    }

}

/*
 * Set default log hook
 */
if(!function_exists('ualpSetDefaultLogHook')){
    function ualpSetDefaultLogHook(){
        global $wpdb;
        $post_types = ualpPosttypes();
        $taxonomies = ualpTaxonomies();
        if( !get_option( 'enableLogHookList' ) ) {
            $logHook = array();
            foreach ($post_types as $post_type) {
                $postTypeHook[] = $post_type->name;
            }
            $logHook = array_merge($logHook,$postTypeHook);
            foreach ($taxonomies as $taxonomy) {
                $taxonomyHook[] = $taxonomy->name;
            }
            $logHook = array_merge($logHook,$taxonomyHook);
            $pluginHook = array('activated_plugin','deactivated_plugin','delete_plugin','plugin_modify','plugin_updated','plugin_installed');
            $logHook = array_merge($pluginHook,$logHook);
            $contactHook = array('wpcf7_after_create','wpcf7_after_update','wpcf7_admin_notices','wpcf7-recaptcha-setup');
            $logHook = array_merge($contactHook,$logHook);
            $ualpHook = array('ualp_untrack_users_list_updated','ualp_export_activity_log','ualp_general_settings_updated','ualp_hook_log_settings_updated','ualp_manage_role','ualp_set_password','ualp_change_password','ualp_email_settings_updated','ualp_disable_email_notification');
            $logHook = array_merge($ualpHook,$logHook);
            $userHook = array('wp_login','wp_login_failed','wp_logout','delete_user','user_register','insert_user_meta');
            $logHook = array_merge($userHook,$logHook);
            $themeHook = array('theme_file_modify','switch_theme','customize_save','theme_updated','theme_installed','delete_site_transient_update_themes');
            $logHook = array_merge($themeHook,$logHook);
            $commentHook = array('wp_insert_comment','edit_comment','trash_comment','spam_comment','restore_comment','delete_comment','comment_unapprove','comment_approve');
            $logHook = array_merge($commentHook,$logHook);
            $menuviewHook = array('wp_create_nav_menu','wp_update_nav_menu','delete_nav_menu');
            $logHook = array_merge($menuviewHook,$logHook);
            $otherHook = array('_core_updated_successfully','import_end','export_wp','widget_update_callback','updated_option','woocommerce_updated_option','dbdelta_queries');
            $logHook = array_merge($otherHook,$logHook);
            $supportedPluginHook = array('blog_designer','gravityforms','woocommerce_variation','wordfence','wordpress-seo','edd_settings');
            $logHook = array_merge($supportedPluginHook,$logHook);
            update_option('enableLogHookList', $logHook);
        }
    }
}

/**
 * Function to handle AJAX request.
 *
 * @since    1.0.0
 */
if (!function_exists('ualpAjaxFavoriteLog')) {

    function ualpAjaxFavoriteLog() {
        global $wpdb;
        $featured = $_POST['featured'];
        $id = (int) $_POST['post'];
        if (!empty($id) && $featured !== NULL) {
            if ($featured == 'no') {
                $result = $wpdb->update(
                    UALP_TABLENAME,
                    array( 'favorite' => '0' ),
                    array( 'uactid' => $id ),
                    array( '%s' ),
                    array( '%d' )
                );
            } else {
                $result = $wpdb->update(
                    UALP_TABLENAME,
                    array( 'favorite' => '1' ),
                    array( 'uactid' => $id ),
                    array( '%s' ),
                    array( '%d' )
                );
            }
        }
        exit;
    }

}

/*
 * View detailed log
 */
if(!function_exists('ualpViewUpdateDetail')){
    function ualpViewUpdateDetail(){
        global $wpdb,$externaldb;
        $uactid = $_POST['logID'];
        $uactLogActivity = $externaldb->get_results( 'SELECT * FROM '.UALP_TABLENAME.' WHERE uactid = '.$uactid );
        $uactDetails = $externaldb->get_results( 'SELECT uactd_key,uactd_value FROM '.UALP_DETAIL_TABLENAME.' WHERE uactid = '.$uactid );

        foreach($uactLogActivity as $k => $v){
            $objectType = $v->object_type;
            $action = $v->action;
            $userId = $v->user_id;
            $date = $v->modified_date;
            $username = $v->user_name;
            $userrole = $v->user_role;
            $useremail = $v->user_email;
            $ipaddress = $v->ip_address;
            $country = (isset($v->country) && $v->country != '') ? $v->country : '';
            $user_agent = (isset($v->user_agent) && $v->user_agent != '') ? $v->user_agent : '';
            $detail = $v->description;
        }
        $user_primary_key_array = ualpGetUserPrimaryData($userId);
        $user_meta_key_array = ualpGetUserMetaData($userId);
        $user_full_key_array = array_merge($user_primary_key_array,$user_meta_key_array);
        $post_primary_key_array = ualpGetPrimaryPostData($objectType);
        $post_meta_key_array = ualpGetPostMetaData($objectType);
        $post_full_key_array = array_merge($post_primary_key_array,$post_meta_key_array);
        $get_term_key_array = array("term_name","term_slug","term_description","term_parent");

        $customizerActivities = array();
        $customizerActivities = $externaldb->get_results( 'SELECT uactd_key,uactd_value FROM '.UALP_DETAIL_TABLENAME.' WHERE uactid = '.$uactid , ARRAY_A);

        $post_types = ualpPosttypes(); ?>
        <div class="ualp_view_details_wrap" title="<?php esc_attr_e('Log Details', 'user_activity_log_pro'); ?>">
            <div class="ualp_view_user_details">
                <table class="striped widefat">
                    <tr>
                        <td colspan="2" class="ulap_view_title">
                            <?php esc_html_e('Activity Detail','user_activity_log_pro'); ?>
                        </td>
                    </tr>
                    <tr>
                        <td><?php esc_html_e('Action ID','user_activity_log_pro'); ?></td>
                        <td>
                            <?php echo $uactid; ?>
                        </td>
                    </tr>
                    <tr>
                        <td><?php esc_html_e('Message','user_activity_log_pro'); ?></td>
                        <td>
                            <?php echo $detail; ?>
                        </td>
                    </tr>
                    <?php
                    if($objectType == 'Woocommerce' && $action == 'product variation deleted'){ ?>
                        <tr>
                            <td><?php esc_html_e('Product name','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_product_name',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Deleted variation data','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        $variation_data = ualpGetActivityLogDetail('ualp_variation_data',$uactid);
                                        $variation_data = unserialize($variation_data);
                                        print_r($variation_data);
                                    ?>
                                </span>
                            </td>
                        </tr><?php
                    }

                    if($objectType == 'Woocommerce' && $action == 'product variation saved'){ ?>
                        <tr>
                            <td><?php esc_html_e('Product name','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_product_name',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Variation SKU','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_variation_sku',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Variation regular price','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_variation_regular_price',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Variation sale price','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_variation_sale_price',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Virtual','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_virtual',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Downloadable','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_downloadable',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Weight','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_weight',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Length','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_length',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Manage stock','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_manage_stock',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Backorders','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_backorders',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Tax class','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_tax_class',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Download limit','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_download_limit',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Download expiry','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_download_expiry',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Variation description','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        print_r(ualpGetActivityLogDetail('ualp_variation_description',$uactid));
                                    ?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Updated variation data','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php
                                        $variation_data = ualpGetActivityLogDetail('ualp_variation_data',$uactid);
                                        $variation_data = unserialize($variation_data);
                                        print_r($variation_data);
                                    ?>
                                </span>
                            </td>
                        </tr><?php
                    }

                    if($objectType == 'Theme' && $action == 'switched'){ ?>
                        <tr>
                            <td><?php printf('%s %s', $objectType, $action); ?></td>
                            <td>
                                <span>
                                    <del>
                                        <?php
                                        print_r(ualpGetActivityLogDetail('ualp_old_theme_name',$uactid));
                                        echo "(";
                                        print_r(ualpGetActivityLogDetail('ualp_old_theme_version',$uactid));
                                        echo ")";
                                        ?>
                                    </del>
                                    <ins>
                                        <?php
                                        print_r(ualpGetActivityLogDetail('ualp_new_theme_name',$uactid));
                                        echo "(";
                                        print_r(ualpGetActivityLogDetail('ualp_new_theme_version',$uactid));
                                        echo ")";
                                        ?>
                                    </ins>
                                </span>
                            </td>
                        </tr><?php
                    }

                    if($objectType == 'Theme' && $action == 'updated'){ ?>
                        <tr>
                            <td><?php esc_html_e('Theme Name','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php print_r(ualpGetActivityLogDetail('ualp_theme_name',$uactid));?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Theme Version','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php print_r(ualpGetActivityLogDetail('ualp_theme_version',$uactid));?>
                                </span>
                            </td>
                        </tr><?php
                    }

                    if($objectType == 'Theme' && $action == 'customize updated'){
                        foreach($customizerActivities as $customizerActivity){
                            $customizerOldValue = ualpGetActivityLogDetail($customizerActivity['uactd_value']."_setting_old_value",$uactid);
                            $customizerNewValue = ualpGetActivityLogDetail($customizerActivity['uactd_value']."_setting_new_value",$uactid);
                            if($customizerActivity['uactd_key'] == 'main_text_colorcontrol_id' ||
                                $customizerActivity['uactd_key'] == 'secondary_text_colorcontrol_id' ||
                                $customizerActivity['uactd_key'] == 'background_repeatcontrol_id' ||
                                $customizerActivity['uactd_key'] == 'background_position_xcontrol_id' ||
                                $customizerActivity['uactd_key'] == 'background_attachmentcontrol_id' ||
                                $customizerActivity['uactd_key'] == 'page_background_colorcontrol_id' ||
                                $customizerActivity['uactd_key'] == 'link_colorcontrol_id' ||
                                $customizerActivity['uactd_key'] == 'header_textcolorcontrol_id' ||
                                $customizerActivity['uactd_key'] == 'blognamecontrol_id' ||
                                $customizerActivity['uactd_key'] == 'blogdescriptioncontrol_id' ||
                                $customizerActivity['uactd_key'] == 'header_textcolor_setting_id' ||
                                $customizerActivity['uactd_key'] == 'color_scheme_setting_id' ||
                                $customizerActivity['uactd_key'] == 'sidebar_textcolor_setting_id' ||
                                $customizerActivity['uactd_key'] == 'header_background_color_setting_id' ||
                                $customizerActivity['uactd_key'] == 'nav_menu_locations[primary]control_id' ||
                                $customizerActivity['uactd_key'] == 'nav_menu_locations[social]control_id' ||
                                $customizerActivity['uactd_key'] == 'background_colorcontrol_id'
                            ){ ?>
                                <tr>
                                    <td><?php echo ualpReplaceKey($customizerActivity['uactd_value']); ?></td>
                                    <td>
                                        <del><?php print_r($customizerOldValue);?></del>
                                        <span>
                                            <ins>
                                                <?php print_r($customizerNewValue);?>
                                            </ins>
                                        </span>
                                    </td>
                                </tr><?php
                            }

                            $theme = get_option('stylesheet');
                            $custom_css = "custom_css[".$theme."]_setting_id";

                            if($customizerActivity['uactd_key'] == $custom_css){ ?>
                                <tr>
                                    <td><?php echo ualpReplaceKey($customizerActivity['uactd_value']); ?></td>
                                    <td>
                                        <table class="diff">
                                            <colgroup><col class="content"></colgroup>
                                            <tbody>
                                                <tr>
                                                    <td class="diff-deletedline">
                                                        <?php if($customizerOldValue != ""){
                                                            echo ($customizerOldValue);
                                                        }?>
                                                    </td>
                                                    <td>&nbsp;</td>
                                                    <td class="diff-addedline">
                                                        <?php if($customizerNewValue != ""){
                                                            echo ($customizerNewValue);
                                                        }?>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                    </td>
                                </tr><?php
                            }

                            if($customizerActivity['uactd_key'] == 'page_for_posts_setting_id' || $customizerActivity['uactd_key'] == 'page_on_front_setting_id'){ ?>
                                <tr>
                                    <td><?php echo ualpReplaceKey($customizerActivity['uactd_value']); ?></td>
                                    <td>
                                        <del><?php
                                            if($customizerOldValue != ""){
                                                echo get_the_title($customizerOldValue);
                                            }?>
                                        </del>
                                        <span>
                                            <ins>
                                                <?php
                                                if($customizerNewValue != ""){
                                                    echo get_the_title($customizerNewValue);
                                                }?>
                                            </ins>
                                        </span>
                                    </td>
                                </tr><?php
                            }

                            if($customizerActivity['uactd_key'] == 'background_image_setting_id' || $customizerActivity['uactd_key'] == 'header_image_setting_id'){ ?>
                                <tr>
                                    <td><?php echo ualpReplaceKey($customizerActivity['uactd_value']); ?></td>
                                    <td><?php
                                        if($customizerOldValue != ""){?>
                                            <del><img class="ualp-tmb-img" src="<?php echo $customizerOldValue; ?>" alt="<?php esc_attr_e('Old Background image', 'user_activity_log_pro'); ?>"></del><?php
                                        }?>
                                        <span><?php
                                            if($customizerNewValue != ""){?>
                                                <ins><img class="ualp-tmb-img" src="<?php echo $customizerNewValue; ?>" alt="<?php esc_attr_e('New Background image', 'user_activity_log_pro'); ?>"></ins><?php
                                            }?>
                                        </span>
                                    </td>
                                </tr><?php
                            }
                            if($customizerActivity['uactd_key'] == 'custom_logocontrol_id' || $customizerActivity['uactd_key'] == 'site_icon_setting_id'){ ?>
                                <tr>
                                    <td><?php echo ualpReplaceKey($customizerActivity['uactd_value']); ?></td>
                                    <td><?php
                                        if($customizerOldValue != ""){?>
                                            <del><img class="ualp-tmb-img" src="<?php echo wp_get_attachment_thumb_url( $customizerOldValue ); ?>" alt="<?php esc_attr_e('Old custom logo', 'user_activity_log_pro'); ?>"></del><?php
                                        }?>
                                        <span><?php
                                            if($customizerNewValue != ""){?>
                                                <ins><img class="ualp-tmb-img" src="<?php echo wp_get_attachment_thumb_url( $customizerNewValue ); ?>" alt="<?php esc_attr_e('New custom logo', 'user_activity_log_pro'); ?>"></ins><?php
                                            }?>
                                        </span>
                                    </td>
                                </tr><?php
                            }
                        }
                    }

                    if($objectType == 'Comment' && ($action == 'edited' || $action == 'inserted')){
                        $commentID = ualpGetActivityLogDetail('ualp_comment_id',$uactid);
                        $comment = get_comment( $commentID );
                        ?>
                        <tr>
                            <td><?php esc_html_e('Comment ID','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php echo $commentID;?>
                                </span>
                            </td>
                        </tr>
                        <?php
                        if(isset($comment->comment_author) && $comment->comment_author != ''){ ?>
                            <tr>
                                <td><?php esc_html_e('Comment Author','user_activity_log_pro'); ?></td>
                                <td>
                                    <span>
                                        <?php print_r($comment->comment_author);?>
                                    </span>
                                </td>
                            </tr><?php
                        }
                        if(isset($comment->comment_author_email) && $comment->comment_author_email != ''){ ?>
                            <tr>
                                <td><?php esc_html_e('Comment Author E-mail','user_activity_log_pro'); ?></td>
                                <td>
                                    <span>
                                        <?php print_r($comment->comment_author_email);?>
                                    </span>
                                </td>
                            </tr><?php }
                        if(isset($comment->comment_author_url) && $comment->comment_author_url != ''){ ?>
                            <tr>
                                <td><?php esc_html_e('Comment Author URL','user_activity_log_pro'); ?></td>
                                <td>
                                    <span>
                                        <?php print_r($comment->comment_author_url);?>
                                    </span>
                                </td>
                            </tr><?php
                        } ?>
                        <tr>
                            <td><?php esc_html_e('Comment Content','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php print_r($comment->comment_content);?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Comment Date','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php print_r($comment->comment_date);?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Comment Approved','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php print_r($comment->comment_approved);?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Comment Post Title','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php print_r(get_the_title($comment->comment_post_ID));?>
                                </span>
                            </td>
                        </tr><?php
                    }

                    if($objectType == 'Widget' && $action == 'updated'){?>
                        <tr>
                            <td><?php esc_html_e('Sidebar Name','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php echo ualpGetActivityLogDetail('ualp_sidebar_name_translated',$uactid);?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Widget Name','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php echo ualpGetActivityLogDetail('ualp_widget_name_translated',$uactid);?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('Old instance','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php echo ualpGetActivityLogDetail('ualp_old_instance',$uactid);?>
                                </span>
                            </td>
                        </tr>
                        <tr>
                            <td><?php esc_html_e('New instance','user_activity_log_pro'); ?></td>
                            <td>
                                <span>
                                    <?php echo ualpGetActivityLogDetail('ualp_new_instance',$uactid);?>
                                </span>
                            </td>
                        </tr><?php
                    }

                    if($objectType == 'User' && $action == 'profile updated'){
                        foreach($user_full_key_array as $user_full_key_single) {
                            $old_user_meta_key = "ualp_user_old_$user_full_key_single";
                            $new_user_meta_key = "ualp_user_new_$user_full_key_single";
                            foreach ($uactDetails as $k => $v){
                                if($old_user_meta_key == $v->uactd_key){
                                    $oldValue = ualpGetActivityLogDetail($old_user_meta_key,$uactid);
                                    $newValue = ualpGetActivityLogDetail($new_user_meta_key,$uactid);
                                    ?><tr>
                                        <td>
                                            <label><?php
                                                ualpReplaceKey($user_full_key_single);
                                                ?> :
                                            </label>
                                        </td>
                                        <td class="user_updated">
                                            <?php
                                            if($oldValue != '') { ?>
                                                <del><?php echo ualpReplaceSpecialArray($user_full_key_single, $oldValue); ?></del><?php
                                            } ?>
                                                <span>
                                                <ins><?php echo ualpReplaceSpecialArray($user_full_key_single, $newValue); ?></ins>
                                            </span>
                                        </td>
                                    </tr><?php
                                }
                            }
                        }
                    }

                    if($objectType == 'Term' && $action == 'edited') {
                        foreach($get_term_key_array as $term_key_single) {
                            $old_term_meta_key = "ulap_old_$term_key_single";
                            $new_term_meta_key = "ulap_new_$term_key_single";
                            foreach ($uactDetails as $k => $v) {
                                if ($old_term_meta_key == $v->uactd_key) {
                                    $oldValue = ualpGetActivityLogDetail($old_term_meta_key, $uactid);
                                    $newValue = ualpGetActivityLogDetail($new_term_meta_key, $uactid);
                                    if($oldValue != "" && $newValue != ""){
                                        ?>
                                        <tr>
                                            <td><?php ualpReplaceKey($term_key_single); ?></td>
                                            <td>
                                                <?php if($term_key_single == 'term_parent'){

                                                    if($oldValue == 0){
                                                        $oldValue = esc_html__("None", "user_activity_log_pro");
                                                    }else{
                                                        $oldValue = ualpGetTermById($oldValue);
                                                        $oldValue = $oldValue['name'];
                                                    }
                                                    if($newValue == 0){
                                                        $newValue = esc_html__("None", "user_activity_log_pro");
                                                    }else{
                                                        $newValue = ualpGetTermById($newValue);
                                                        $newValue = $newValue['name'];
                                                    }
                                                }
                                                if($oldValue == '1'){
                                                    $oldValue = 'True';
                                                }
                                                if($oldValue == '0'){
                                                    $oldValue = 'False';
                                                }
                                                if($newValue == '1'){
                                                    $newValue = 'True';
                                                }
                                                if($newValue == '0'){
                                                    $newValue = 'False';
                                                } ?>
                                                <del><?php print_r($oldValue); ?></del>
                                                <span>
                                                    <ins><?php print_r($newValue); ?></ins>
                                                </span>
                                            </td>
                                        </tr><?php
                                    }
                                }
                            }
                        }
                    }
                    foreach ($post_types as $post_type) {
                        if($objectType == $post_type->name) {
                            foreach($post_full_key_array as $post_full_key_single) {
                                    $old_user_meta_key = "ualp_post_old_$post_full_key_single";
                                    $new_user_meta_key = "ualp_post_new_$post_full_key_single";
                                    foreach ($uactDetails as $k=>$v){
                                        if($post_full_key_single == 'field_') {
                                            if(strpos($v->uactd_key, 'ualp_post_old_field_') !== false) {
                                                $old_user_meta_key = $v->uactd_key;
                                                $field_name = ualpStrAfter($v->uactd_key,'ualp_post_old_field_');
                                                $new_user_meta_key = "ualp_post_new_field_$field_name";
                                            }
                                        }
                                        if($old_user_meta_key == $v->uactd_key){
                                            $oldValue = ualpGetActivityLogDetail($old_user_meta_key,$uactid);
                                            $newValue = ualpGetActivityLogDetail($new_user_meta_key,$uactid);
                                            ?>
                                            <tr>
                                                <td>
                                                    <label>
                                                        <?php
                                                        if($post_full_key_single == 'field_') {
                                                            ualpReplaceKey('field_'.$field_name);
                                                        }
                                                        else {
                                                            ualpReplaceKey($post_full_key_single,$objectType);
                                                        }
                                                        ?>
                                                    </label>
                                                </td>
                                                <td>
                                                    <?php
                                                    if($post_full_key_single == 'post_content') {
                                                        $diff_table = wp_text_diff( $oldValue,$newValue);
                                                        echo $diff_table;
                                                    } else {
                                                        if($post_full_key_single == 'post_parent'){
                                                            $oldValue = get_the_title($oldValue);
                                                            $newValue = get_the_title($newValue);
                                                        }
                                                        if($post_full_key_single == 'post_author'){
                                                            $oldUser = get_user_by('id',$oldValue);
                                                            $newUser = get_user_by('id',$newValue);
                                                            if((isset($newUser) && !empty($newUser)) || (isset($oldUser) && !empty($oldUser)) ){
                                                                $oldValue = isset($oldUser->display_name) ? $oldUser->display_name : '';
                                                                $newValue = isset($newUser->display_name) ? $newUser->display_name : '';
                                                            }else {
                                                                $oldValue = "";
                                                                $newValue = "";
                                                            }
                                                        }
                                                        $old_val = ualpReplaceSpecialArray($post_full_key_single,$oldValue);
                                                        $new_val = ualpReplaceSpecialArray($post_full_key_single,$newValue);
                                                        if($post_full_key_single == '_sale_price_dates_to' || $post_full_key_single == '_sale_price_dates_from'){
                                                            $date_format = get_option('date_format');
                                                            $old_val = date($date_format, $old_val);
                                                            $new_val = date($date_format, $new_val);
                                                        }
                                                        if($post_full_key_single == '_tax_class'){
                                                            if($old_val == ''){
                                                                $old_val = 'Standard';
                                                            }
                                                            if($new_val == ''){
                                                                $new_val = 'Standard';
                                                            }
                                                        }
                                                        if($post_full_key_single == '_tax_status'){
                                                            if($old_val == ''){
                                                                $old_val = 'None';
                                                            }
                                                            if($new_val == ''){
                                                                $new_val = 'None';
                                                            }
                                                        }
                                                        ?>
                                                        <span>
                                                            <?php
                                                            if($old_val != '') { ?>
                                                                <del><?php echo $old_val; ?></del><?php
                                                            } ?>
                                                            <ins><?php echo $new_val; ?></ins>
                                                        </span>
                                                    <?php } ?>
                                                </td>
                                            </tr>
                                                <?php
                                        }
                                    }
                                }
                        }
                    }

                    $all_taxs = ualpGetAllActivityLogDetail($uactid);

                    foreach($all_taxs as $all_tax) {
                        $oldValue = '';
                        $tax_key = $all_tax['uactd_key'];
                        $ualpTermIn = ualpTermIn($tax_key);
                        $ualpTermInNew = ualpTermInNew($tax_key);
                        if($ualpTermInNew) {
                            $taxname = ualpStrAfter($tax_key,'ualp_post_tax_new_');
                            $oldkey = 'ualp_post_tax_old_'.$taxname;
                            $oldValue = ualpGetActivityLogDetail($oldkey,$uactid);
                            if ($ualpTermIn && $ualpTermInNew) {
                                $newValue = $all_tax['uactd_value'];
                                if($tax_key == 'ualp_post_tax_new_post_format' || $tax_key == 'ualp_post_tax_old_post_format' ){
                                    if($oldValue != '') {
                                        $oldValue = ualpReplaceSpecialArray($tax_key,$oldValue,'old');
                                    }
                                    $newValue = ualpReplaceSpecialArray($tax_key,$newValue,'new');
                                    if($oldValue == ''){
                                        $oldValue = 'Standard';
                                    }
                                    if($newValue == ''){
                                        $newValue = 'Standard';
                                    }
                                } else {
                                    if($oldValue != '') {
                                        $oldValue = ualpReplaceSpecialArray($tax_key,$oldValue,'old');
                                    }
                                    $newValue = ualpReplaceSpecialArray($tax_key,$newValue,'new');
                                }
                                if($oldValue != $newValue){
                                    if($oldValue == '1'){
                                        $oldValue = 'True';
                                    }
                                    if($oldValue == '0'){
                                        $oldValue = 'False';
                                    }
                                    if($newValue == '1'){
                                        $newValue = 'True';
                                    }
                                    if($newValue == '0'){
                                        $newValue = 'False';
                                    } ?>
                                    <tr>
                                        <td><?php ualpReplaceKey($tax_key); ?></td>
                                        <td>
                                            <span>
                                                <del><?php print_r($oldValue); ?></del>
                                                <ins><?php print_r($newValue); ?></ins>
                                            </span>
                                        </td>
                                    </tr><?php
                                }
                            }
                        }
                    }

                    foreach($all_taxs as $all_tax) {
                        $oldValue = '';
                        $option_key = $all_tax['uactd_key'];
                        $ualpOptionIn = ualpOptionIn($option_key);
                        $ualpOptionInNew = ualpOptionInNew($option_key);
                        if($ualpOptionInNew) {
                            $optionname = ualpStrAfter($option_key,'ualp_option_new_');
                            $oldkey = 'ualp_option_old_'.$optionname;
                            $oldValue = ualpGetActivityLogDetail($oldkey,$uactid);
                            if ($ualpOptionIn && $ualpOptionInNew) {
                                $newValue = $all_tax['uactd_value'];
                                if($oldValue != '') {
                                    $oldValue = ualpReplaceSpecialArray($option_key,$oldValue,'old');
                                }
                                $newValue = ualpReplaceSpecialArray($option_key,$newValue,'new');
                                if($oldValue != $newValue){
                                    if($option_key == 'ualp_option_new_autoptimize_extra_checkbox_field_1'){
                                        $option_label = 'Remove emojis';
                                    } elseif($option_key == 'ualp_option_new_autoptimize_extra_checkbox_field_0'){
                                        $option_label = 'Remove query strings from static resources';
                                    } elseif($option_key == 'ualp_option_new_autoptimize_extra_radio_field_4'){
                                        $option_label = 'Google Fonts';
                                    } elseif($option_key == 'ualp_option_new_autoptimize_extra_text_field_2'){
                                        $option_label = 'Preconnect to 3rd party domains';
                                    } elseif($option_key == 'ualp_option_new_autoptimize_extra_text_field_3'){
                                        $option_label = 'Async Javascript-files';
                                    } else {
                                        $option_label = $option_key;
                                    }
                                    ?>
                                    <tr>
                                        <td><?php ualpReplaceKey($option_label); ?></td>
                                        <td>
                                            <span>
                                                <?php
                                                    if($option_key == 'ualp_option_new_rest_front_page' ||
                                                        $option_key == 'ualp_option_old_rest_front_page' ||
                                                        $option_key == 'ualp_option_new_directory_page_id' ||
                                                        $option_key == 'ualp_option_old_directory_page_id' ||
                                                        $option_key == 'ualp_option_new_profile_page_id' ||
                                                        $option_key == 'ualp_option_old_profile_page_id' ||
                                                        $option_key == 'ualp_option_new_login_page_id' ||
                                                        $option_key == 'ualp_option_old_login_page_id' ||
                                                        $option_key == 'ualp_option_new_registration_page_id' ||
                                                        $option_key == 'ualp_option_old_registration_page_id' ||
                                                        $option_key == 'ualp_option_new_xoousersultra_my_account_page' ||
                                                        $option_key == 'ualp_option_old_xoousersultra_my_account_page' ||
                                                        $option_key == 'ualp_option_new_rest_cancel_page' ||
                                                        $option_key == 'ualp_option_old_rest_front_page'){
                                                        $oldValue = get_the_title($oldValue);
                                                        $newValue = get_the_title($newValue);
                                                    }

                                                    if( $option_key == 'ualp_option_new_holiday_dates' || $option_key == 'ualp_option_old_holiday_dates' ){
                                                        $newValue = str_replace('replace_this :',' ',$newValue);
                                                        $newValue = str_replace('rest_holidays_date_from : , rest_holidays_date_to :',' ',$newValue);
                                                        $newValue = trim($newValue,', ,');
                                                        $newValue = trim($newValue,',');
                                                        $newValue = explode(', ,', $newValue);

                                                        $oldValue = str_replace('replace_this :',' ',$oldValue);
                                                        $oldValue = str_replace('rest_holidays_date_from : , rest_holidays_date_to :',' ',$oldValue);
                                                        $oldValue = trim($oldValue,', ,');
                                                        $oldValue = trim($oldValue,',');
                                                        $oldValue = explode(', ,', $oldValue);

                                                        $tempNewValue = array_intersect($newValue, $oldValue);
                                                        $newValue1 = array_diff($newValue, $tempNewValue);

                                                        $tempOldValue = array_intersect($oldValue, $newValue);
                                                        $oldValue1 = array_diff($oldValue, $tempOldValue);

                                                        $newValue = $newValue1;
                                                        $oldValue = $oldValue1;

                                                        $newValue = implode(', ',$newValue);
                                                        $oldValue = implode(', ',$oldValue);
                                                    }
                                                    if( $option_key == 'ualp_option_new_dayno' || $option_key == 'ualp_option_old_dayno' ){
                                                        $newValue = trim($newValue,', ');
                                                        $newValue = ltrim($newValue,', ');
                                                        $newValue = explode(', ,', $newValue);
                                                        foreach($newValue as $key => $value){
                                                            if(isset($value))
                                                            $new_Value[$key] = date('l', strtotime("Monday + $key Days")) .' : ' .$value;
                                                        }
                                                        $newValue = $new_Value;

                                                        $oldValue = trim($oldValue,', ');
                                                        $oldValue = ltrim($oldValue,', ');
                                                        $oldValue = explode(', ,', $oldValue);
                                                        foreach($oldValue as $key => $value){
                                                            if(isset($value))
                                                            $old_Value[$key] = date('l', strtotime("Monday + $key Days")) .' : ' .$value;
                                                        }
                                                        $oldValue = $old_Value;

                                                        $tempNewValue = array_intersect($newValue, $oldValue);
                                                        $newValue1 = array_diff($newValue, $tempNewValue);

                                                        $tempOldValue = array_intersect($oldValue, $newValue);
                                                        $oldValue1 = array_diff($oldValue, $tempOldValue);

                                                        $newValue = $newValue1;
                                                        $oldValue = $oldValue1;

                                                        $newValue = implode(', ',$newValue);
                                                        $oldValue = implode(', ',$oldValue);
                                                    }
                                                    if( $option_key == 'ualp_option_new_r_closed_days' || $option_key == 'ualp_option_old_r_closed_days'){
                                                        $newValue = explode(',', $newValue);
                                                        foreach($newValue as $value){
                                                            $new_Value[] = date('l', strtotime("Sunday + $value Days"));
                                                        }
                                                        $newValue = implode(', ',$new_Value);
//
                                                        $oldValue = explode(',', $oldValue);
                                                        foreach($oldValue as $value){
                                                            $old_Value[] = date('l', strtotime("Sunday + $value Days"));
                                                        }
                                                        $oldValue = implode(', ',$old_Value);
                                                    }
                                                    if($option_key == 'ualp_option_new_shipping' || $option_key == 'ualp_option_old_shipping' || $option_key == 'ualp_option_new_billing' || $option_key == 'ualp_option_old_billing'){
                                                        $oldValue = trim($oldValue,', ');
                                                        $oldValue = ltrim($oldValue,', ');
                                                        $oldValue = explode(', , ',$oldValue);

                                                        $newValue = trim($newValue,', ');
                                                        $newValue = ltrim($newValue,', ');
                                                        $newValue = explode(', , ',$newValue);

                                                        $tempNewValue = array_intersect($newValue, $oldValue);
                                                        $newValue1 = array_diff($newValue, $tempNewValue);

                                                        $tempOldValue = array_intersect($oldValue, $newValue);
                                                        $oldValue1 = array_diff($oldValue, $tempOldValue);

                                                        $newValue = $newValue1;
                                                        $oldValue = $oldValue1;

                                                        $oldValue = json_encode($oldValue);
                                                        $oldValue = str_replace(', ',', <br/>',$oldValue);
                                                        $new_Value = str_replace(',"position',',<br/>"position',$oldValue);

                                                        $newValue = json_encode($newValue);
                                                        $newValue = str_replace(', ',', <br/>',$newValue);
                                                        $old_Value = str_replace(',"position',',<br/>"position',$newValue);

                                                        $newValue = $new_Value;
                                                        $oldValue = $old_Value;
                                                        ?>
                                                        <del style="display: inline-block;width: 48%;float: left;margin: 0;padding: 10px;box-sizing: border-box;"><?php print_r($oldValue); ?></del>
                                                        <ins style="display: inline-block;width: 48%;float: right;margin: 0;padding: 10px;box-sizing: border-box;"><?php print_r($newValue); ?></ins><?php
                                                    } else {
                                                        if($option_key == 'ualp_option_new_uultra_front_publisher_default_category' || $option_key == 'ualp_option_old_uultra_front_publisher_default_category'){
                                                            if($oldValue == '0') {
                                                                $oldValue = '-';
                                                            } else {
                                                                $term = get_term_by('id', $oldValue, 'category');
                                                                $oldValue = $term->name;
                                                            }
                                                            if($newValue == '0') {
                                                                $newValue = '-';
                                                            } else {
                                                                $term = get_term_by('id', $newValue, 'category');
                                                                $newValue = $term->name;
                                                            }
                                                        }
                                                        if($option_key == 'ualp_option_new_redirect_after_registration_login' || $option_key == 'ualp_option_old_redirect_after_registration_login') {
                                                            if($oldValue == '0') {
                                                                $oldValue = '-';
                                                            } else {
                                                                $oldValue = get_the_title($oldValue);
                                                            }
                                                            if($newValue == '0') {
                                                                $newValue = '-';
                                                            } else {
                                                                $newValue = get_the_title($newValue);
                                                            }
                                                        }
                                                        if($oldValue == '1'){
                                                            $oldValue = 'True';
                                                        }
                                                        if($oldValue == '0'){
                                                            $oldValue = 'False';
                                                        }
                                                        if($newValue == '1'){
                                                            $newValue = 'True';
                                                        }
                                                        if($newValue == '0'){
                                                            $newValue = 'False';
                                                        }
                                                        ?>
                                                        <del><?php print_r($oldValue); ?></del>
                                                        <ins><?php print_r($newValue); ?></ins><?php
                                                    }
                                                ?>
                                            </span>
                                        </td>
                                    </tr><?php
                                }
                            }
                        }
                    }
                    ?>
                    <tr>
                        <td class="ulap_view_title" colspan="2">
                            <?php esc_html_e('User Detail','user_activity_log_pro'); ?>
                        </td>
                    </tr>
                    <tr>
                        <td><?php esc_html_e('Date','user_activity_log_pro'); ?></td>
                        <td>
                            <?php
                            $date_format = get_option('date_format');
                            $time_format = get_option('time_format');

                            $modified_date = date($date_format, strtotime($date));
                            $modified_time = date($time_format, strtotime($date));

                            echo $modified_date.' '.$modified_time;
                            ?>
                        </td>
                    </tr>
                    <tr>
                        <td><?php esc_html_e('Username','user_activity_log_pro'); ?></td>
                        <td>
                            <?php echo $username; ?>
                        </td>
                    </tr>
                    <?php
                    if(isset($userrole) && $userrole != ''){ ?>
                        <tr>
                            <td><?php esc_html_e('Role','user_activity_log_pro'); ?></td>
                            <td>
                                <?php echo $userrole; ?>
                            </td>
                        </tr><?php
                    }
                    if(isset($useremail) && $useremail != ''){ ?>
                        <tr>
                            <td><?php esc_html_e('Email Address','user_activity_log_pro'); ?></td>
                            <td>
                                <?php echo $useremail; ?>
                            </td>
                        </tr><?php
                    }
                    if(ualpAllowIp()) {
                    ?>
                    <tr>
                        <td><?php esc_html_e('IP Address','user_activity_log_pro'); ?></td>
                        <td>
                            <?php echo $ipaddress; ?>
                        </td>
                    </tr>
                    <?php }
                    if(ualpAllowCountry()) {
                    ?>
                    <tr>
                        <td><?php esc_html_e('Country','user_activity_log_pro'); ?></td>
                        <td>
                            <?php echo $country; ?>
                        </td>
                    </tr>
                    <?php } 
                    if(ualpAllowUserAgent()) {
                    ?>
                    <tr>
                        <td><?php esc_html_e('User Agent','user_activity_log_pro'); ?></td>
                        <td>
                            <?php echo $user_agent; ?>
                        </td>
                    </tr>
                    <?php } ?>
                </table>
            </div>
        </div><?php
        exit;
    }
}

/*
 * Get current admin page url
 */
if (!function_exists('ualpGetCurrentAdminPageUrl')) {

    function ualpGetCurrentAdminPageUrl($SERVER = null) {
        if ($SERVER === null)
            $SERVER = $_SERVER;
        if (!isset($SERVER['SERVER_PORT']))
            return '';
        $ssl = false;
        if (isset($SERVER['HTTPS'])) {
            $value = strtolower($SERVER['HTTPS']);
            $ssl = (( $value != '' ) && ( $value != 'off' ));
        }

        $port = $SERVER['SERVER_PORT'];
        if ($ssl && $port == 443)
            $port = '';
        if (!$ssl && $port == 80)
            $port = '';
        if ($port != '')
            $port = ':' . $port;

        $url = $SERVER['REQUEST_URI'];
        return sprintf('%s://%s%s%s', $ssl ? 'https' : 'http', $SERVER['HTTP_HOST'], $port, $url);
    }

}

/*
 * Get detail activity log
 */
if(!function_exists('ualpGetActivityLogDetail')){
    function ualpGetActivityLogDetail($optionName,$activityId){
        global $wpdb, $externaldb;
        $row = $externaldb->get_row("SELECT uactd_value FROM ".UALP_DETAIL_TABLENAME." WHERE uactd_key = '$optionName' AND uactid = '$activityId'", ARRAY_A );
        return $row['uactd_value'];
    }
}

/*
 * Get all activity log
 */
if(!function_exists('ualpGetAllActivityLogDetail')){
    function ualpGetAllActivityLogDetail($activityId){
        global $wpdb, $externaldb;
        $uactd_data = $externaldb->get_results("SELECT * FROM ".UALP_DETAIL_TABLENAME." WHERE uactid = '$activityId'", ARRAY_A );
        return $uactd_data;
    }
}

/*
 * Delete activity log as per selected days
 */
if(!function_exists('ualpDeleteLog')){
    function ualpDeleteLog(){
        global $wpdb, $externaldb;
        $getLogSpan = "";
        $getLogSpan = get_option('ualpKeepLogsDay');
        $time = strtotime('-' . $getLogSpan . ' days');
        $date = date('Y-m-d', $time);
        if (isset($getLogSpan) && !empty($getLogSpan)) {
            $externaldb->query("DELETE FROM " . UALP_TABLENAME . " WHERE modified_date < '$date'");
        }
    }
}

/*
 * replace key width label
 */
if(!function_exists('ualpReplaceKey')) {
    function ualpReplaceKey($val='',$post_type='') {
        $dflt_array = array();

        if($val == '_upsell_ids'){
            $val = '_upsell_products';
        }
        if($val == 'ualp_option_new_uultra_password_lenght'){
            $val = 'User Ultra Password Length';
        }
        if($val == '_crosssell_ids'){
            $val = '_crosssell_products';
        }

        $val = str_replace('ualp_post_tax_old_', '', $val);
        $val = str_replace('ualp_post_tax_new_', '', $val);
        $val = str_replace('ualp_option_old_', '', $val);
        $val = str_replace('ualp_option_new_', '', $val);

        if(0 === strpos($val, 'rest_')){
            $val = substr($val, strlen('rest_'));
        }

        $val = str_replace('_', ' ', $val);
        $val = trim($val);
        $val = ucfirst($val);
        $val = apply_filters('ualp_replace_key',$val,$post_type);
        print_r($val);
    }
}

/*
 * Replace value for special key
 */
if(!function_exists('ualpReplaceSpecialArray')) {
    function ualpReplaceSpecialArray($key,$value,$status = '') {
        //post id serialized array
        $post_serialized_array = ualpGetSerializedPostArray();
        //cat id serialized array
        $cat_serialized_array = ualpGetSerializedCatArray();
        //data serialized array
        //$data_serialized_array = ualpGetSerializedDataArray();
        $n_value = '';
        if($key == '_thumbnail_id') {
            $n_value = '<img class="ualp-tmb-img" src="'.wp_get_attachment_thumb_url( $value ).'" />';
            return $n_value;
        }
        else if($key == '_product_image_gallery') {
            $value = explode(',',$value);
            if(is_array($value)) {
                foreach($value as $s_value) {
                   $n_value .= '<img class="ualp-tmb-img" src="'.wp_get_attachment_thumb_url( $s_value ).'" />';
                }
            }
            return $n_value;
        }
        //for acf support
        else if($key == 'rule') {
            $value = maybe_unserialize($value);
            if(is_array($value)) {
                $j = 0;
                foreach($value as $s_value) {
                    $s_value = maybe_unserialize($s_value);
                    if($j != 0) {
                        $n_value .= '<br/>';
                    }
                    $i = 0;
                    foreach ($s_value as $ss_key=>$ss_value) {
                        if($i == 0) {
                            $n_value .= $ss_key.':'.$ss_value;
                        }
                        else {
                            $n_value .= ', '.$ss_key.':'.$ss_value;
                        }
                        $i++;
                    }
                    $j++;
                }
                return $n_value;
            }
        }
        else if(in_array($key, $post_serialized_array)) {
            $value = maybe_unserialize($value);
            if(is_array($value)) {
                $i = 0;
                foreach ($value as $s_value) {
                    if($i == 0) {
                        $n_value .= get_the_title( $s_value );
                    }
                    else {
                        $n_value .= ', '.get_the_title( $s_value );
                    }
                    $i++;
                }
            }
            else {
                $n_value = get_the_title( $value );
            }
            return $n_value;
        }

        else if(array_key_exists($key, $cat_serialized_array)) {
            $value = maybe_unserialize($value);
            if(is_array($value)) {
                $i = 0;
                foreach ($value as $s_value) {
                    $term_data = get_term( $s_value, $cat_serialized_array[$s_value]);
                    if(!empty($term_data)) {
                        if($i == 0) {
                            $n_value .= $term_data->name;
                        }
                        else {
                            $n_value .= ', '.$term_data->name;
                        }
                    }
                    $i++;
                }
            }
            else {
                $term_data = get_term( $value, $cat_serialized_array[$value]);
                if(!empty($term_data)) {
                    $n_value .= $term_data->name;
                }
            }
            return $n_value;
        }
        else if(ualpTermIn($key)) {
            $value = maybe_unserialize($value);
            if(is_array($value)) {
                $i = 0;
                foreach($value as $term_id) {
                    if(ualpTermInOld($key)) {
                        $taxname = ualpStrAfter($key,'ualp_post_tax_old_');
                    }
                    else {
                        $taxname = ualpStrAfter($key,'ualp_post_tax_new_');
                    }
                    $term_data = get_term( $term_id, $taxname);
                    if(!empty($term_data)) {
                        if($i == 0) {
                            $n_value .= $term_data->name;
                        }
                        else {
                            $n_value .= ', '.$term_data->name;
                        }
                    }
                    $i++;
                }
                return $n_value;
            }
        }
        else if(is_serialized($value)){
            $value = maybe_unserialize($value);
            if(is_array($value)) {
                $i = 0;
                $n_value = ualpserializeloop($value);
                return $n_value;
            }
        }
        return $value;
    }
}

/*
 * check if taxonomy term
 */
if(!function_exists('ualpTermIn')) {
    function ualpTermIn($tax_key) {
        if (strpos($tax_key, 'ualp_post_tax_') !== false) {
            return true;
        }
        return false;
    }
}

/*
 * check if taxonomy term old change
 */
if (!function_exists('ualpTermInOld')) {

    function ualpTermInOld($tax_key) {
        if (strpos($tax_key, 'ualp_post_tax_old_') !== false) {
            return true;
        }
        return false;
    }

}

/*
 * check if taxonomy term new change
 */
if (!function_exists('ualpTermInNew')) {

    function ualpTermInNew($tax_key) {
        if (strpos($tax_key, 'ualp_post_tax_new_') !== false) {
            return true;
        }
        return false;
    }

}

/*
 * check if option
 */
if(!function_exists('ualpOptionIn')) {
    function ualpOptionIn($option_key) {
        if (strpos($option_key, 'ualp_option_') !== false) {
            return true;
        }
        return false;
    }
}

/*
 * check if option old change
 */
if (!function_exists('ualpOptionInOld')) {

    function ualpOptionInOld($option_key) {
        if (strpos($option_key, 'ualp_option_old_') !== false) {
            return true;
        }
        return false;
    }

}

/*
 * check if option new change
 */
if (!function_exists('ualpOptionInNew')) {

    function ualpOptionInNew($option_key) {
        if (strpos($option_key, 'ualp_option_new_') !== false) {
            return true;
        }
        return false;
    }

}

/*
 * get taxnonomy name
 */
if (!function_exists('ualpStrAfter')) {

    function ualpStrAfter($string, $substring) {
        $pos = strpos($string, $substring);
        if ($pos === false)
            return $string;
        else
            return(substr($string, $pos + strlen($substring)));
    }

}


/*
 * get all post types
 */
if(!function_exists('ualpPosttypes')) {
    function ualpPosttypes() {
        $ualp_post_types = array();
        $post_types = get_post_types(array(), 'objects', 'and');
        $removable_post_type_array = array('nav_menu_item','revision','product_variation','shop_order_refund','user_request');
        foreach($post_types as $post_type) {
            if(in_array($post_type->name, $removable_post_type_array)) {
                unset($post_types[$post_type->name]);
            }
        }
        return apply_filters('ualp_post_types',$post_types);
    }
}

/*
 * get all taxonomies
 */
if(!function_exists('ualpTaxonomies')) {
    function ualpTaxonomies() {
        $taxonomies = get_taxonomies(array(), 'objects', 'and');
        $removable_taxonomy_array = array('nav_menu','link_category','post_format','product_type');
        foreach($taxonomies as $taxonomy) {
            if(in_array($taxonomy->name, $removable_taxonomy_array)) {
                unset($taxonomies[$taxonomy->name]);
            }
        }
        return apply_filters('ualp_taxonomies',$taxonomies);
    }
}

/*
 * get all keys contain serialized array of post id
 */
if(!function_exists('ualpGetSerializedPostArray')) {
    function ualpGetSerializedPostArray() {
        $serialized_array = array('_upsell_ids','_crosssell_ids','product_ids','exclude_product_ids','_edd_discount_product_reqs','_edd_discount_excluded_products');
        $serialized_array = apply_filters('ualp_post_serialized_array',$serialized_array);
        return $serialized_array;
    }
}

/*
 * get all keys contain serialized array of Cat ids
 */
if(!function_exists('ualpGetSerializedCatArray')) {
    function ualpGetSerializedCatArray() {
        $serialized_array = array('product_categories'=>'product_cat','exclude_product_categories'=>'product_cat');
        $serialized_array = apply_filters('ualp_cat_serialized_array',$serialized_array);
        return $serialized_array;
    }
}

/*
 * get all keys contain serialized array of data
 */
if(!function_exists('ualpGetSerializedDataArray')) {
    function ualpGetSerializedDataArray() {
        $serialized_array = array('wp_capabilities', 'customer_email', 'field_', 'edd_variable_prices', 'edd_download_files');
        $serialized_array = apply_filters('ualp_data_serialized_array',$serialized_array);
        return $serialized_array;
    }
}

/*
 * function to unserialoze content in loop
 */
if(!function_exists('ualpserializeloop')) {
    function ualpserializeloop($in_array,$in_key='', $n_value = '', $j = 0) {
        if(is_array($in_array) && !empty($in_array)) {
            foreach($in_array as $in_key => $in_value) {
                if($in_key !== '' && $in_key !== 'key' && $in_key !== 'field') {
                    if($j != 0) {
                        $n_value .= ', ';
                    }
                    if(!is_numeric($in_key)) {
                        $n_value .= $in_key.' : ';
                    }
                    $j++;
                    $n_value .= ualpserializeloop($in_value,$in_key,'',$j);
                }
            }
        }
        else {
            if($in_key !== '' && $in_key !== 'key') {
                $n_value .= $in_array;
            }
        }
        return $n_value;
    }
}

/*
 * function to get all primary data key of post
 */
if(!function_exists('ualpGetPrimaryPostData')) {
    function ualpGetPrimaryPostData($post_type = '') {
        $get_dafault_post_key_array = array("post_title","post_name","post_content","post_status","menu_order","post_date","post_date_gmt","post_excerpt","comment_status","ping_status","post_parent","post_author");
        return apply_filters('ualp_post_primary_array',$get_dafault_post_key_array,$post_type);
    }
}

/*
 * function to get all meta key of post
 */
if(!function_exists('ualpGetPostMetaData')) {
    function ualpGetPostMetaData($post_type = '') {
        $get_default_metakey_array = array("_thumbnail_id","_product_attributes","_product_image_gallery","_manage_stock","_stock_status","_stock","_backorders","_price","_regular_price","_sale_price","_sale_price_dates_from","_sale_price_dates_to","_sold_individually","_upsell_ids","_crosssell_ids","_tax_status","_tax_class",
            "_weight","_length","_width","_height","_sku","_featured","_purchase_note","_virtual","_downloadable","_visibility",
            "discount_type","coupon_amount","individual_use","product_ids","exclude_product_ids","usage_limit","usage_limit_per_user","limit_usage_to_x_items","expiry_date","free_shipping","exclude_sale_items","product_categories","exclude_product_categories","minimum_amount","maximum_amount","customer_email",
            "position","layout","hide_on_screen","rule","field_",
            "_edd_download_earnings",'_edd_download_sales','edd_price','edd_variable_prices','edd_download_files','_edd_bundled_products','_edd_bundled_products_conditions','_variable_pricing','_edd_default_price_id','_edd_hide_purchase_link','_edd_download_limit',
            "code"=>"_edd_discount_code",'name'=>'_edd_discount_name','status'=>'_edd_discount_status','max'=>'_edd_discount_max_uses','amount'=>'_edd_discount_amount','start'=>'_edd_discount_start','expiration'=>'_edd_discount_expiration','type'=>'_edd_discount_type','min_price'=>'_edd_discount_min_price','products'=>'_edd_discount_product_reqs','product_condition'=>'_edd_discount_product_condition','excluded-products'=>'_edd_discount_excluded_products','not_global'=>'_edd_discount_is_not_global','use_once'=>'_edd_discount_is_single_use',
            '_wc_file_names' => '_downloadable_files');
        return apply_filters('ualp_post_meta_array',$get_default_metakey_array,$post_type);
    }
}

/*
 * function to get all user fields
 */
if(!function_exists('ualpGetUserPrimaryData')) {
    function ualpGetUserPrimaryData() {
        $user_primary_key_array = array('email'=>'user_email','url'=>'user_url','display_name');
        return apply_filters('ualp_user_primary_array',$user_primary_key_array);
    }
}

/*
 * function to get all user fields
 */
if(!function_exists('ualpGetUserMetaData')) {
    function ualpGetUserMetaData() {
        $user_meta_key_array = array('nickname','first_name','last_name','description','rich_editing','admin_color','admin_bar_front'=>'show_admin_bar_front',
            'billing_first_name','billing_last_name','billing_company','billing_address_1','billing_address_2','billing_city','billing_postcode','billing_country','billing_state','billing_phone','billing_email','shipping_first_name','shipping_last_name','shipping_company','shipping_address_1','shipping_address_2','shipping_city','shipping_postcode','shipping_country','shipping_state','googleplus','facebook','twitter','linkedin');
        return apply_filters('ualp_user_meta_array',$user_meta_key_array);
    }
}

/*
 * function for add loader
 */
if(!function_exists('ualploader')) {
    function ualploader() { ?>
        <div class="loader">
            <span class="rotating"></span>
        </div><?php
    }
}

add_action('admin_head','ualploader');

/*
 * function to get all whitelist options
 */

if(!function_exists('ualpGetOptions')) {
    function ualpGetOptions() {
        $ualp_options_array = array(
            // General
            'blogname',
            'blogdescription',
            'siteurl',
            'home',
            'admin_email',
            'users_can_register',
            'default_role',
            'timezone_string',
            'date_format',
            'time_format',
            'start_of_week',
            'gmt_offset',
            'WPLANG',
            'new_admin_email',
            // Writing
            'use_smilies',
            'use_balanceTags',
            'default_category',
            'default_post_format',
            'mailserver_url',
            'mailserver_login',
            'mailserver_pass',
            'mailserver_port',
            'default_email_category',
            'default_link_category',
            'ping_sites',
            // Reading
            'show_on_front',
            'page_on_front',
            'page_for_posts',
            'posts_per_page',
            'posts_per_rss',
            'rss_use_excerpt',
            'blog_public',
            // Discussion
            'default_pingback_flag',
            'default_ping_status',
            'default_comment_status',
            'require_name_email',
            'comment_registration',
            'close_comments_for_old_posts',
            'close_comments_days_old',
            'thread_comments',
            'thread_comments_depth',
            'page_comments',
            'comments_per_page',
            'default_comments_page',
            'comment_order',
            'comments_notify',
            'moderation_notify',
            'comment_moderation',
            'comment_whitelist',
            'comment_max_links',
            'moderation_keys',
            'blacklist_keys',
            'show_avatars',
            'avatar_rating',
            'avatar_default',
            // Media
            'thumbnail_size_w',
            'thumbnail_size_h',
            'thumbnail_crop',
            'medium_size_w',
            'medium_size_h',
            'large_size_w',
            'large_size_h',
            'uploads_use_yearmonth_folders',
            // Network
            'registrationnotification',
            'registration',
            'add_new_users',
            'menu_items',
            'upload_space_check_disabled',
            'blog_upload_space',
            'upload_filetypes',
            'site_name',
            'first_post',
            'first_page',
            'first_comment',
            'first_comment_url',
            'first_comment_author',
            'welcome_email',
            'welcome_user_email',
            'fileupload_maxk',
            'global_terms_enabled',
            'illegal_names',
            'limited_email_domains',
            'banned_email_domains',
            'blog_count',
            'user_count',
            //permalink
            'woocommerce_permalinks',
            'permalink_structure',
            'category_base',
            'tag_base'
        );
        return apply_filters('ualp_options_array',$ualp_options_array);
    }
}

/*
 * permalink array
 */
if(!function_exists('ualpPermalinks')) {
    function ualpPermalinks() {
        $permalink_array = apply_filters('ualp_permalink_array',array('woocommerce_permalinks','permalink_structure','category_base','tag_base'));
        return $permalink_array;
    }
}

/**
 * Add Admin Dashboard Widget - Latest User Activity Logs
 */
if (!function_exists('ualpLatestActivityLogs')) {

    function ualpLatestActivityLogs() {
        // Register the new dashboard widget with the 'wp_dashboard_setup' action
        add_action('wp_dashboard_setup', 'ualpLatestLogs');
        if (!function_exists('ualpLatestLogs')) {

            function ualpLatestLogs() {
                add_screen_option('layout_columns', array('max' => 3, 'default' => 2));
                add_meta_box('ualp_dashboard_widget', esc_html__('Latest User Activity Logs', 'user_activity_log_pro'), 'ualpDashboardWidget', 'dashboard', 'normal', 'high');
            }

        }
        if (!function_exists('ualpDashboardWidget')) {

            function ualpDashboardWidget() {
                ?>
                <ul class="ualp_log_table">
                    <li>
                        <span class="ualp-column-date"><b><?php esc_html_e('Date', 'user_activity_log_pro'); ?></b></span>
                        <span class="ualp-column-author"><b><?php esc_html_e('Author', 'user_activity_log_pro'); ?></b></span>
                        <span class="ualp-column-activity"><b><?php esc_html_e('Activity', 'user_activity_log_pro'); ?></b></span>
                    </li>
                    <?php
                    global $wpdb, $externaldb;
                    $select_query = "SELECT * from ".UALP_TABLENAME." ORDER BY modified_date desc LIMIT 5";
                    $get_data = $externaldb->get_results($select_query);
                    if ($get_data) {
                        $srno = 1;
                        foreach ($get_data as $data) {
                            ?>
                            <li>
                                <span class="ualp-column-date"><?php
                                    $modified_date = strtotime($data->modified_date);
                                    $date_format = get_option('date_format');
                                    $time_format = get_option('time_format');
                                    $date = date($date_format, $modified_date);
                                    $time = date($time_format, $modified_date);
                                    echo $date."<br/>".$time."<br/>";
                                    $current_t = current_time( 'timestamp' );
                                    $t_diff = human_time_diff( $modified_date, $current_t );
                                    echo '<b>'. $t_diff .' '. esc_html__('ago','user_activity_log_pro'). '</b>'
                                    ?>
                                </span>
                                <span class="ualp-column-author column-author"><?php
                                    global $wp_roles;
                                    if (!empty($data->user_id) && 0 !== (int) $data->user_id) {
                                        $user = get_user_by('id', $data->user_id);
                                        if ($user instanceof WP_User && 0 !== $user->ID) {
                                            printf(
                                                    '<a href="%s">%s <span class="author-name">%s</span></a><br /><small>%s</small><br/>%s',
                                                    get_edit_user_link($user->ID),
                                                    get_avatar($user->ID, 40),
                                                    ucfirst($user->display_name),
                                                    isset($user->roles[0]) &&
                                                    isset($wp_roles->role_names[$user->roles[0]]) ? $wp_roles->role_names[$user->roles[0]] : esc_html__('Guest', 'user_activity_log_pro'),
                                                    $user->user_email
                                            );
                                        }
                                    }else{
                                        esc_html_e('Guest', 'user_activity_log_pro');
                                    }
                                    ?>
                                </span>
                                <span class="ualp-column-activity">
                                    <?php
                                    if($data->object_type == 'Page' && $data->action == 'Viewed'){
                                        echo ucfirst($data->object_type) .' '. ucfirst($data->action) .' : '. $data->post_title;
                                    } else {
                                        echo ucfirst($data->object_type) .' '. ucfirst($data->action) .' : '. ucfirst($data->post_title);
                                    }
                                    ?>
                                </span>
                            </li>
                            <?php
                        }
                        echo '<li>';
                        echo '<p><a href="'.admin_url('admin.php?page=ual_pro').'" target="_blank" class="button button-default">'.__('Read More','user_activity_log_pro').' →</a></p>';
                        echo '</li>';
                    } else {
                        echo '<li>';
                        echo '<div>' . esc_html__('No Activity found.', 'user_activity_log_pro') . '</div>';
                        echo '</li>';
                    }
                    ?>

                </ul>
                <?php
            }

        }
    }

}
add_action('plugins_loaded', 'ualpLatestActivityLogs');

add_action('admin_head','ualpCreateUploadFolder');

if(!function_exists('ualpCreateUploadFolder')){
    function ualpCreateUploadFolder(){
        if (!is_dir(WP_CONTENT_DIR.'/uploads')) {
            mkdir(WP_CONTENT_DIR.'/uploads');
        }
    }
}

if(!function_exists('ualpExternal')) {
    function ualpExternal() {
        global $wpdb,$externaldb;

        $dbuser = $dbpassword = $dbname = $dbhost = $tableprefix = '';
        $externaldb     = $wpdb;
        $tableprefix    = get_option('table_prefix');
        $dbuser         = get_option('database_username');
        $dbpassword     = get_option('database_password');
        $dbname         = get_option('database_name');
        $dbhost         = get_option('database_hostname');

        /**
         * @param string $dbuser     MySQL database user
         * @param string $dbpassword MySQL database password
         * @param string $dbname     MySQL database name
         * @param string $dbhost     MySQL database host
         */

        if((isset($dbuser) && $dbuser != '') && (isset($dbpassword)) && (isset($dbname) && $dbname != '') && (isset($dbhost) && $dbhost != '')){
            $externaldb = new wpdb($dbuser,$dbpassword,$dbname,$dbhost);

            $plugin_data = get_plugin_data(WP_PLUGIN_DIR . '/user-activity-log-pro/user_activity_log_pro.php', $markup = true, $translate = true);
            $current_version = $plugin_data['Version'];
            ualpCreateTable();
            ualpCreateDetailTable();
            ualpCreateExternalTable();
            ualpCreateDetailExternalTable();
            update_option('ualp_version',$current_version);

        }
        return $externaldb;
    }
}

if(!function_exists('ualpMigrateCurrentToExternal')){
    function ualpMigrateCurrentToExternal(){
        global $externaldb,$wpdb;
        $tableprefix    = '';
        $tableprefix    = get_option('table_prefix');
        $dbuser         = get_option('database_username');
        $dbpassword     = get_option('database_password');
        $dbname         = get_option('database_name');
        $dbhost         = get_option('database_hostname');

        if((isset($dbuser) && $dbuser != '') && (isset($dbpassword)) && (isset($dbname) && $dbname != '') && (isset($dbhost) && $dbhost != '')){
            $results = $wpdb->get_results( 'SELECT * FROM '.$wpdb->prefix.'ualp_user_activity', OBJECT );

            foreach($results as $single_result) {
                $uactid = $single_result->uactid;
                $post_id = $single_result->post_id;
                $favorite = $single_result->favorite;
                $post_title = $single_result->post_title;
                $user_id = $single_result->user_id;
                $user_name = $single_result->user_name;
                $user_role = $single_result->user_role;
                $user_email = $single_result->user_email;
                $ip_address = $single_result->ip_address;
                $user_agent = $single_result->user_agent;
                $country = $single_result->country;
                $modified_date = $single_result->modified_date;
                $object_type = $single_result->object_type;
                $action = $single_result->action;
                $hook = $single_result->hook;
                $description = $single_result->description;

                ualpCreateTable();
                ualpCreateDetailTable();
                ualpCreateExternalTable();
                ualpCreateDetailExternalTable();

                $insert_query = $externaldb->insert(
                    UALP_TABLENAME,
                    array(
                        'post_id' => $post_id,
                        'favorite' => '0',
                        'post_title' => $post_title,
                        'user_id' => $user_id,
                        'user_name' => $user_name,
                        'user_role' => $user_role,
                        'user_email' => $user_email,
                        'ip_address' => $ip_address,
                        'user_agent' => $user_agent,
                        'country' => $country,
                        'modified_date' => $modified_date,
                        'object_type' => $object_type,
                        'action' => $action,
                        'hook' => $hook,
                        'description' => $description
                    )
                );

            }

            $detail_results = $wpdb->get_results( 'SELECT * FROM '.$wpdb->prefix.'ualp_user_activity_detail', OBJECT );

            foreach($detail_results as $single_result){
                $uactd_id = $single_result->uactd_id;
                $uactid = $single_result->uactid;
                $uactd_key = $single_result->uactd_key;
                $uactd_value = $single_result->uactd_value;

                $externaldb->insert(
                    $tableprefix.'ualp_user_activity_detail',
                    array(
                        'uactd_id' => '',
                        'uactid' => $uactid,
                        'uactd_key' => $uactd_key,
                        'uactd_value' => $uactd_value
                    )
                );
            }
        }
    }
}

if(!function_exists('ualpMigrateExternalToCurrent')){
    function ualpMigrateExternalToCurrent(){
        global $externaldb,$wpdb;
        $tableprefix    = '';
        $tableprefix    = get_option('table_prefix');
        $dbuser         = get_option('database_username');
        $dbpassword     = get_option('database_password');
        $dbname         = get_option('database_name');
        $dbhost         = get_option('database_hostname');

        if((isset($dbuser) && $dbuser != '') && (isset($dbpassword)) && (isset($dbname) && $dbname != '') && (isset($dbhost) && $dbhost != '')){
            $results = $externaldb->get_results( 'SELECT * FROM '.$tableprefix.'ualp_user_activity', OBJECT );

            foreach($results as $single_result) {
                $uactid = $single_result->uactid;
                $post_id = $single_result->post_id;
                $favorite = $single_result->favorite;
                $post_title = $single_result->post_title;
                $user_id = $single_result->user_id;
                $user_name = $single_result->user_name;
                $user_role = $single_result->user_role;
                $user_email = $single_result->user_email;
                $ip_address = $single_result->ip_address;
                $user_agent = $single_result->user_agent;
                $country = $single_result->country;
                $modified_date = $single_result->modified_date;
                $object_type = $single_result->object_type;
                $action = $single_result->action;
                $hook = $single_result->hook;
                $description = $single_result->description;

                ualpCreateTable();
                ualpCreateDetailTable();
                ualpCreateExternalTable();
                ualpCreateDetailExternalTable();

                $wpdb->insert(
                    $wpdb->prefix.'ualp_user_activity',
                    array(
                        'uactid' => '',
                        'post_id' => $post_id,
                        'favorite' => $favorite,
                        'post_title' => $post_title,
                        'user_id' => $user_id,
                        'user_name' => $user_name,
                        'user_role' => $user_role,
                        'user_email' => $user_email,
                        'ip_address' => $ip_address,
                        'user_agent' => $user_agent,
                        'country' => $country,
                        'modified_date' => $modified_date,
                        'object_type' => $object_type,
                        'action' => $action,
                        'hook' => $hook,
                        'description' => $description
                    ),
                    array(
                        '%s',
                        '%s',
                        '%s',
                        '%s',
                        '%s',
                        '%s',
                        '%s',
                        '%s',
                        '%s',
                        '%s',
                        '%s',
                        '%s',
                        '%s',
                        '%s',
                        '%s'
                    )
                );
            }

            $detail_results = $externaldb->get_results( 'SELECT * FROM '.$tableprefix.'ualp_user_activity_detail', OBJECT );

            foreach($detail_results as $single_result){
                $uactd_id = $single_result->uactd_id;
                $uactid = $single_result->uactid;
                $uactd_key = $single_result->uactd_key;
                $uactd_value = $single_result->uactd_value;

                $wpdb->insert(
                    $wpdb->prefix.'ualp_user_activity_detail',
                    array(
                        'uactd_id' => '',
                        'uactid' => $uactid,
                        'uactd_key' => $uactd_key,
                        'uactd_value' => $uactd_value
                    )
                );
            }
        }
    }
}

/*
 * Function to check if Ipaddress is allowed
 */
if(!function_exists('ualpAllowIp')) {
    function ualpAllowIp() {
        $ualpAllowIp = get_option('ualpAllowIp');
        if($ualpAllowIp == 1) {
            return true;
        }
        return false;
    }
}

/*
 * Function to check if Country is allowed
 */
if(!function_exists('ualpAllowCountry')) {
    function ualpAllowCountry() {
        $ualpAllowCountry = get_option('ualpAllowCountry');
        if($ualpAllowCountry == 1) {
            return true;
        }
        return false;
    }
}

/*
 * Function to check if User Agent is allowed
 */
if(!function_exists('ualpAllowUserAgent')) {
    function ualpAllowUserAgent() {
        $ualpAllowUserAgent = get_option('ualpAllowUserAgent');
        if($ualpAllowUserAgent == 1) {
            return true;
        }
        return false;
    }
}

/*
 * Function to get current session Token
 */

if(!function_exists('ualpGetCurrentToken')) {
    function ualpGetCurrentToken($token = '') {
        if($token == '') {
            $token = wp_get_session_token();
        }
        if ( function_exists( 'hash' ) ) {
                return hash( 'sha256', $token );
        } else {
                return sha1( $token );
        }
    }
}