<?php
/*
 * Exit if accessed directly
 */
if (!defined('ABSPATH')) {
    exit;
}


/**
 * Get setting from database from shortcode id
 * @param int $shortcode_id
 * @global object $wpdb
 * @return string Shortcode name
 */
if (!function_exists('ualp_get_blog_layout_name')) {

    function ualp_get_blog_layout_name($shortcode_id) {
        global $wpdb;
        $tableName = $wpdb->prefix . 'blog_designer_pro_shortcodes';
        $get_settings_query = "SELECT * FROM $tableName WHERE bdid = " . $shortcode_id;
        $settings_val = $wpdb->get_results($get_settings_query, ARRAY_A);
        if (!$settings_val) {
            return;
        }
        foreach ($settings_val as $settings){
            return $settings['shortcode_name'];
        }
        return false;
    }

}

/**
 * Get Archive layout name from database from shortcode id
 * @param int $shortcode_id
 * @global object $wpdb
 * @return string Archive name
 */
if (!function_exists('ualp_get_archive_layout_name')) {

    function ualp_get_archive_layout_name($shortcode_id) {
        global $wpdb;
        $tableName = $wpdb->prefix . 'bdp_archives';
        $get_settings_query = "SELECT archive_name FROM $tableName WHERE id = " . $shortcode_id;
        $settings_val = $wpdb->get_results($get_settings_query, ARRAY_A);
        if (!$settings_val) {
            return;
        }
        foreach ($settings_val as $settings){
            return $settings['archive_name'];
        }
        return false;
    }

}

/**
 * Get Single layout name from database from shortcode id
 * @param int $shortcode_id
 * @global object $wpdb
 * @return string Single name
 */
if (!function_exists('ualp_get_single_layout_name')) {

    function ualp_get_single_layout_name($shortcode_id) {
        global $wpdb;
        $tableName = $wpdb->prefix . 'bdp_single_layouts';
        $get_settings_query = "SELECT single_name FROM $tableName WHERE id = " . $shortcode_id;

        $settings_val = $wpdb->get_results($get_settings_query, ARRAY_A);

        if (!$settings_val) {
            return;
        }
        foreach ($settings_val as $settings){
            return $settings['single_name'];
        }
        return false;
    }

}

/**
 * Get activity for blog layout shortcode update
 *
 * @param int $shortcode_ID
 */
if (!function_exists('ualpHookBDPUpdateShortcode')){

    function ualpHookBDPUpdateShortcode($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Blog Layout Updated";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_blog_layout_name($shortcode_ID);
            $hook = "bdp_update_shortcode";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_update_shortcode', 'ualpHookBDPUpdateShortcode',10,1);

/**
 * Get activity for blog layout shortcode reset
 *
 * @param int $shortcode_ID
 */
if (!function_exists('ualpHookBDPResetShortcode')){

    function ualpHookBDPResetShortcode($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Blog Layout Reset";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_blog_layout_name($shortcode_ID);
            $hook = "bdp_reset_shortcode";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_reset_shortcode', 'ualpHookBDPResetShortcode',10,1);

/**
 * Get activity for blog layout shortcode reset
 *
 * @param int $shortcode_ID
 */
if (!function_exists('ualpHookBDPResetArchiveLayout')){

    function ualpHookBDPResetArchiveLayout($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Archive Layout Reset";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_archive_layout_name($shortcode_ID);
            $hook = "bdp_reset_archive_page";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_reset_archive_page', 'ualpHookBDPResetArchiveLayout',10,1);

/**
 * Get activity for add blog shortcode
 *
 * @param int $shortcode_ID
 */
if (!function_exists('ualpHookBDPAddShortcode')){

    function ualpHookBDPAddShortcode($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Blog Layout Created";
            $obj_type = "Blog Designer Pro";
            $post_id = $shortcode_ID;
            $post_title = ualp_get_blog_layout_name($shortcode_ID);
            $hook = "bdp_add_shortcode";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_add_shortcode', 'ualpHookBDPAddShortcode');

/**
 * Get activity for Single file update
 *
 */
if (!function_exists('ualpHookBDPUpdateSingleFile')){

    function ualpHookBDPUpdateSingleFile() {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "updated in theme";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = "Single template file";
            $hook = "bdp_update_single_file";
            $description = "$obj_type : $post_title $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_update_single_file', 'ualpHookBDPUpdateSingleFile');

/**
 * Get activity for add archive layout
 *
 * @param int $shortcode_ID
 */
if (!function_exists('ualpHookBDPAddArchiveLayout')){

    function ualpHookBDPAddArchiveLayout($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Archive Layout Created";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_archive_layout_name($shortcode_ID);
            $hook = "bdp_add_archive_layout";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_add_archive_layout', 'ualpHookBDPAddArchiveLayout');

/**
 * Get activity for delete shortcode
 *
 * @param int $shortcode_ID
 */
if (!function_exists('ualpHookBDPDeleteShortcode')){

    function ualpHookBDPDeleteShortcode($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Blog Layout Deleted";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_blog_layout_name($shortcode_ID);
            $hook = "bdp_delete_shortcode";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_delete_shortcode', 'ualpHookBDPDeleteShortcode');

/**
 * Get activity for delete single template
 *
 */
if (!function_exists('ualpHookBDPDeleteSingleTemplate')){

    function ualpHookBDPDeleteSingleTemplate() {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "deleted from theme";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = "Single template file";
            $hook = "bdp_delete_single_template";
            $description = "$obj_type : $post_title $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_delete_single_template', 'ualpHookBDPDeleteSingleTemplate');

/**
 * Get activity for copy single template
 *
 */
if (!function_exists('ualpHookBDPCopySingleTemplate')){

    function ualpHookBDPCopySingleTemplate() {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "created in theme";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = "Single template file";
            $hook = "bdp_copy_single_template";
            $description = "$obj_type : $post_title $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_copy_single_template', 'ualpHookBDPCopySingleTemplate');

/**
 * Get activity for duplicate layout
 *
 * @param int $shortcode_ID
 */
if (!function_exists('ualpHookBDPDuplicateLayout')){

    function ualpHookBDPDuplicateLayout($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Blog Layout Duplicated";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_blog_layout_name($shortcode_ID);
            $hook = "bdp_duplicate_layout_settings";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_duplicate_layout_settings', 'ualpHookBDPDuplicateLayout');

/**
 * Get activity for import blog layout
 *
 * @param string $shortcode_name shortcode name
 */
if (!function_exists('ualpHookBDPImportBlogLayout')){

    function ualpHookBDPImportBlogLayout($shortcode_name) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Blog Layout Imported";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = $shortcode_name;
            $hook = "bdp_import_blog_layout_settings";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_import_blog_layout_settings', 'ualpHookBDPImportBlogLayout');

/**
 * Get activity for import archive layout
 *
 * @param string $archive_name Archive Layout Name
 */
if (!function_exists('ualpHookBDPImportArchiveLayout')){

    function ualpHookBDPImportArchiveLayout($archive_name) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Archive Layout Imported";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_archive_layout_name($archive_id);
            $hook = "$archive_name";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_import_archive_layout_settings', 'ualpHookBDPImportArchiveLayout');

/**
 * Get activity for export archive layout
 *
 * @param int $archive_id Archive Layout ID
 */
if (!function_exists('ualpHookBDPExportArchiveLayout')){

    function ualpHookBDPExportArchiveLayout($archive_id) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Archive Layout Exported";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_archive_layout_name($archive_id);
            $hook = "bdp_export_archive_layout_settings";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_export_archive_layout_settings', 'ualpHookBDPExportArchiveLayout');

/**
 * Get activity for export blog layout
 *
 * @param int $layout_id Layout Id
 */
if (!function_exists('ualpHookBDPExportBlogLayout')){

    function ualpHookBDPExportBlogLayout($layout_id) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Blog Layout Exported";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_blog_layout_name($layout_id);
            $hook = "bdp_export_blog_layout_settings";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_export_blog_layout_settings', 'ualpHookBDPExportBlogLayout');

/**
 * Get activity for update archive layout
 *
 * @param int $shortcode_ID
 */
if (!function_exists('ualpHookBDPUpdateArchivePage')){

    function ualpHookBDPUpdateArchivePage($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Archive Layout Updated";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_archive_layout_name($shortcode_ID);
            $hook = "bdp_update_archive_page";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_update_archive_page', 'ualpHookBDPUpdateArchivePage');

/**
 * Get activity for update single page design
 *
 */
if (!function_exists('ualpHookBDPUpdateSinglePost')){

    function ualpHookBDPUpdateSinglePost() {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Update";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = "Single post updated";
            $hook = "bdp_update_single_post";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_update_single_post', 'ualpHookBDPUpdateSinglePost'); // remove

/**
 * Get activity for import file
 *
 * @param string $single_layout_name Layout name
 */
if (!function_exists('ualpHookBDPImportSingleLayout')){

    function ualpHookBDPImportSingleLayout($single_layout_name) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Single layout Imported";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = $single_layout_name;
            $hook = "bdp_import_single_layout_settings";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_import_single_layout_settings', 'ualpHookBDPImportSingleLayout');

/**
 * Get activity for export file
 *
 * @param int $single_layout_ids Layout ID
 */
if (!function_exists('ualpHookBDPExportSingleLayout')){

    function ualpHookBDPExportSingleLayout($single_layout_ids) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Single Layout Exported";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_single_layout_name($single_layout_ids);
            $hook = "bdp_export_single_layout_settings";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_export_single_layout_settings', 'ualpHookBDPExportSingleLayout');

/**
 * Get activity for delete archive
 *
 * @param int $archive Archive layout id
 */
if (!function_exists('ualpHookBDPDeleteArchiveLayouts')){

    function ualpHookBDPDeleteArchiveLayouts($archive) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Archive layout deleted";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_archive_layout_name($archive);
            $hook = "bdp_delete_archive";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_delete_archive', 'ualpHookBDPDeleteArchiveLayouts');


/**
 * Get activity for delete single layout
 *
 * @paramn int $shortcode_ID Shortcode ID
 */
if (!function_exists('ualpHookBDPDeleteSingleLayout')){

    function ualpHookBDPDeleteSingleLayout($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Single Layout Deleted";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_single_layout_name($shortcode_ID);
            $hook = "bdp_delete_single_layout";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_delete_single_layout', 'ualpHookBDPDeleteSingleLayout');


/**
 * Get activity for update single page
 *
 * @paramn int $shortcode_ID Shortcode ID
 */
if (!function_exists('ualpHookBDPUpdateSingleLayout')){

    function ualpHookBDPUpdateSingleLayout($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Single Layout Updated";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_single_layout_name($shortcode_ID);
            $hook = "bdp_update_single_page";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_update_single_page', 'ualpHookBDPUpdateSingleLayout');

/**
 * Get activity for reset single page
 *
 * @paramn int $shortcode_ID Shortcode ID
 */
if (!function_exists('ualpHookBDPResetSingleLayout')){

    function ualpHookBDPResetSingleLayout($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Single Layout Reset";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_single_layout_name($shortcode_ID);
            $hook = "bdp_reset_single_page";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_reset_single_page', 'ualpHookBDPResetSingleLayout');

/**
 * Get activity for add single layout
 *
 * @paramn int $shortcode_ID Shortcode ID
 */
if (!function_exists('ualpHookBDPAddSingleLayout')){

    function ualpHookBDPAddSingleLayout($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Single Layout Created";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_single_layout_name($shortcode_ID);
            $hook = "bdp_add_single_layout";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_add_single_layout', 'ualpHookBDPAddSingleLayout');

/**
 * Get activity for duplicate single layout
 *
 * @paramn int $shortcode_ID Shortcode ID
 */
if (!function_exists('ualpHookBDPDuplicateSingleLayout')){

    function ualpHookBDPDuplicateSingleLayout($shortcode_ID) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('blog_designer',$logHookList)) {
            $action = "Single Layout Duplicated";
            $obj_type = "Blog Designer Pro";
            $post_id = "";
            $post_title = ualp_get_single_layout_name($shortcode_ID);
            $hook = "bdp_duplicate_single_layout_settings";
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('bdp_duplicate_single_layout_settings', 'ualpHookBDPDuplicateSingleLayout');
