<?php

/*
 * Exit if accessed directly
 */
if (!defined('ABSPATH')) {
    exit;
}

/*
 * Get activity for the user - Activate Discount code
 *
 * @param array $data dicount data
 */
if (!function_exists('ualpHookActivateDiscountCode')) {

    function ualpHookActivateDiscountCode($data) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('edd_discount', $logHookList)) {
            $action = "Activate";
            $obj_type = "edd_discount";
            $post_id = absint( $data['discount'] );
            $post_title = get_the_title($post_id);
            $hook = "edd_activate_discount";
            $description = "$obj_type $action : $post_title";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }

}

add_action('edd_activate_discount', 'ualpHookActivateDiscountCode'); // new

/*
 * Get activity for the user - Deactivate Discount code
 *
 * @param array $data dicount data
 */
if (!function_exists('ualpHookDeactivateDiscountCode')) {

    function ualpHookDeactivateDiscountCode($data) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('edd_discount', $logHookList)) {
            $action = "Deactivate";
            $obj_type = "edd_discount";
            $post_id = absint( $data['discount'] );
            $post_title = get_the_title($post_id);
            $hook = "edd_deactivate_discount";
            $description = "$obj_type $action : $post_title";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }

}

add_action('edd_deactivate_discount', 'ualpHookDeactivateDiscountCode'); // new

/*
 * Get activity for the user - Add Discount
 *
 * @param array $data dicount data
 */
if (!function_exists('ualpHookAddDiscountCode')) {

    function ualpHookAddDiscountCode($data) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('edd_discount', $logHookList)) {
            $action = "Added";
            $obj_type = "edd_discount";
            $post_id = $data['discount'];
            $post_title = "Add Discount Code";
            $hook = "edd_add_discount";
            $description = "$obj_type : $post_title";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }

}

add_action('edd_add_discount', 'ualpHookAddDiscountCode'); // new


/*
 * Get activity for the user - Delete Discount
 *
 * @param array $data dicount data
 */
if (!function_exists('ualpHookDeleteDiscountCode')) {

    function ualpHookDeleteDiscountCode($data) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('edd_discount', $logHookList)) {
            $action = "Deleted";
            $obj_type = "edd_discount";
            $post_id = $data['discount'];
            $post_title = "Discount Code Deleted";
            $hook = "edd_delete_discount";
            $description = "$obj_type : $post_title";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }

}

add_action('edd_delete_discount', 'ualpHookDeleteDiscountCode'); // new

/*
 * Get activity for the user - Edit Discount
 */
if(!function_exists('ualpHookEditDiscount')) {
    function ualpHookEditDiscount() {
        if ( ! empty( $_POST['discount-id'] ) ) {
            $post_ID = isset( $_POST['discount-id'] ) ? (int) $_POST['discount-id'] : 0;
            if (!$post_ID) {
                return;
            }
            if (!current_user_can('edit_post',$post_ID)) {
                return;
            };
            $old_post_data = array(
                "post_data" => '',
                "post_meta" => get_post_custom($post_ID),
                "post_tax" => ''
            );
            $post_meta_data = ualpGetPostMetaData('discount');
            $new_post_meta = '';
            foreach($post_meta_data as $post_meta_key=>$post_meta_value) {
                if(!is_numeric($post_meta_key)) {
                    if(isset($_POST[$post_meta_key])) {
                        $meta_key_value = maybe_serialize($_POST[$post_meta_key]);
                        $new_post_meta[$post_meta_value][0] = sanitize_text_field($meta_key_value);
                    }
                }
                else {
                    if(isset($_POST[$post_meta_value])) {
                        $meta_key_value = maybe_serialize($_POST[$post_meta_value]);
                        $new_post_meta[$post_meta_value][0] = sanitize_text_field($meta_key_value);
                    }
                }
            }
            $new_post_data = array(
                "post_data" => '',
                "post_meta" => $new_post_meta,
                "post_tax" => ''
            );
            if (in_array('edd_discount', $logHookList)) {
                $action = 'updated';
                $obj_type = 'edd_discount';
                $hook = "transition_post_status";
                $post_title = sanitize_text_field($_POST['name']);
                $page_link = get_edit_post_link($post_id);
                if($page_link == ''){
                    $page_link = get_the_permalink($post_id);
                }
                $description = "$obj_type $action : <a target='blank' href='". $page_link."'>$post_title</a>";
                $uactid = ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
                ualpAddActivityLogDetailPostUpdate($uactid,$old_post_data,$new_post_data,$obj_type);
            }
        }
    }
}
add_action('init','ualpHookEditDiscount');

/*
 * Get activity for the user - update options
 *
 * @param string $option option name
 * @param string $oldvalue Old Option Value
 * @param string $option New Option Value
 */
if(!function_exists('ualpHookEddOption')) {
    function ualpHookEddOption($option, $oldvalue, $_newvalue) {
        if($option != 'edd_settings' && $option != 'edd_tax_rates') {
            return;
        }
        $logHookList = get_option('enableLogHookList');
        if (in_array('edd_settings',$logHookList)) {
            $action = "updated";
            $obj_type = "Settings";
            $post_id = "";
            $post_title = $option;
            $hook = "updated_option";
            $description = "$obj_type $action : $post_title";
            $uactid = ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
            ualpAddWordPressSettingsLogDetail($uactid,$oldvalue,$_newvalue,$obj_type,$option);
        }
    }
}
add_action('updated_option','ualpHookEddOption',10,3);