<?php
/**
 * Exit if accessed directly
 */
if (!defined('ABSPATH')) {
    exit;
}
/**
 * Fires once the admin request has been validated or not.
 *
 * @param string    $action The nonce action.
 * @param false|int $result False if the nonce is invalid,
 *                  1 if the nonce is valid and generated between 0-12 hours ago,
 *                  2 if the nonce is valid and generated between 12-24 hours ago.
 */
if (!function_exists('ualpHookGformsSaveEntry')){

    function ualpHookGformsSaveEntry($action_type,$result) {
        $obj_type = 'Gravity Form';
        $post_id = '';
        $hook = $action_type;
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            if( $action_type == 'gf_export_forms' ) {
                $action = 'Form exported';
                if ( isset( $_POST['export_forms'] ) ) {
                    $selected_forms = rgpost( 'gf_form_id' );
                    if(is_array($selected_forms)){
                        foreach ($selected_forms as $selected_form){
                            $form = GFFormsModel::get_form_meta( $selected_form );
                            $post_title = $form['title'];
                            $description = "$obj_type : '$post_title' $action";
                            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
                        }
                    }
                }
            }
        }
    }
}

add_action('check_admin_referer', 'ualpHookGformsSaveEntry', 10, 2);

/**
 * Fires once Notification duplicated.
 *
 * @param string    $action The nonce action.
 * @param false|int $result False if the nonce is invalid,
 *                  1 if the nonce is valid and generated between 0-12 hours ago,
 *                  2 if the nonce is valid and generated between 12-24 hours ago.
 */

if (!function_exists('ualpHookGformsDuplicateNotify')){

    function ualpHookGformsDuplicateNotify($action,$result) {
        if($action == "gform_notification_list_action" )  {
            $logHookList = get_option('enableLogHookList');
            if (in_array('gravityforms',$logHookList)) {
                $actions = rgpost( 'action' );
                if($actions == "duplicate"){
                    $form_id = rgget( 'id' );
                    $notification_id = rgpost( 'action_argument' );

                    $form = GFFormsModel::get_form_meta( $form_id );
                    $notification_title = $form['notifications'][$notification_id]['name'];

                    $post_title = $form['title'];
                    $obj_type = 'Gravity Form';
                    $post_id = '';
                    $hook = 'notification_duplicated';
                    $description = "$obj_type : '$notification_title' notification duplicated for '$post_title'";
                    ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
                }
            }
        }
    }
}

add_action('check_admin_referer', 'ualpHookGformsDuplicateNotify', 10, 2);

/**
 * Fired after an entry is created
 *
 * @param array $lead The Entry object
 * @param array $form The Form object
 */
if (!function_exists('ualpHook_gform_entry_created')){

    function ualpHook_gform_entry_created($lead, $form) {
        $lead_id = (isset($lead)) ? $lead['id'] : '';
        if(isset($lead_id) && $lead_id != ''){
            $lead_title = $lead[1];
            $logHookList = get_option('enableLogHookList');
            if (in_array('gravityforms',$logHookList)) {
                $form_title = '';
                if(isset($form['title']) && !empty($form['title'])){
                    $form_title = $form['title'];
                }
                $action = 'created';
                $obj_type = 'Gravity Form';
                $post_id = '';
                $post_title = $lead_title;
                $hook = 'gform_entry_created';
                $description = "$obj_type : New entry '$post_title' $action in '".$form_title."' Form";
                ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
            }
        }
    }
}

add_action('gform_entry_created', 'ualpHook_gform_entry_created', 20, 2);

/**
 * Fires when resend email notifications
 */
if (!function_exists('ualpHook_wp_ajax_gf_resend_notifications')){

    function ualpHook_wp_ajax_gf_resend_notifications() {
        $form_id = absint( rgpost( 'formId' ) );
        $leads   = rgpost( 'leadIds' );

        if ( !empty( $leads ) && !empty( $form_id ) ) {

            $form = GFFormsModel::get_form_meta( $form_id );

            $logHookList = get_option('enableLogHookList');
            if (in_array('gravityforms',$logHookList)) {
                $action = '';
                $obj_type = "Gravity Form";
                $post_id = '';
                $post_title = $form['title'];
                $hook = "gf_resend_notifications";
                foreach($leads as $single_lead){
                    $lead = GFFormsModel::get_lead( $single_lead );
                    $description = "$obj_type : Notifications for '$lead[1]' entry resent for '$post_title' form";
                    ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
                }
            }
        }
    }
}

add_action('wp_ajax_gf_resend_notifications', 'ualpHook_wp_ajax_gf_resend_notifications');

/**
 * Fires before a note is deleted
 *
 * @param int $note_id The current note ID
 * @param int $lead_id The current lead ID
 */
if (!function_exists('ualpHookgform_pre_note_deleted')){
    function ualpHookgform_pre_note_deleted($note_id, $lead_id) {
        $lead = GFFormsModel::get_lead( $lead_id );
        $form = GFFormsModel::get_form_meta( $lead['form_id'] );
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = 'deleted';
            $post_id = '';
            $obj_type = 'Gravity Form';
            $post_title = $form['title'];
            $hook = 'gform_pre_note_deleted';
            $description = "$obj_type : '$note_id' note $action from lead '$lead_id' on '$post_title' form";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_pre_note_deleted', 'ualpHookgform_pre_note_deleted',10,2); // todo

/**
 * Fires when settings updated
 *
 * @param string $option
 * @param string $oldvalue
 * @param string $_newvalue
 */
if(!function_exists('ualpHookGarvityFormUpdatedOption')){
    function ualpHookGarvityFormUpdatedOption($option, $oldvalue = null, $_newvalue = null) {
        $whitelist_options = array(
            'gform_enable_noconflict',
            'gform_enable_toolbar_menu',
            'gform_enable_background_updates',
            'gform_enable_logging',
            'rg_gforms_currency',
            'rg_gforms_key',
            'rg_gforms_enable_html5',
            'rg_gforms_disable_css',
            'rg_gforms_captcha_public_key',
            'rg_gforms_captcha_private_key',
        );

        if (!in_array($option, $whitelist_options))
            return;

        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = "updated";
            $obj_type = "Settings";
            $post_id = '';
            $post_title = $option;
            $hook = 'updated_option';
            $description = "$obj_type $action : $post_title";
            $uactid = ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
            ualpAddWordPressSettingsLogDetail($uactid,$oldvalue,$_newvalue,$obj_type,$option);
        }
    }
}

add_action('updated_option', 'ualpHookGarvityFormUpdatedOption', 20, 3);
add_action('delete_option', 'ualpHookGarvityFormUpdatedOption', 20, 3);
add_action('add_option', 'ualpHookGarvityFormUpdatedOption', 20, 3);

/**
 * Fires after exporting all the entries in form
 *
 * @param array  $form       The Form object to get the entries from
 * @param string $start_date The start date for when the export of entries should take place
 * @param string $end_date   The end date for when the export of entries should stop
 * @param array  $fields     The specified fields where the entries should be exported from
 */
if (!function_exists('ualpHookgform_post_export_entries')){
    function ualpHookgform_post_export_entries($form, $start_date, $end_date, $fields) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = 'form entries exported';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = $form['title'];
            $hook = 'gform_post_export_entries';
            $description = "$obj_type : '$post_title' $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_post_export_entries', 'ualpHookgform_post_export_entries',10,4);

/**
 * Fires after a note has been added to an entry
 *
 * @param int    $note_id         The row ID of this note in the database
 * @param int    $lead_id         The ID of the entry that the note was added to
 * @param int    $user_id         The ID of the current user adding the note
 * @param string $user_name       The user name of the current user
 * @param string $note            The content of the note being added
 * @param string $note_type       The type of note being added.  Defaults to 'note'
 */
if (!function_exists('ualpHookgform_post_note_added')){
    function ualpHookgform_post_note_added($note_id, $lead_id, $user_id, $user_name, $note, $note_type) {
        $lead = GFFormsModel::get_lead( $lead_id );
        $form = GFFormsModel::get_form_meta( $lead['form_id'] );
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = 'added';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = $note_id;
            $hook = 'gform_post_note_added';
            $description = "$obj_type : '$post_title' note $action to lead '$lead_id' on '".$form['title']."' form";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_post_note_added', 'ualpHookgform_post_note_added', 10, 6); // todo

/**
 * Fires when you delete entries for a specific form
 *
 * @param int    $form_id The form ID to specify from which form to delete entries
 * @param string $status  Allows you to set the form entries to a deleted status
 */
if (!function_exists('ualpHookgform_delete_entries')){
    function ualpHookgform_delete_entries($form_id, $status) {

        $form = GFFormsModel::get_form_meta( $form_id );
        $form_title = $form['title'];
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = '';
            $post_id = '';
            $obj_type = 'Gravity Form';
            $post_title = "Entry deleted";
            $hook = 'gform_delete_entries';
            $description = "$obj_type : $post_title from '$form_title'";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_delete_entries', 'ualpHookgform_delete_entries', 10, 2); // todo

/**
 * Fires after form views are deleted
 *
 * @param int $form_id The ID of the form that views were deleted from
 */
if (!function_exists('ualpHookgform_post_form_views_deleted')){
    function ualpHookgform_post_form_views_deleted($form_id) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = 'view Reset';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $form = GFFormsModel::get_form_meta( $form_id );
            $post_title = $form['title'];
            $hook = 'gform_post_form_views_deleted';
            $description = "$obj_type : '$post_title' Form $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_post_form_views_deleted', 'ualpHookgform_post_form_views_deleted', 10, 1);

/**
 * Fires after an inactive form gets marked as active
 *
 * @param int $form_id The Form ID used to specify which form to activate
 */
if (!function_exists('ualpHookgform_post_form_activated')){
    function ualpHookgform_post_form_activated($form_id) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = 'activated';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $form = GFFormsModel::get_form_meta( $form_id );
            $post_title = $form['title'];
            $hook = 'gform_post_form_activated';
            $description = "$obj_type : '$post_title' Form $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_post_form_activated', 'ualpHookgform_post_form_activated', 10, 1);

/**
 * Fires after an active form gets marked as inactive
 *
 * @param int $form_id The Form ID used to specify which form to activate
 */
if (!function_exists('ualpHookgform_post_form_deactivated')){
    function ualpHookgform_post_form_deactivated($form_id) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = 'deactivated';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $form = GFFormsModel::get_form_meta( $form_id );
            $post_title = $form['title'];
            $hook = 'gform_post_form_deactivated';
            $description = "$obj_type : '$post_title' Form $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_post_form_deactivated', 'ualpHookgform_post_form_deactivated', 10, 1);

/**
 * Fires before a form is deleted
 *
 * @param int $form_id The ID of the form being deleted
 */
if (!function_exists('ualpHookgform_before_delete_form')){
    function ualpHookgform_before_delete_form($form_id) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = 'deleted';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $form = GFFormsModel::get_form_meta( $form_id );
            $post_title = $form['title'];
            $hook = 'gform_before_delete_form';
            $description = "$obj_type : '$post_title' Form $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_before_delete_form', 'ualpHookgform_before_delete_form', 10, 1);

/**
 * Fires after a form is trashed
 *
 * @param int $form_id The ID of the form that was trashed
 */
if (!function_exists('ualpHookgform_post_form_trashed')){
    function ualpHookgform_post_form_trashed($form_id) {
        $logHookList = get_option('enableLogHookList');
        $form = GFFormsModel::get_form_meta( $form_id );
        if (in_array('gravityforms',$logHookList)) {
            $action = 'trashed';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = $form['title'];
            $hook = 'gform_post_form_trashed';
            $description = "$obj_type : '$post_title' Form $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_post_form_trashed', 'ualpHookgform_post_form_trashed', 10, 1);

/**
 * Fires after a form is restored from trash
 *
 * @param int $form_id The ID of the form that was restored
 */
if (!function_exists('ualpHookgform_post_form_restored')){
    function ualpHookgform_post_form_restored($form_id) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = 'restored';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $form = GFFormsModel::get_form_meta( $form_id );
            $post_title = $form['title'];
            $hook = 'gform_post_form_restored';
            $description = "$obj_type : '$post_title' Form $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_post_form_restored', 'ualpHookgform_post_form_restored', 10, 1);

/**
 * Fires after a form is duplicated
 *
 * @param int $form_id The original form's ID
 * @param int $new_id  The ID of the new, duplicated form
 */
if (!function_exists('ualpHookgform_post_form_duplicated')){
    function ualpHookgform_post_form_duplicated($form_id,$new_id) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = 'duplicated';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $form = GFFormsModel::get_form_meta( $form_id );
            $post_title = $form['title'];
            $hook = 'gform_post_form_duplicated';
            $description = "$obj_type : '$post_title' Form $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_post_form_duplicated', 'ualpHookgform_post_form_duplicated', 10, 2);

/**
 * Fires after a form is saved
 *
 * Used to run additional actions after the form is saved
 *
 * @param array $form_meta The form meta
 * @param bool  true       Returns true if this is a new form.
 */
if (!function_exists('ualpHookgform_after_save_form')){
    function ualpHookgform_after_save_form($form_meta,$flag) {

        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $obj_type = 'Gravity Form';
            $post_id = '';
            $action = $flag ? 'created' : 'updated';
            $hook = 'gform_after_save_form';
            $post_title = $form_meta['title'];
            $description = "$obj_type : '$post_title' form $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_after_save_form', 'ualpHookgform_after_save_form', 10, 2);

/**
 * Fires after forms have been imported.
 *
 * Used to perform additional actions after import
 *
 * @param array $forms An array imported form objects.
 *
 */
if (!function_exists('ualpHookgform_forms_post_import')){
    function ualpHookgform_forms_post_import($forms) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {

            $forms_total  = count( $forms );
            $forms_label  = ( 1 === $forms_total ) ? 'form' : 'forms';
            $forms_ids    = wp_list_pluck( $forms, 'id' );
            $forms_titles = wp_list_pluck( $forms, 'title' );
            $forms_title = implode(',', $forms_titles);
            $action = 'imported';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = '';
            $hook = 'gform_forms_post_import';
            $description = "$obj_type : '$forms_title' $forms_total $forms_label $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_forms_post_import', 'ualpHookgform_forms_post_import', 10, 1);

/**
 * Fires before a notification is deleted.
 *
 * @param array $notification_id    The notification being deleted.
 * @param array $form               The Form Object that the notification is being deleted from.
 */
if (!function_exists('ualpHookgform_pre_notification_deleted')){
    function ualpHookgform_pre_notification_deleted($notification_id, $form ) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = '';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = $form['title'];
            $hook = 'gform_pre_notification_deleted';
            $description = "$obj_type : '".$notification_id['name']."' Notification deleted from '$post_title'";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_pre_notification_deleted', 'ualpHookgform_pre_notification_deleted', 10, 2);

/**
 * Fires right before a confirmation is deleted.
 *
 * @param int   $confirmation_id The ID of the confirmation being deleted.
 * @param array $form                                    The Form object.
 */
if (!function_exists('ualpHookgform_pre_confirmation_deleted')){
    function ualpHookgform_pre_confirmation_deleted($confirmation_id,$form) {
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = 'confirmation deleted';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = $confirmation_id['name'];
            $hook = 'gform_pre_confirmation_deleted';
            $description = "$obj_type : '$post_title' $action from '".$form['title']."'";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_pre_confirmation_deleted', 'ualpHookgform_pre_confirmation_deleted', 10, 2);

/**
 * Fires when update notification saved
 */
if (!function_exists('ualpHookwp_ajax_rg_update_notification_active')){
    function ualpHookwp_ajax_rg_update_notification_active() {

        if($_POST['is_active'] == 1){
            $action =  'active';
        }else{
            $action =  'inactive';
        }

        $form_id = $_POST['form_id'];
        $form = GFFormsModel::get_form_meta( $form_id );

        $notification_id = $_POST['notification_id'];
        $notification_title = $form['notifications'][$notification_id]['name'];

        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $obj_type = "Gravity Form";
            $post_id = '';
            $post_title = $form['title'];
            $hook = "wp_ajax_rg_update_notification_active";
            $description = "$obj_type : '$notification_title' notification $action for '$post_title'";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('wp_ajax_rg_update_notification_active', 'ualpHookwp_ajax_rg_update_notification_active');

/**
 * Fires when confirmation activated
 */
if (!function_exists('ualpHookwp_ajax_rg_update_confirmation_active')){
    function ualpHookwp_ajax_rg_update_confirmation_active() {
        $logHookList = get_option('enableLogHookList');

        if($_POST['is_active'] == 1){
            $action =  'active';
        }else{
            $action =  'inactive';
        }

        $form_id = $_POST['form_id'];
        $form = GFFormsModel::get_form_meta( $form_id );
        $confirmation_id =  $_POST['confirmation_id'];
        $c_title = $form['confirmations'][$confirmation_id]['name'];

        if (in_array('gravityforms',$logHookList)) {
            $post_id = '';
            $obj_type = "Gravity Form";
            $post_title = $form['title'];
            $hook = "wp_ajax_rg_update_confirmation_active";
            $description = "$obj_type : '$c_title' confirmation $action for '$post_title'";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('wp_ajax_rg_update_confirmation_active', 'ualpHookwp_ajax_rg_update_confirmation_active');

/**
 * Fires when saving form confirmations
 *
 * @param array $confirmation
 * @param array $form
 * @param bool $is_new
 * @return array
 */

if(!function_exists('ualpHookgform_confirmation_save')){
    function ualpHookgform_confirmation_save( $confirmation, $form, $is_new = true ){
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $confirmation_name = $confirmation['name'];
            $action = $is_new ? 'created' : 'updated';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = $form['title'];
            $hook = 'gform_pre_confirmation_save';
            $description = "$obj_type : '$confirmation_name' confirmation $action for '$post_title'";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
        return $confirmation;
    }
}
add_filter('gform_pre_confirmation_save', 'ualpHookgform_confirmation_save', 10, 3);

/**
 * Fires when saving form notification
 *
 * @param array $notification
 * @param array $form
 * @param bool $is_new
 * @return array
 */

if(!function_exists('ualpHookgform_notification_save')){
    function ualpHookgform_notification_save( $notification, $form, $is_new = true ){
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = $is_new ? 'created' : 'updated';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = $notification['name'].' notification';
            $hook = 'gform_pre_notification_save';
            $description = "$obj_type : '$post_title' $action for '".$form['title']."'";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
        return $notification;
    }
}
add_filter('gform_pre_notification_save', 'ualpHookgform_notification_save', 10, 3);

/**
 * Fires after form lead is deleted
 *
 * @param int $lead_id The ID of the lead
 */
if (!function_exists('ualpHookgform_post_lead_deleted')){
    function ualpHookgform_post_lead_deleted($lead_id) {
        $lead = GFFormsModel::get_lead( $lead_id );
        $form = GFFormsModel::get_form_meta( $lead['form_id'] );
        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = "deleted";
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = "Entry '$lead[1]' from '" . $form['title'] ."'";
            $hook = 'gform_delete_lead';
            $description = "$obj_type : $post_title $action";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_delete_lead', 'ualpHookgform_post_lead_deleted', 10, 1);

/**
 * Fires before form status updated
 *
 * @param string $status Current Status
 * @param string $status Previous Status
 * @param int $lead_id The current lead ID
 */
if (!function_exists('ualpHookgform_update_status')){
    function ualpHookgform_update_status($lead_id, $status, $prev = '') {

        $lead = GFFormsModel::get_lead( $lead_id );
        $form = GFFormsModel::get_form_meta( $lead['form_id'] );

        if ( 'active' === $status && 'trash' === $prev ) {
            $action = 'restore';
        }elseif($status == 'active'){
            $action = 'active';
        }elseif($status == 'spam'){
            $action = 'spam';
        }elseif($status == 'trash'){
            $action = 'trash';
        }elseif($status == 'restore'){
            $action = 'restore';
        }else{
            $action = $status;
        }

        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = "Entry '$lead[1]' $action on '".$form['title']."' form";
            $hook = 'gform_update_status';
            $description = "$obj_type :  $post_title";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_update_status', 'ualpHookgform_update_status',10,3);

/**
 * Fires before read entry
 *
 * @param int $status Current status
 * @param int $lead_id The current lead ID
 */
if (!function_exists('ualpHookgform_read_entry')){
    function ualpHookgform_read_entry( $lead_id, $status ) {

        $lead = GFFormsModel::get_lead( $lead_id );
        $form = GFFormsModel::get_form_meta( $lead['form_id'] );

        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = ( ! empty( $status ) ) ? 'read' : 'unread';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = "Entry '$lead[1]' marked as $action on '".$form['title']."' form";
            $hook = 'gform_update_is_read';
            $description = "$obj_type :  $post_title";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_update_is_read', 'ualpHookgform_read_entry',10,2);

/**
 * Fires before entry marked as starred
 *
 * @param int $status Current status
 * @param int $lead_id The current lead ID
 */
if (!function_exists('ualpHookgform_mark_starred')){
    function ualpHookgform_mark_starred( $lead_id, $status ) {

        $lead = GFFormsModel::get_lead( $lead_id );
        $form = GFFormsModel::get_form_meta( $lead['form_id'] );

        $logHookList = get_option('enableLogHookList');
        if (in_array('gravityforms',$logHookList)) {
            $action = ( ! empty( $status ) ) ? 'starred' : 'unstarred';
            $obj_type = 'Gravity Form';
            $post_id = '';
            $post_title = "Entry '$lead[1]' $action on '".$form['title']."' form";
            $hook = 'gform_update_is_starred';
            $description = "$obj_type : $post_title";
            ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
        }
    }
}
add_action('gform_update_is_starred', 'ualpHookgform_mark_starred',10,2);

/**
 * Fires when settings updated
 *
 * @param string $option
 * @param string $oldvalue
 * @param string $_newvalue
 */
if(!function_exists('ualpHookGarvityFormLicenceUpdated')){
    function ualpHookGarvityFormLicenceUpdated($option, $oldvalue, $_newvalue) {
        if($option == 'rg_gforms_key'){
            $logHookList = get_option('enableLogHookList');
            $is_update = ( $_newvalue && strlen( $_newvalue ) );
            if (in_array('gravityforms',$logHookList)) {
                $action = $is_update ? 'updated' : 'deleted';
                $obj_type = 'Gravity Form';
                $post_id = '';
                $post_title = 'Gravity Forms license key';
                $hook = 'updated_option';
                $description = "$obj_type : $post_title $action";
                $uactid = ualpGetActivityLog($action, $obj_type, $post_id, $post_title, $hook, $description);
                ualpAddWordPressSettingsLogDetail($uactid,$oldvalue,$_newvalue,$obj_type,$option);
            }
        }
    }
}
add_action('updated_option', 'ualpHookGarvityFormLicenceUpdated', 20, 3);
