<?php
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

if (!class_exists('WP_List_Table'))
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );

class UALP_Admin_Ui {

    /**
     * @var UALP_Activity_Log_List_Table
     */
    protected $_list_table = null;
    protected $_screens = array();

    public function create_admin_menu() {

        $ualpRoleAccessList = get_option('ualpRoleAccessList');
        $currentUser = wp_get_current_user();
        if(isset($currentUser->roles[0])){
            $currentUserRole = $currentUser->roles[0];
        }else{
            if ( is_multisite()){
                $ID = get_current_user_id();
                $usermeta = get_user_meta($ID,'wp_capabilities');
                if(is_array($usermeta[0])){
                    $currentUserrolls = array_keys($usermeta[0]);
                }else{
                    $currentUserrolls = $usermeta;
                }
                if(isset($currentUserrolls[0])){
                    $currentUserRole = $currentUserrolls[0];
                }
            }
        }
        if(sizeof($ualpRoleAccessList) > 1){
            foreach ($ualpRoleAccessList as $ualpRole){
                if($currentUserRole == $ualpRole){
                    $this->_screens['main'] = add_menu_page(__('User Activity Log', 'user_activity_log_pro'), esc_html__('User Activity Log', 'user_activity_log_pro'), $ualpRole, 'ual_pro', array(&$this, 'ualp_log_page_func'), UALP_PLUGIN_URL.'/assets/images/menu-icon.png');
                    $hook = add_submenu_page('ual_pro', esc_html__('Settings', 'user_activity_log_pro').' | '.__('User Activity Log', 'user_activity_log_pro'), esc_html__('Settings', 'user_activity_log_pro'), $ualpRole, 'ualp_settings', 'ualpSettingsPanel');
                    add_action("load-".$hook, array(&$this,'usersetting_logged_submenupage_screen_options'));
                    add_submenu_page('ual_pro',  esc_html__('DB Integration', 'user_activity_log_pro').' | '.__('User Activity Log', 'user_activity_log_pro'), esc_html__('DB Integration', 'user_activity_log_pro'), $ualpRole, 'ualp_db_integration', 'ualpDbIntegration');
                    add_submenu_page('ual_pro',  esc_html__('License Key', 'user_activity_log_pro').' | '.__('User Activity Log', 'user_activity_log_pro'), esc_html__('License Key', 'user_activity_log_pro'), $ualpRole, 'ualp_license_key', 'ualpLicenseKey');
                    add_action('load-' . $this->_screens['main'], array(&$this, 'get_list_table'));
                }
            }
        }else{
            if($currentUserRole == 'administrator'){
                $this->_screens['main'] = add_menu_page(__('User Activity Log', 'user_activity_log_pro'), esc_html__('User Activity Log', 'user_activity_log_pro'), 'manage_options', 'ual_pro', array(&$this, 'ualp_log_page_func'), UALP_PLUGIN_URL.'/assets/images/menu-icon.png');
                $hook =add_submenu_page('ual_pro',  esc_html__('Settings', 'user_activity_log_pro').' | '.__('User Activity Log', 'user_activity_log_pro'), esc_html__('Settings', 'user_activity_log_pro'), 'manage_options', 'ualp_settings', 'ualpSettingsPanel');
                add_action("load-".$hook, array(&$this,'usersetting_logged_submenupage_screen_options'));
                add_submenu_page('ual_pro',  esc_html__('DB Integration', 'user_activity_log_pro').' | '.__('User Activity Log', 'user_activity_log_pro'), esc_html__('DB Integration', 'user_activity_log_pro'), 'manage_options', 'ualp_db_integration', 'ualpDbIntegration');
                add_submenu_page('ual_pro',  esc_html__('License Key', 'user_activity_log_pro').' | '.__('User Activity Log', 'user_activity_log_pro'), esc_html__('License Key', 'user_activity_log_pro'), 'manage_options', 'ualp_license_key', 'ualpLicenseKey');
                add_action('load-' . $this->_screens['main'], array(&$this, 'get_list_table'));
            }
        }
    }

    public function ualp_log_page_func() {
        $this->get_list_table()->prepare_items();
        ?>
        <div class="wrap">
            <h1><?php esc_html_e('User Activity Log', 'user_activity_log_pro'); ?></h1>
            <form id="activity-filter" method="get" action="<?php echo admin_url('admin.php?page=ual_pro'). '?' . $_SERVER['QUERY_STRING']; ?>">
                <input type="hidden" name="page" value="<?php echo esc_attr($_REQUEST['page']); ?>" />
                <?php $this->get_list_table()->display(); ?>
            </form>
        </div>
        <?php
    }

    public function __construct() {
        add_action('admin_menu', array(&$this, 'create_admin_menu'), 20);
    }

    /**
     * @return UALP_Activity_Log_List_Table
     */
    public function get_list_table() {
        if (is_null($this->_list_table))
            $this->_list_table = new UALP_Activity_Log_List_Table(array('screen' => $this->_screens['main']));
        return $this->_list_table;
    }
    public function usersetting_logged_submenupage_screen_options() {
        if (is_null($this->_list_table))
            $this->_list_table = new UALP_User_Logged_Activity_Log_List_Table(array('screen' => $this->_screens['main']));
        return $this->_list_table;
    }
}

class UALP_Activity_Log_List_Table extends WP_List_Table {

    protected function _get_action_label($action) {
        return ucwords(str_replace('_', ' ', esc_html__($action, 'user_activity_log_pro')));
    }

    public function __construct($args = array()) {
        parent::__construct(
                array(
                    'singular' => 'activity',
                    'ajax' => true,
                    'screen' => isset($args['screen']) ? $args['screen'] : null,
                )
        );
        add_screen_option(
                'per_page', array(
                    'default' => 20,
                    'label' => esc_html__('Number of logs per page', 'user_activity_log_pro').' : ',
                    'option' => 'ualp_logs_per_page',
                )
        );
        add_filter('set-screen-option', array(&$this, 'ualp_set_screen_option'), 10, 3);
        set_screen_options();
    }

    public function get_columns() {
        $columns = array(
            'check' => '<input type="checkbox" id="cb-select-all-ual">',
            'modified_date' => esc_html__('Date', 'user_activity_log_pro'),
            'user_id' => esc_html__('Author', 'user_activity_log_pro'),
        );
        if(ualpAllowIp()) {
            $columns['ip_address'] = esc_html__('IP Address', 'user_activity_log_pro');
        }
        if(ualpAllowCountry()) {
            $columns['country'] = esc_html__('Country', 'user_activity_log_pro');
        }
        if(ualpAllowUserAgent()) {
            $columns['user_agent'] = esc_html__('User Agent', 'user_activity_log_pro');
        }
        $columns['hook'] = esc_html__('Hook', 'user_activity_log_pro');
        $columns['object_type'] = esc_html__('Type', 'user_activity_log_pro');
        $columns['title'] = esc_html__('Description', 'user_activity_log_pro');
        $columns['action'] = esc_html__('Action', 'user_activity_log_pro');
        return $columns;
    }

    public function get_sortable_columns() {
        return array(
            'ip_address' => array('ip_address', false),
            'country' => array('country', false),
            'user_agent' => array('user_agent', false),
            'modified_date' => array('modified_date', true),
            'object_type' => array('object_type', false),
            'user_id' => array('user_id', false),
            'hook' => array('hook', false),
         );
    }

    public function column_default($item, $column_name) {
        global $wpdb, $externaldb;
        $return = '';
        $i = $paged = 1;
        switch ($column_name) {
            case 'check' :
                $return = "<input type='checkbox' name='chkual[]' id='cb-select-$item->uactid' value='$item->uactid'>";
                break;
            case 'modified_date' :
                $modified_date = strtotime($item->modified_date);
                $date_format = get_option('date_format');
                $time_format = get_option('time_format');
                $date = date($date_format, $modified_date);
                $time = date($time_format, $modified_date);
                $return = '<a title="'.$date.'" href="'.admin_url('admin.php?page=ual_pro&datefilter=').$modified_date.'">'.$date.'</a>'. '<br/>'.
                            $time.'<br/>'.
                        '<b>'. human_time_diff( $modified_date, current_time( 'timestamp' ) ) .' '. esc_html__('ago','user_activity_log_pro'). '</b>';
                break;
            case 'user_id' :
                global $wp_roles;
                if (!empty($item->user_id) && 0 !== (int) $item->user_id) {
                    $user = get_user_by('id', $item->user_id);
                    if ($user instanceof WP_User && 0 !== $user->ID) {
                        $user_role = isset($user->roles) ? $user->roles : esc_html__('Unknown', 'user_activity_log_pro');
                        $return = '';
                        $return .= get_avatar($user->ID, 40);
                        $return .= '<a title="'.ucfirst($user->display_name).'" href="'.admin_url("admin.php?page=ual_pro")."&usershow=".$user->display_name.'"><span>'.$user->display_name.'</span></a></br>'
                        ;
                        foreach($user_role as $alluserrole){
                            $return .= sprintf(
                                '<a title="'.$alluserrole.'" href="'.admin_url("admin.php?page=ual_pro&capshow=").$alluserrole.'">'.
                                '<small>'.$alluserrole.'</small>'.
                                '</a></br>');
                        }
                    }
                $return .= $item->user_email;
                }else {
                    $return = '<a href="'.admin_url('admin.php?page=ual_pro').'&usershow=Guest">'.__('Guest', 'user_activity_log_pro').'</a>';
                }
                break;
            case 'object_type' :
                $return = "<a href='".admin_url('admin.php?page=ual_pro&typeshow=').$item->object_type."' title='$item->object_type'>".ucfirst($item->object_type)."</a>";
                break;
            case 'ip_address' :
                $return = "<a href='".admin_url('admin.php?page=ual_pro&showip=').$item->ip_address."' title='$item->ip_address'>".$item->ip_address."</a>";
                break;
            case 'country' :
                if(isset($item->country)){
                    $return = "<a href='".admin_url('admin.php?page=ual_pro&showcountry=').$item->country."' title='$item->country'>".$item->country."</a>";
                }
                break;
            case 'user_agent' :
                if(isset($item->user_agent)){
                    $return = "<a href='".admin_url('admin.php?page=ual_pro&showuser_agent=').$item->user_agent."' title='$item->user_agent'>".$item->user_agent."</a>";
                }
                break;
            case 'hook' :
                $return = "<a href='".admin_url('admin.php?page=ual_pro&showhook=').$item->hook."' title='$item->hook'>".$item->hook."</a>";
                break;
            case 'title' :
                if (isset($item->description) && $item->description != "") {
                    $filter = '';
                    if($item->hook == 'transition_post_status'){
                        $filter = '<a title="'.$item->post_title.'" href="'.admin_url('admin.php?page=ual_pro').'&filterposts='.$item->post_id.'">'
                                    . '<div class="dashicons dashicons-filter post_filter"></div>'.
                                  '</a>';
                    }
                    $return .= ucfirst($item->description) . $filter;
                } else {
                    $return .= $item->action .' : '. $item->post_title;
                }
                break;
            case 'action' :
                $return = "";
                if ($item->favorite == '1') {
                    $favTitle = esc_html__('Favorite','user_activity_log_pro');
                    $selected = "selected";
                } else {
                    $favTitle = esc_html__('Unfavorite','user_activity_log_pro');
                    $selected = "";
                }
                $viewTitle = esc_html__('View','user_activity_log_pro');
                $deleteTitle = esc_html__('Delete','user_activity_log_pro');
                if (!get_option('ualp_delete_log_pwd') || get_option('ualp_delete_log_pwd') == "") {
                    $class = "setDeletePassword";
                } else {
                    $class = "deleteSingleLog";
                }
                ualpCreateTable();
                ualpCreateDetailTable();
                ualpCreateExternalTable();
                ualpCreateDetailExternalTable();
                $viewCount = $externaldb->get_var('SELECT COUNT(uactd_id) FROM '.UALP_DETAIL_TABLENAME.' WHERE uactid = '.$item->uactid);
                if($viewCount > 0){
                    $return .= '<a data-view="'.$item->uactid.'" title="'.$viewTitle.'" href="javascript:void(0)" class="ualp_view"><span class="dashicons dashicons-visibility"></span></a>';
                }else {
                    $return .= '<span style="float:left;margin-right: 5px;margin-top: 4px;" class="dashicons dashicon-show dashicons-visibility ualp-not-allowed"></span>';
                }
                $return .= '<a title="'.$favTitle.'" class="ualpFavorite '.$selected.'" id="'.$item->uactid.'"></a>';

                if ($item->favorite == '1') {
                    $return .= '<span class="padding_left_right_5 padding_top_bottom_3 ualp-not-allowed dashicons dashicons-trash"></span>';
                } else {
                    $return .= '<a title="'.$deleteTitle.'" class="column-delete deleteLog '.$class.'" data-id="'.$item->uactid.'" href="'.wp_nonce_url(admin_url("admin.php?page=ual_pro&paged=$paged&action=delete&id=$item->uactid"), "delete-action$item->uactid", "delete-nonce").'" ><span class="dashicons dashicons-trash"></span></a>';
                }
                break;
            default :
                if (isset($item->$column_name))
                    $return = $item->$column_name;
        }
        $return = apply_filters('ualp_table_list_column_default', $return, $item, $column_name);
        return $return;
    }

    public function column_author($item) {
        global $wp_roles;
        if (!empty($item->user_id) && 0 !== (int) $item->user_id) {
            $user = get_user_by('id', $item->user_id);
            if ($user instanceof WP_User && 0 !== $user->ID) {
                $userLink = get_edit_user_link($user->ID);
                $userAvatar = get_avatar($user->ID, 40);
                $userDisplayName = $user->display_name;
                $userRole = (isset($user->roles[0]) && isset($wp_roles->role_names[$user->roles[0]])) ? $wp_roles->role_names[$user->roles[0]] : 'Unknown';
                return '<a href="'.$userLink.'">'
                            .$userAvatar.' <span>'.$userDisplayName.'</span>'
                        . '</a><br />'
                        . '<small>'.$userRole.'</small>';
            }
        }
        return '<span>'.__('Guest', 'user_activity_log_pro').'</span>';
    }

    public function column_type($item) {
        $return = $item->object_type;
        $return = apply_filters('ualp_table_list_column_type', $return, $item);
        return $return;
    }

    public function column_label($item) {
        $return = '';
        if (!empty($item->object_subtype)) {
            $pt = get_post_type_object($item->object_subtype);
            $return = !empty($pt->label) ? $pt->label : $item->object_subtype;
        }
        $return = apply_filters('ualp_table_list_column_label', $return, $item);
        return $return;
    }

    public function display_tablenav($which) {
        ?>
        <div class="tablenav <?php echo esc_attr($which); ?>"><?php
            global $wpdb, $externaldb;
            ualpCreateTable();
            ualpCreateDetailTable();
            ualpCreateExternalTable();
            ualpCreateDetailExternalTable();
            $itemList = $externaldb->get_var('SELECT count(uactid) FROM '.UALP_TABLENAME);
            if($itemList){
                if ('top' == $which) {
                    wp_nonce_field('bulk-' . $this->_args['plural']); ?>
                    <div class="wp-filter">
                        <div class="filter-items">
                            <?php
                            $this->extra_tablenav($which); ?>
                                <div class="top-cover">
                                    <div class="alignleft bulkactions">
                                        <?php
                                        if (!get_option('ualp_delete_log_pwd') || get_option('ualp_delete_log_pwd') == "") {
                                            $class = "setBulkDeletePassword";
                                        } else {
                                            $class = "deleteBulkLog";
                                        }
                                        ?>
                                        <label class="screen-reader-text" for="bulk-action-selector-top">
                                            <?php esc_html_e('Select bulk action', 'user_activity_log_pro'); ?>
                                        </label>
                                        <select class="<?php echo $class; ?>" id="bulk-action-selector-top" name="bulk_action_selector">
                                            <option value="0"><?php esc_html_e('Bulk Actions', 'user_activity_log_pro'); ?></option>
                                            <option value="delete"><?php esc_html_e('Delete Permanently', 'user_activity_log_pro'); ?></option>
                                            <option value="favorite"><?php esc_html_e('Favorite', 'user_activity_log_pro'); ?></option>
                                            <option value="unfavorite"><?php esc_html_e('Unfavorite', 'user_activity_log_pro'); ?></option>
                                        </select>
                                        <input type="submit" value="<?php esc_html_e('Apply', 'user_activity_log_pro'); ?>" name="bulk_action" class="button action" id="doaction">
                                        <?php
                                        $items_array = $this->items;
                                        if(is_array($items_array) && count($items_array) > 0) {
                                            if (!isset($_REQUEST['capshow']))
                                                $_REQUEST['capshow'] = '';
                                            if (!isset($_REQUEST['usershow']))
                                                $_REQUEST['usershow'] = '';
                                            if (!isset($_REQUEST['typeshow']))
                                                $_REQUEST['typeshow'] = '';
                                            if (!isset($_REQUEST['showip']))
                                                $_REQUEST['showip'] = '';
                                            if (!isset($_REQUEST['showcountry']))
                                                $_REQUEST['showcountry'] = '';
                                            if (!isset($_REQUEST['showuser_agent']))
                                                $_REQUEST['showuser_agent'] = '';
                                            if (!isset($_REQUEST['dateshow']))
                                                $_REQUEST['dateshow'] = '';
                                            if (!isset($_REQUEST['showhook']))
                                                $_REQUEST['showhook'] = '';
                                            if (!isset($_REQUEST['showfavorite']))
                                                $_REQUEST['showfavorite'] = '';
                                            if (!isset($_REQUEST['s']))
                                                $_REQUEST['s'] = '';
                                            if (!isset($_REQUEST['start_date']))
                                                $_REQUEST['start_date'] = '';
                                            if (!isset($_REQUEST['end_date']))
                                                $_REQUEST['end_date'] = '';
                                            if (!isset($_REQUEST['t_session']))
                                                $_REQUEST['t_session'] = '';
                                        ?>
                                            <a href="<?php echo wp_nonce_url(admin_url("admin.php?page=ual_pro&export=user_logs&userrole=".$_REQUEST['capshow']."&username=".$_REQUEST['usershow']."&type=".$_REQUEST['typeshow']."&ip=".$_REQUEST['showip']."&country=".$_REQUEST['showcountry']."&user_agent=".$_REQUEST['showuser_agent']."&time=".$_REQUEST['dateshow']."&start_date=".$_REQUEST['start_date']."&end_date=".$_REQUEST['end_date']."&hook=".$_REQUEST['showhook']."&favorite=".$_REQUEST['showfavorite']."&txtsearch=".$_REQUEST['s']."&t_session=".$_REQUEST['t_session']), "export-action", "export-nonce"); ?>" class="button-primary action">
                                                <?php esc_html_e('Export Logs (CSV)', 'user_activity_log_pro'); ?>
                                            </a><?php
                                        } ?>
                                    </div>
                                </div><?php
                            $this->search_box(__('Search', 'user_activity_log_pro'), 'ualp-search'); ?>
                        </div>
                    </div><?php
                }
                $this->pagination($which);
            }?>
            <br class="clear" />
        </div><?php
    }

    public function extra_tablenav($which) {

        global $wpdb, $externaldb;
        if ('top' !== $which)
            return;
        echo '<div class="alignleft actions1">';
        $users = $externaldb->get_results($externaldb->prepare(
                        'SELECT DISTINCT user_name FROM '.UALP_TABLENAME.'
				WHERE 1 = 1 AND user_name <> %s
				ORDER BY user_name
			'
        ,'""'));
        $types = $externaldb->get_results($externaldb->prepare(
                        'SELECT DISTINCT object_type FROM '.UALP_TABLENAME.'
				WHERE 1 = 1 AND object_type <> %s
				ORDER BY object_type
			'
        ,'""'));
        // Make sure we get items for filter.
        if ($users || $types) {
            if (!isset($_REQUEST['dateshow']))
                $_REQUEST['dateshow'] = '';
            $date_options = array(
                '' => esc_html__('All Time', 'user_activity_log_pro'),
                'today' => esc_html__('Today', 'user_activity_log_pro'),
                'yesterday' => esc_html__('Yesterday', 'user_activity_log_pro'),
                'week' => esc_html__('Week', 'user_activity_log_pro'),
                'this-month' => esc_html__('This Month', 'user_activity_log_pro'),
                'month' => esc_html__('Last 1 Month', 'user_activity_log_pro'),
                '2-month' => esc_html__('Last 2 Month', 'user_activity_log_pro'),
                '3-month' => esc_html__('Last 3 Month', 'user_activity_log_pro'),
                '6-month' => esc_html__('Last 6 Month', 'user_activity_log_pro'),
                'this-year' => esc_html__('This Year', 'user_activity_log_pro'),
                'last-year' => esc_html__('Last Year', 'user_activity_log_pro'),
                'custom' => esc_html__('Custom Date Range', 'user_activity_log_pro'),
            );
            echo '<div class="filter-cover"><select name="dateshow" class="chosen-filter" id="ualp-filter-date">';
            foreach ($date_options as $key => $value)
                printf('<option value="%1$s"%2$s>%3$s</option>', $key, selected($_REQUEST['dateshow'], $key, false), $value);
            echo '</select>';
        }
        $user_id = $externaldb->get_results(
            'SELECT DISTINCT user_id FROM '.UALP_TABLENAME.'
                    WHERE 1 = 1
                    ORDER BY user_id
            '
            );
            
        if ($user_id) {
            if (!isset($_REQUEST['capshow'])) {
                $_REQUEST['capshow'] = '';
            }
            $output = array();
            foreach ($user_id as $alluserroleid) {
                foreach($alluserroleid as $alluserrole){
                    $userroles = get_user_by('id', $alluserrole);
                    $user_roles = $userroles->roles;
                        if($user_roles == ''){
                            $user_roles = array();
                        }
                        foreach($user_roles as $user_id_role){
                            $output[] = sprintf('<option value="%s"%s>%s</option>', $user_id_role, selected($_REQUEST['capshow'], $user_id_role, false), $user_id_role);
                       }
                    
                }  
            }
       
        echo '<select class="chosen-filter" name="capshow" id="ualp-filter-capshow">';
        printf('<option value="">'.__('All Roles', 'user_activity_log_pro').'</option>');
        echo implode('', array_unique($output));
        echo '</select>';
    }
        if ($users) {
            if (!isset($_REQUEST['usershow']))
                $_REQUEST['usershow'] = '';
            $output = array();
            foreach ($users as $_user) {
                if(isset($_user->user_name) && $_user->user_name != ''){
                    $output[] = sprintf('<option value="%s"%s>%s</option>', $_user->user_name, selected($_REQUEST['usershow'], $_user->user_name, false), $this->_get_action_label($_user->user_name));
                }
            }
            echo '<select class="chosen-filter" name="usershow" id="ualp-filter-usershow">';
            printf('<option value="">' .__('All Users', 'user_activity_log_pro'). '</option>');
            echo implode('', $output);
            echo '</select>';
        }

        $ips = $externaldb->get_results(
            'SELECT DISTINCT ip_address FROM '.UALP_TABLENAME.'
                    WHERE 1 = 1
                    ORDER BY ip_address
            '
        );
        if ($ips && ualpAllowIp()) {
            if (!isset($_REQUEST['showip']))
                $_REQUEST['showip'] = '';
            $output = array();
            foreach ($ips as $ip) {
                if(isset($ip->ip_address) && $ip->ip_address != ''){
                    $output[] = sprintf('<option value="%s"%s>%s</option>', $ip->ip_address, selected($_REQUEST['showip'], $ip->ip_address, false), $this->_get_action_label($ip->ip_address));
                }
            }

            echo '<select class="chosen-filter" name="showip" id="ualp-filter-showip">';
            printf('<option value="">'.__('All IP', 'user_activity_log_pro').'</option>');
            echo implode('', $output);
            echo '</select>';
        }
        $countrys = $externaldb->get_results(
            'SELECT DISTINCT country FROM '.UALP_TABLENAME.'
                    WHERE 1 = 1
                    ORDER BY country'
        );
        if ($countrys && ualpAllowCountry()) {
            if (!isset($_REQUEST['showcountry']))
                $_REQUEST['showcountry'] = '';
            $output = array();
            foreach ($countrys as $country){
                if(isset($country->country) && $country->country != ''){
                    $output[] = sprintf('<option value="%s"%s>%s</option>', $country->country, selected($_REQUEST['showcountry'], $country->country, false), $this->_get_action_label($country->country));
                }
            }
            echo '<select class="chosen-filter" name="showcountry" id="ualp-filter-showcountry">';
            printf('<option value="">'.__('All Countries', 'user_activity_log_pro').'</option>');
            echo implode('', $output);
            echo '</select>';
        }
        $user_agents = $externaldb->get_results(
            'SELECT DISTINCT user_agent FROM '.UALP_TABLENAME.'
                    WHERE 1 = 1
                    ORDER BY user_agent'
        );
        if ($user_agents && ualpAllowUserAgent()) {
            if (!isset($_REQUEST['showuser_agent']))
                $_REQUEST['showuser_agent'] = '';
            $output = array();
            foreach ($user_agents as $user_agent){
                if(isset($user_agent->user_agent) && $user_agent->user_agent != ''){
                    $output[] = sprintf('<option value="%s"%s>%s</option>', $user_agent->user_agent, selected($_REQUEST['showuser_agent'], $user_agent->user_agent, false), $this->_get_action_label($user_agent->user_agent));
                }
            }
            echo '<select style="max-width:200px" class="chosen-filter" name="showuser_agent" id="ualp-filter-showuser_agent">';
            printf('<option value="">'.__('All User Agents', 'user_activity_log_pro').'</option>');
            echo implode('', $output);
            echo '</select>';
        }
        if ($types) {
            if (!isset($_REQUEST['typeshow']))
                $_REQUEST['typeshow'] = '';
            $output = array();
            foreach ($types as $type) {
                if(isset($type->object_type) && $type->object_type != ''){
                    $output[] = sprintf('<option value="%1$s"%2$s>%3$s</option>', $type->object_type, selected($_REQUEST['typeshow'], $type->object_type, false), ucfirst($type->object_type));
                }
            }
            echo '<select class="chosen-filter" name="typeshow" id="ualp-filter-typeshow">';
            printf('<option value="">'.__('All Types', 'user_activity_log_pro').'</option>' );
            echo implode('', $output);
            echo '</select>';
        }

        $hooks = $externaldb->get_results(
            'SELECT DISTINCT hook FROM '.UALP_TABLENAME.'
                    WHERE 1 = 1
                    ORDER BY hook
            '
        );
        if ($hooks) {
            if (!isset($_REQUEST['showhook']))
                $_REQUEST['showhook'] = '';
            $output = array();

            foreach ($hooks as $hook) {
                if ( isset($hook->hook) && $hook->hook != '') {
                    $output[] = sprintf('<option value="%s"%s>%s</option>', $hook->hook, selected($_REQUEST['showhook'], $hook->hook, false), $hook->hook);
                }
            }
            echo '<select class="chosen-filter" name="showhook" id="ualp-filter-showhook">';
            printf('<option value="">'.__('All Hook', 'user_activity_log_pro').'</option>');
            echo implode('', $output);
            echo '</select>';
        }

        $favorites = $externaldb->get_results(
            'SELECT DISTINCT favorite FROM '.UALP_TABLENAME.'
                    WHERE 1 = 1
                    ORDER BY favorite
            '
        );
        if ($favorites) {
            if (!isset($_REQUEST['showfavorite']))
                $_REQUEST['showfavorite'] = '';
        }

        $startDate = (isset($_REQUEST['start_date']) && $_REQUEST['start_date'] != '') ? $_REQUEST['start_date'] : '';
        $endDate = (isset($_REQUEST['end_date']) && $_REQUEST['end_date'] != '') ? $_REQUEST['end_date'] : '';

        $output = array();
        $output = sprintf('<option value="1"%s>%s</option>', selected($_REQUEST['showfavorite'], '1', false), esc_html__('Favorite', 'user_activity_log_pro'));
        $output .= sprintf('<option value="0"%s>%s</option>', selected($_REQUEST['showfavorite'], '0', false), esc_html__('Unfavorite', 'user_activity_log_pro'));
        echo '<select class="chosen-filter" name="showfavorite" id="ualp-filter-showfavorite">';
        printf('<option value="">'.__('All Favorite/Unfavorite', 'user_activity_log_pro').'</option>');
        echo $output;
        echo '</select></div>';

        // Parse all query vars into an array
        $query_vars = array();

        if ( isset( $_SERVER['QUERY_STRING'] ) ) {
            parse_str( urldecode( $_SERVER['QUERY_STRING'] ), $query_vars );
        }

        // Ignore certain query vars and query vars that are empty
        foreach ( $query_vars as $query_var => $value ) {
            if ( '' === $value || 'page' === $query_var || 'paged' === $query_var ) {
                unset( $query_vars[ $query_var ] );
            }
        } ?>
        <div class="filter-btn-cover">
            <?php
            submit_button(__('Filter', 'user_activity_log_pro'), 'primary', false, false, array('uactid' => 'activity-query-submit'));
            if ( ! empty( $query_vars ) ) { ?>
                <a class="button ualp-button-green" href="<?php echo admin_url('admin.php?page=ual_pro'); ?>">
                    <?php esc_html_e('Reset Filter', 'user_activity_log_pro'); ?>
                </a><?php
            }
            ?>
        </div><?php

            echo '<div class="custom-date pull-left">'
                    . '<p>'
                        .__("Start date","user_activity_log_pro"). ' : '
                        . '<input type="text" name="start_date" value="'.$startDate.'" class="datepicker start-date"> '
                        .__("End date","user_activity_log_pro"). ' : '
                        . '<input type="text" name="end_date" value="'.$endDate.'" class="datepicker end-date">'
                    . '</p>'
                    . '<p class="custom_date_msg"></p>'
                . '</div>'
        . '</div>';
    }

    public function prepare_items() {
        global $wpdb, $externaldb;
        $_SERVER['REQUEST_URI'] = remove_query_arg('_wp_http_referer', $_SERVER['REQUEST_URI']);
        $items_per_page = $this->get_items_per_page('ualp_logs_per_page');
        $this->_column_headers = array($this->get_columns(), get_hidden_columns($this->screen), $this->get_sortable_columns());
        $where = ' WHERE 1=1';
        if (!empty($_REQUEST['bulk_action_selector']) && $_REQUEST['bulk_action_selector'] == 'favorite') {
            if (isset($_REQUEST['chkual']) && !empty($_REQUEST['chkual'])) {
                $logs = $_REQUEST['chkual'];
                foreach ($logs as $log) {
                    $result = $externaldb->update(
                        UALP_TABLENAME,
                        array( 'favorite' => '1' ),
                        array( 'uactid' => $log ),
                        array( '%s' ),
                        array( '%d' )
                    );
                }
                wp_redirect(admin_url("admin.php?page=ual_pro"));
            }
        }
        if (!empty($_REQUEST['bulk_action_selector']) && $_REQUEST['bulk_action_selector'] == 'unfavorite') {
            if (isset($_REQUEST['chkual']) && !empty($_REQUEST['chkual'])) {
                $logs = $_REQUEST['chkual'];
                foreach ($logs as $log) {
                    $result = $externaldb->update(
                        UALP_TABLENAME,
                        array( 'favorite' => '0' ),
                        array( 'uactid' => $log ),
                        array( '%s' ),
                        array( '%d' )
                    );
                }
                wp_redirect(admin_url("admin.php?page=ual_pro"));
            }
        }
        if (!isset($_REQUEST['order']) || !in_array($_REQUEST['order'], array('desc', 'asc'))) {
            $_REQUEST['order'] = 'desc';
        }
        if (!isset($_REQUEST['orderby']) || !in_array($_REQUEST['orderby'], array('modified_date', 'user_id', 'user_email', 'object_type', 'hook', 'ip_address', 'country'))) {
            $_REQUEST['orderby'] = 'modified_date';
        }
        if (!empty($_REQUEST['typeshow'])) {
            $where .= $externaldb->prepare(' AND object_type = %s', $_REQUEST['typeshow']);
        }
        if (isset($_REQUEST['showip']) && '' !== $_REQUEST['showip']) {
            $where .= $externaldb->prepare(' AND `ip_address` = \'%s\'', $_REQUEST['showip']);
        }
        if (isset($_REQUEST['showcountry']) && '' !== $_REQUEST['showcountry']) {
            $where .= $externaldb->prepare(' AND `country` = \'%s\'', $_REQUEST['showcountry']);
        }
        if (isset($_REQUEST['showuser_agent']) && '' !== $_REQUEST['showuser_agent']) {
            $where .= $externaldb->prepare(' AND `user_agent` = \'%s\'', $_REQUEST['showuser_agent']);
        }
        if (isset($_REQUEST['showhook']) && '' !== $_REQUEST['showhook']) {
            $where .= $externaldb->prepare(' AND `hook` = \'%s\'', $_REQUEST['showhook']);
        }
        if (isset($_REQUEST['usershow']) && '' !== $_REQUEST['usershow']) {
            $where .= $externaldb->prepare(' AND `user_name` = %s', $_REQUEST['usershow']);
        }
        if (isset($_REQUEST['showfavorite']) && '' !== $_REQUEST['showfavorite']) {
            $where .= $externaldb->prepare(' AND `favorite` = %s', $_REQUEST['showfavorite']);
        }
        if (isset($_REQUEST['capshow']) && $_REQUEST['capshow'] != '') {
            $where .=' AND user_role LIKE "%%'.$_REQUEST['capshow'].'%%"';
        }
        if (isset($_REQUEST['dateshow']) && in_array($_REQUEST['dateshow'], array('today', 'yesterday', 'week','this-month', 'month','2-month','3-month','6-month','this-year','last-year','custom'))) {
            $get_time = $_REQUEST['dateshow'];
            $current_time = current_time('timestamp');
            $start_time = mktime(0, 0, 0, date('m', $current_time), date('d', $current_time), date('Y', $current_time));
            $end_time = mktime(23, 59, 59, date('m', $current_time), date('d', $current_time), date('Y', $current_time));
            if ($get_time == 'today') {
                $start_time = $current_time;
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time);

            } elseif ($get_time === 'yesterday') {
                $start_time = strtotime('yesterday', $start_time);
                $end_time = $current_time;

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time);

            } elseif ($get_time === 'week') {
                $start_time = strtotime('-1 week', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time);

            } elseif ($get_time === 'this-month') {
                $start_time = date('Y-m-01');
                $start_time = strtotime($start_time);

                $end_time = date('Y-m-31');
                $end_time = strtotime($end_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time);

            } elseif ($get_time === 'month') {
                $start_time = strtotime('-1 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time);

            } elseif ($get_time === '2-month') {
                $start_time = strtotime('-2 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time);

            } elseif ($get_time === '3-month') {
                $start_time = strtotime('-3 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time);

            } elseif ($get_time === '6-month') {
                $start_time = strtotime('-6 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time);

            }elseif ($get_time === 'this-year') {
                $start_time = date('Y-01-01');
                $start_time = strtotime($start_time);

                $end_time = date('Y-12-31');
                $end_time = strtotime($end_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time);
            }elseif($get_time === 'last-year'){

                $start_time = date('Y-01-01');
                $start_time = strtotime($start_time);
                $start_time = strtotime('-1 year',$start_time);

                $end_time = date('Y-12-31');
                $end_time = strtotime($end_time);
                $end_time = strtotime('-1 year',$end_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND modified_date > "%s" AND modified_date < "%s"', $start_time, $end_time);
            } elseif ($get_time === 'custom') {
                $custom_start_date = $_REQUEST['start_date'];
                $custom_end_date = $_REQUEST['end_date'];
                if(isset($custom_start_date) && $custom_start_date != ''){
                    $start_time = strtotime($custom_start_date);
                    $start_time = strtotime('-1 day', $start_time);
                    $start_time = date('Y-m-d', $start_time);
                    $where .= $externaldb->prepare(' AND modified_date > "%s"', $start_time);
                }
                if(isset($custom_end_date) && $custom_end_date != ''){
                    $end_time = strtotime($custom_end_date);
                    $end_time = strtotime('+1 day', $end_time);
                    $end_time = date('Y-m-d', $end_time);
                    $where .= $externaldb->prepare(' AND modified_date < "%s"', $end_time);
                }
            }
        }

        if (isset($_REQUEST['datefilter']) && $_REQUEST['datefilter'] != '') {
            $date_filter = $_REQUEST['datefilter'];
            $date_filter = date('Y-m-d', $date_filter);
            $where .= ' AND modified_date LIKE "%%'.$date_filter.'%%"';
        }
        if (isset($_REQUEST['filterposts']) && $_REQUEST['filterposts'] != '') {
            $where .= " AND hook like 'transition_post_status' AND post_id = ".$_REQUEST['filterposts'];
        }
        if (isset($_REQUEST['t_session']) && $_REQUEST['t_session'] != '') {
            $where .= " AND t_session = '".$_REQUEST['t_session']."'";
        }

        if (isset($_REQUEST['s']) && $_REQUEST['s'] != '') {
            $where .= ' AND (user_name LIKE \'%%'.$externaldb->esc_like($_REQUEST['s']).'%%\' OR user_role LIKE \'%%'.$externaldb->esc_like($_REQUEST['s']).'%%\' OR description LIKE \'%%'.$externaldb->esc_like($_REQUEST['s']).'%%\' OR country LIKE \'%%'.$externaldb->esc_like($_REQUEST['s']).'%%\' OR object_type LIKE \'%%'.$externaldb->esc_like($_REQUEST['s']).'%%\')';
        }
        $offset = ( $this->get_pagenum() - 1 ) * $items_per_page;
        ualpCreateTable();
        ualpCreateDetailTable();
        ualpCreateExternalTable();
        ualpCreateDetailExternalTable();
        $total_items = $externaldb->get_var(
            'SELECT COUNT(`uactid`) FROM ' . UALP_TABLENAME . $where
        );
        $this->items = $externaldb->get_results($externaldb->prepare(
            'SELECT * FROM '.UALP_TABLENAME . $where . '
                        ORDER BY '.$_REQUEST['orderby'] . ' '.$_REQUEST['order'].'
                        LIMIT %d, %d', $offset, $items_per_page
        ));
        $this->set_pagination_args(array(
            'total_items' => $total_items,
            'per_page' => $items_per_page,
            'total_pages' => ceil($total_items / $items_per_page)
        ));
    }

    public function ualp_set_screen_option( $status, $option, $value ) {
        if ( 'ualp_logs_per_page' === $option )
            return $value;
    }

    public function no_items() {
            esc_html_e( 'No Activity found.','user_activity_log_pro' );
    }

    public function search_box($text, $input_id) {
        $search_data = isset($_REQUEST['s']) ? sanitize_text_field($_REQUEST['s']) : '';
        $input_id = $input_id . '-search-input';
        ?>
        <p class="search-box">
            <label class="screen-reader-text" for="<?php echo $input_id ?>"><?php echo $text; ?>:</label>
            <input type="search" id="<?php echo $input_id ?>" name="s" placeholder="<?php esc_html_e('User, Role, Type', 'user_activity_log_pro'); ?>" value="<?php echo esc_attr($search_data); ?>" />
            <?php submit_button($text, 'button', false, false, array('uactid' => 'search-submit')); ?>
        </p>
        <?php
    }

}

$ualpAdminUi = new UALP_Admin_Ui();

/*
* User Logged Details Table
*/
class UALP_User_Logged_Activity_Log_List_Table extends WP_List_Table
{
    protected function _get_action_label($action) {
        return ucwords(str_replace('_', ' ', esc_html__($action, 'user_activity_log_pro')));
    }

    public function __construct(){
        global $status, $page;
        parent::__construct(array(
            'singular' => 'logingactivity',
            'screen' => isset($args['screen']) ? $args['screen'] : null,
        ));
        add_screen_option(
            'per_page', array(
                'default' => 20,
                'label' => esc_html__('Number of logged per page', 'user_activity_log_pro').' : ',
                'option' => 'ualp_user_logged_per_page',
        ));
        add_filter('set-screen-option', array(&$this, 'ualp_logged_set_screen_option'), 10, 3);
        set_screen_options();
    }

    public function ualp_logged_set_screen_option( $status, $option, $value ) {
        if ( 'ualp_user_logged_per_page' === $option )
            return $value;
    }
    public function column_default($item, $column_name){   
        return $item[$column_name];
    }

    public function column_cb($item){
        return sprintf(
            '<input type="checkbox" name="id[]" value="%s" />',
            $item->uacltid
        );
    }

    public function column_user_id($item) {
        global $wp_roles;
        if (!empty($item->user_id) && 0 !== (int) $item->user_id) {
            $user = get_user_by('id', $item->user_id);
            if ($user instanceof WP_User && 0 !== $user->ID) {
                $userLink = get_edit_user_link($user->ID);
                $userAvatar = get_avatar($user->ID, 40);
                $userDisplayName = $user->display_name;
                $useremail = $user->user_email;
                $userRole = (isset($user->roles)) ? $user->roles : 'Unknown';
                $alluserrole = '';
                $alluserrole .=  $userAvatar.' <a title="'.ucfirst($userDisplayName).'" href="'.admin_url("admin.php?page=ualp_settings&usershow=").$user->display_name.'">'.$userDisplayName.'</a></br>';
                foreach($userRole as $all_rols){
                    $alluserrole .=  '<a title="'.ucfirst($userDisplayName).'"  href="'.admin_url("admin.php?page=ualp_settings&user_role=").$all_rols.'">'.$all_rols.'</a></br>';
                }
                $alluserrole .='<span>'.$useremail. '</span>';
                return $alluserrole;
            }
        } else {
            return '<span>'.__('Guest', 'user_activity_log_pro').'</span>';
        }
    }

    public function column_ip_address($item){   
        $ip_address = $item->ip_address;
        $return = '<a title="'.$ip_address.'" href="'.admin_url('admin.php?page=ualp_settings&showip=').$ip_address.'">'.$ip_address.'</a>';
        return $return;
    }
   
    public function column_country($item){   
        return $item->country;
    }

    public function column_user_agent($item) {   
        $return = "<a href='".admin_url('admin.php?page=ualp_settings&showuser_agent=').$item->user_agent."' title='$item->user_agent'>".$item->user_agent."</a>";
        return $return;
    }

    public function column_time_login($item){   
        $time_login_data = strtotime($item->time_login);
        $date_format = get_option('date_format');
        $time_format = get_option('time_format');
        $date = date($date_format, $time_login_data);
        $time = date($time_format, $time_login_data);
        $return = '<a title="'.$date.'" href="'.admin_url('admin.php?page=ualp_settings&datefilterlogin=').$time_login_data.'">'.$date.'</a>'. '<br/>'.
                    $time.'<br/>'.
                '<b>'. human_time_diff( $time_login_data, current_time( 'timestamp' ) ) .' '. esc_html__('ago','user_activity_log_pro'). '</b>';
                return $return;
    }

    public function column_time_logout($item) {   
        $time_logout_data = strtotime($item->time_logout);
        $date_format = get_option('date_format');
        $time_format = get_option('time_format');
        $date = date($date_format, $time_logout_data);
        $time = date($time_format, $time_logout_data);
        if($time_logout_data != ''){
            $return = '<a title="'.$date.'" href="'.admin_url('admin.php?page=ualp_settings&datefilterlogout=').$time_logout_data.'">'.$date.'</a>'. '<br/>'.
            $time.'<br/>'.
        '<b>'. human_time_diff( $time_logout_data, current_time( 'timestamp' ) ) .' '. esc_html__('ago','user_activity_log_pro'). '</b>';
        } else {
            $return = '';
        }
        
        return $return;
    }

    public function column_time_last_seen($item){    
        
        $time_last_seen = strtotime($item->time_last_seen);
        $date_format = get_option('date_format');
        $time_format = get_option('time_format');
        $date = date($date_format, $time_last_seen);
        $time = date($time_format, $time_last_seen);
        $return = '<a title="'.$date.'" href="'.admin_url('admin.php?page=ualp_settings&datefilterlastseen=').$time_last_seen.'">'.$date.'</a>'. '<br/>'.
                    $time.'<br/>'.
                '<b>'. human_time_diff( $time_last_seen, current_time( 'timestamp' ) ) .' '. esc_html__('ago','user_activity_log_pro'). '</b>';
                return $return;
    }

    public function column_login_status($item) {   
        $user_id = $item->user_id;
        $login_status = 'logout';
        $user_metas = get_user_meta($user_id,'session_tokens',true);
        $total_logins = 0;
        $session_token = $item->session_token;
        $enc_session_token = ualpGetCurrentToken($session_token);
        if(is_array($user_metas)) {
            $total_logins = count($user_metas);
            if(array_key_exists($enc_session_token, $user_metas)) {
                $login_status = 'login';
            }
        }
        $all_login_status = ucfirst($login_status);
        $return = '<a title="'.$all_login_status.'" href="'.admin_url('admin.php?page=ualp_settings&loginstatus=').$login_status.'">'.$all_login_status.'</a>';
        return $return;
    }
    
    public function column_action($item) {
        $action = '';
        $user_id = $item->user_id;
        $login_status = 'logout';
        $user_metas = get_user_meta($user_id,'session_tokens',true);
        $total_logins = 0;
        $paged = 1;
        $session_token = $item->session_token;
        $enc_session_token = ualpGetCurrentToken($session_token);
        if(is_array($user_metas)) {
            $total_logins = count($user_metas);
            if(array_key_exists($enc_session_token, $user_metas)) {
                $login_status = 'login';
            }
        }
        global $externaldb;
        if($login_status == 'login' && $user_id != get_current_user_id()) {
           
            $action .= '<a title="'.esc_html__('Log out user','user_activity_log_pro').'"  class ="column-delete ualp-session-expire" data-t_session="'.$session_token.'" data-user-id="'.$user_id.'">'.esc_html__("Log out User from this session only","user_activity_log_pro").'</a><br/>';
        
            $action .= '<a title="'.esc_html__('Log out user','user_activity_log_pro').'"  class ="column-delete ualp-session-expire-all" data-t_session="'.$session_token.'" data-user-id="'.$user_id.'">'.esc_html__("Log out User from All Devices","user_activity_log_pro").'</a><br/>';

        } else if($login_status == 'login' && $user_id == get_current_user_id() && $session_token == wp_get_session_token() && $total_logins>1){
            $action .= '<a title="'.esc_html__('Log out From all other devices','user_activity_log_pro').'"  class ="column-delete ualp-session-expire-except" data-t_session="'.$session_token.'" data-user-id="'.$user_id.'">'.esc_html__("Log out From all other devices","user_activity_log_pro").'</a><br/>';

        }

        $total_history = $externaldb->get_var("select count(*) from ".UALP_TABLENAME." where t_session = '".$session_token."'");

        if($total_history > 0) {

            $action .= '<a target="_blank" href= "'.admin_url("admin.php?page=ual_pro&t_session=$session_token").'" title="'.esc_html__('View Log History','user_activity_log_pro').'"  class ="ualp-green" data-user-id="'.$user_id.'">'.esc_html__("View Log History","user_activity_log_pro").'</a><br/>';

        }
        $deleteTitle = esc_html__('Delete','user_activity_log_pro');
        if (!isset($_REQUEST['usershow'])) {
            $usershow = '';
        } else {
            $usershow = $_REQUEST['usershow'];
        }
        if (!isset($_REQUEST['showip'])){
            $showip = '';
        } else {
            $showip = $_REQUEST['showip'];
        }
        if (!isset($_REQUEST['showcountry'])){
            $showcountry = '';
        } else {
            $showcountry = $_REQUEST['showcountry'];
        }
        if (!isset($_REQUEST['showuser_agent'])){
            $showuser_agent = '';
        } else {
            $showuser_agent = $_REQUEST['showuser_agent'];
        }
        if (!isset($_REQUEST['s'])){
            $s = '';
        } else {
            $s = $_REQUEST['s'];
        }
        if (!isset($_REQUEST['loginstatus'])){
            $loginstatus = '';
        } else {
            $loginstatus = $_REQUEST['loginstatus'];
        }
        if (!isset($_REQUEST['timelogin'])){
            $timelogin = '';
        } else {
            $timelogin = $_REQUEST['timelogin'];
        }
        if (!isset($_REQUEST['timelogout'])){
            $timelogout = '';
        } else {
            $timelogout = $_REQUEST['timelogout'];
        }
        if (!isset($_REQUEST['user_role'])) {
            $user_role = '';
        } else {
           $user_role = $_REQUEST['user_role'];
        }
                                          
        $action .= '<a title="'.$deleteTitle.'" class="column-delete deleteLog" data-id="'.$item->uacltid.'" href="'.wp_nonce_url(admin_url("admin.php?page=ualp_settings&paged=$paged&action=delete&id=$item->uacltid&usershow=$usershow&showip=$showip&showcountry=$showcountry&showuser_agent=$showuser_agent&s=$s&loginstatus=$loginstatus&timelogin=$timelogin&timelogout=$timelogout&user_role=$user_role"), "delete-action$item->uacltid", "delete-nonce").'"><span class="dashicons dashicons-trash"></span></a>';
        return $action;
    }
   
    public function get_columns() {
        $columns = array(
            'cb' => '<input type="checkbox">',
            'user_id' => esc_html__('Author', 'user_activity_log_pro'),
        );
        if(ualpAllowIp()) {
            $columns['ip_address'] = esc_html__('IP Address', 'user_activity_log_pro');
        }
        if(ualpAllowCountry()) {
            $columns['country'] = esc_html__('Country', 'user_activity_log_pro');
        }
        if(ualpAllowUserAgent()) {
            $columns['user_agent'] = esc_html__('User Agent', 'user_activity_log_pro');
        }
        $columns['time_login'] = esc_html__('Logged in Time', 'user_activity_log_pro');
        $columns['time_logout'] = esc_html__('Logged out Time', 'user_activity_log_pro');
        $columns['time_last_seen'] = esc_html__('Last seen', 'user_activity_log_pro');
        $columns['login_status'] = esc_html__('Login Status', 'user_activity_log_pro');
        $columns['action'] = esc_html__('Action', 'user_activity_log_pro');
        
        return $columns;
    }

    public function get_sortable_columns() {
        return array(
            'ip_address' => array('ip_address', false),
            'country' => array('country', false),
            'user_agent' => array('user_agent', false),
            'user_id' => array('user_id', false),
            'time_login' => array('time_login', false),
            'time_logout' => array('time_logout', false),
            'time_last_seen' => array('time_last_seen', false),
            'login_status' => array('login_status', false),
         );
    }
    public function extra_tablenav($which) {
        global $wpdb, $externaldb;
        if ('top' !== $which) {

            return;
        }
        echo '<div class="alignleft actions1">';
        echo '<div class="filter-cover">';
            $users = $externaldb->get_results($externaldb->prepare(
                        'SELECT DISTINCT user_name FROM '.UALP_LOGIN_TABLENAME.'
				WHERE 1 = 1 AND user_name <> %s ORDER BY user_name','""'));
            if ($users) {
                if (!isset($_REQUEST['usershow']))
                    $_REQUEST['usershow'] = '';
                $output = array();
                foreach ($users as $all_user) {
                    if(isset($all_user->user_name) && $all_user->user_name != ''){
                        $output[] = sprintf('<option value="%s"%s>%s</option>', $all_user->user_name, selected($_REQUEST['usershow'], $all_user->user_name, false), $this->_get_action_label($all_user->user_name));
                    }
                }
                echo '<select class="chosen-filter" name="usershow" id="ualp-filter-usershow">';
                printf('<option value="">' .__('All Users', 'user_activity_log_pro'). '</option>');
                echo implode('', $output);
                echo '</select>';
            }
            $user_id = $externaldb->get_results(
                'SELECT DISTINCT user_id FROM '.UALP_LOGIN_TABLENAME.'
                        WHERE 1 = 1
                        ORDER BY user_id
                '
                );
            if ($user_id) {
                if (!isset($_REQUEST['user_role'])) {
                    $_REQUEST['user_role'] = '';
                }
                $output = array();
                foreach ($user_id as $alluserroleid) {
                    foreach($alluserroleid as $alluserrole){
                        $userroles = get_user_by('id', $alluserrole);
                        $user_roles = $userroles->roles;
                        if($user_roles == ''){
                            $user_roles = array();
                        }
                        foreach($user_roles as $user_id_role){
                             $output[] = sprintf('<option value="%s"%s>%s</option>', $user_id_role, selected($_REQUEST['user_role'], $user_id_role, false), $user_id_role);
                        }
                    }  
                }
           
            echo '<select class="chosen-filter" name="user_role" id="ualp-filter-user_role">';
            printf('<option value="">'.__('All Roles', 'user_activity_log_pro').'</option>');
            echo implode('', array_unique($output));
            echo '</select>';
        }
            $ips = $externaldb->get_results(
            'SELECT DISTINCT ip_address FROM '.UALP_LOGIN_TABLENAME.'
                    WHERE 1 = 1
                    ORDER BY ip_address
            '
            );
            if ($ips && ualpAllowIp()) {
                if (!isset($_REQUEST['showip']))
                    $_REQUEST['showip'] = '';
                $output = array();
                foreach ($ips as $ip) {
                    if(isset($ip->ip_address) && $ip->ip_address != ''){
                        $output[] = sprintf('<option value="%s"%s>%s</option>', $ip->ip_address, selected($_REQUEST['showip'], $ip->ip_address, false), $this->_get_action_label($ip->ip_address));
                    }
                }
                echo '<select class="chosen-filter" name="showip" id="ualp-filter-showip">';
                printf('<option value="">'.__('All IP', 'user_activity_log_pro').'</option>');
                echo implode('', $output);
                echo '</select>';
            }
            $countrys = $externaldb->get_results(
                'SELECT DISTINCT country FROM '.UALP_LOGIN_TABLENAME.'
                        WHERE 1 = 1
                        ORDER BY country'
            );
            if ($countrys && ualpAllowCountry()) {
                if (!isset($_REQUEST['showcountry']))
                    $_REQUEST['showcountry'] = '';
                $output = array();
                foreach ($countrys as $country){
                    if(isset($country->country) && $country->country != ''){
                        $output[] = sprintf('<option value="%s"%s>%s</option>', $country->country, selected($_REQUEST['showcountry'], $country->country, false), $this->_get_action_label($country->country));
                    }
                }
                echo '<select class="chosen-filter" name="showcountry" id="ualp-filter-showcountry">';
                printf('<option value="">'.__('All Countries', 'user_activity_log_pro').'</option>');
                echo implode('', $output);
                echo '</select>';
            }
            $user_agents = $externaldb->get_results(
                'SELECT DISTINCT user_agent FROM '.UALP_LOGIN_TABLENAME.'
                        WHERE 1 = 1
                        ORDER BY user_agent'
            );
            if ($user_agents && ualpAllowUserAgent()) {
                if (!isset($_REQUEST['showuser_agent']))
                    $_REQUEST['showuser_agent'] = '';
                $output = array();
                foreach ($user_agents as $user_agent){
                    if(isset($user_agent->user_agent) && $user_agent->user_agent != ''){
                        $output[] = sprintf('<option value="%s"%s>%s</option>', $user_agent->user_agent, selected($_REQUEST['showuser_agent'], $user_agent->user_agent, false), $this->_get_action_label($user_agent->user_agent));
                    }
                }
                echo '<select style="max-width:200px" class="chosen-filter" name="showuser_agent" id="ualp-filter-showuser_agent">';
                printf('<option value="">'.__('All User Agents', 'user_activity_log_pro').'</option>');
                echo implode('', $output);
                echo '</select>';
            }
            
            $allloginstatus = $externaldb->get_results(
                'SELECT DISTINCT login_status FROM '.UALP_LOGIN_TABLENAME.'
                        WHERE 1 = 1
                        ORDER BY login_status
                '
            );
            if ($allloginstatus) {
                if (!isset($_REQUEST['loginstatus'])) {
                    $_REQUEST['loginstatus'] = '';
                }
                $output = array();
                foreach ($allloginstatus as $loginstatus) {
                    if($loginstatus->login_status){
                        $output[] = sprintf('<option value="%s"%s>%s</option>', $loginstatus->login_status, selected($_REQUEST['loginstatus'], $loginstatus->login_status, false), ucfirst($loginstatus->login_status));
                    }
                }
                echo '<select class="chosen-filter" name="loginstatus" id="ualp-filter-loginstatus">';
                printf('<option value="">'.__('All Login Status', 'user_activity_log_pro').'</option>');
                echo implode('', $output);
                echo '</select>';
            }
            $alltimelogin = $externaldb->get_results(
                'SELECT DISTINCT time_login FROM '.UALP_LOGIN_TABLENAME.'
                        WHERE 1 = 1
                        ORDER BY time_login
                '
            );
            if ($alltimelogin) {
                if (!isset($_REQUEST['timelogin']))
                    $_REQUEST['timelogin'] = '';
                    $date_options = array(
                        '' => esc_html__('All Login Time', 'user_activity_log_pro'),
                        'today' => esc_html__('Today', 'user_activity_log_pro'),
                        'yesterday' => esc_html__('Yesterday', 'user_activity_log_pro'),
                        'week' => esc_html__('Week', 'user_activity_log_pro'),
                        'this-month' => esc_html__('This Month', 'user_activity_log_pro'),
                        'month' => esc_html__('Last 1 Month', 'user_activity_log_pro'),
                        '2-month' => esc_html__('Last 2 Month', 'user_activity_log_pro'),
                        '3-month' => esc_html__('Last 3 Month', 'user_activity_log_pro'),
                        '6-month' => esc_html__('Last 6 Month', 'user_activity_log_pro'),
                        'this-year' => esc_html__('This Year', 'user_activity_log_pro'),
                        'last-year' => esc_html__('Last Year', 'user_activity_log_pro'),
                        'custom' => esc_html__('Custom Date Range', 'user_activity_log_pro'),
                );
                echo '<select name="timelogin" class="chosen-filter" id="ualp-login-filter-date">';
                foreach ($date_options as $key => $value)
                    printf('<option value="%1$s"%2$s>%3$s</option>', $key, selected($_REQUEST['timelogin'], $key, false), $value);
                echo '</select>';
            }
            
            $alltimelogout = $externaldb->get_results(
                'SELECT DISTINCT time_logout FROM '.UALP_LOGIN_TABLENAME.'
                        WHERE 1 = 1
                        ORDER BY time_logout
                '
            );
            if ($alltimelogout) {
                if (!isset($_REQUEST['timelogout']))
                    $_REQUEST['timelogout'] = '';
                    $date_options = array(
                        '' => esc_html__('All Logout Time', 'user_activity_log_pro'),
                        'today' => esc_html__('Today', 'user_activity_log_pro'),
                        'yesterday' => esc_html__('Yesterday', 'user_activity_log_pro'),
                        'week' => esc_html__('Week', 'user_activity_log_pro'),
                        'this-month' => esc_html__('This Month', 'user_activity_log_pro'),
                        'month' => esc_html__('Last 1 Month', 'user_activity_log_pro'),
                        '2-month' => esc_html__('Last 2 Month', 'user_activity_log_pro'),
                        '3-month' => esc_html__('Last 3 Month', 'user_activity_log_pro'),
                        '6-month' => esc_html__('Last 6 Month', 'user_activity_log_pro'),
                        'this-year' => esc_html__('This Year', 'user_activity_log_pro'),
                        'last-year' => esc_html__('Last Year', 'user_activity_log_pro'),
                        'custom' => esc_html__('Custom Date Range', 'user_activity_log_pro'),
                );
                echo '<select name="timelogout" class="chosen-filter" id="ualp-logout-filter-date">';
                foreach ($date_options as $key => $value)
                    printf('<option value="%1$s"%2$s>%3$s</option>', $key, selected($_REQUEST['timelogout'], $key, false), $value);
                echo '</select>';
            }
           
        echo '</div>';
         // Parse all query vars into an array
         $query_vars = array();

         if ( isset( $_SERVER['QUERY_STRING'] ) ) {
             parse_str( urldecode( $_SERVER['QUERY_STRING'] ), $query_vars );
         }
 
         // Ignore certain query vars and query vars that are empty
         foreach ( $query_vars as $query_var => $value ) {
             if ( '' === $value || 'page' === $query_var || 'paged' === $query_var ) {
                 unset( $query_vars[ $query_var ] );
             }
         } ?>
       
        <div class="filter-btn-cover">
            <?php
            submit_button(__('Filter', 'user_activity_log_pro'), 'primary', false, false, array('uacltid' => 'login-query-submit'));
            if ( ! empty( $query_vars ) ) { ?>
                <a class="button ualp-button-green" href="<?php echo admin_url('admin.php?page=ualp_settings'); ?>">
                    <?php esc_html_e('Reset Filter', 'user_activity_log_pro'); ?>
                </a><?php
            }
            ?>
        </div>
        <?php 
            $loginstartDate = (isset($_REQUEST['login_start_date']) && $_REQUEST['login_start_date'] != '') ? $_REQUEST['login_start_date'] : '';
            $loginendDate = (isset($_REQUEST['login_end_date']) && $_REQUEST['login_end_date'] != '') ? $_REQUEST['login_end_date'] : '';
                echo '<div class="custom-login-date pull-left">'
                        . '<p>'
                            .__("Login start date","user_activity_log_pro"). ' : '
                            . '<input type="text" name="login_start_date" value="'.$loginstartDate.'" class="datepicker login-start-date"> '
                            .__("Login end date","user_activity_log_pro"). ' : '
                            . '<input type="text" name="login_end_date" value="'.$loginendDate.'" class="datepicker login-end-date">'
                        . '</p>'
                        . '<p class="login_custom_date_msg"></p>'
                    . '</div>';
        $logoutstartDate = (isset($_REQUEST['logout_start_date']) && $_REQUEST['logout_start_date'] != '') ? $_REQUEST['logout_start_date'] : '';
        $logoutendDate = (isset($_REQUEST['logout_end_date']) && $_REQUEST['logout_end_date'] != '') ? $_REQUEST['logout_end_date'] : '';
            echo '<div class="custom-logout-date pull-left">'
                    . '<p>'
                        .__("Logout start date","user_activity_log_pro"). ' : '
                        . '<input type="text" name="logout_start_date" value="'.$logoutstartDate.'" class="datepicker logout-start-date"> '
                        .__("Logout end date","user_activity_log_pro"). ' : '
                        . '<input type="text" name="logout_end_date" value="'.$logoutendDate.'" class="datepicker logout-end-date">'
                    . '</p>'
                    . '<p class="logout_custom_date_msg"></p>'
                 . '</div>';
        echo  '</div>';
    }

    public function display_tablenav($which) {
        global $wpdb, $externaldb;
        $itemList = $externaldb->get_var('SELECT count(uacltid) FROM '.UALP_LOGIN_TABLENAME);
       
        ?>
        <div class="tablenav <?php echo esc_attr($which); ?>">
            <?php
            if($itemList){
                if ('top' == $which) {
                    //wp_nonce_field('bulk-' . $this->_args['plural']);
                    ?><div class = "wp-filter">
                        <div class = "filter-items">
                            <?php
                            $this->extra_tablenav($which);
                            ?>
                            <div class="top-cover">
                                <div class="alignleft bulkactions">
                                    <?php
                                    if (!get_option('ualp_delete_log_pwd') || get_option('ualp_delete_log_pwd') == "") {
                                        $class = "setBulkDeletePassword";
                                    } else {
                                        $class = "deleteBulkLog";
                                    }
                                    ?>
                                    <label class="screen-reader-text" for="bulk-action-selector-top">
                                        <?php esc_html_e('Select bulk action', 'user_activity_log_pro'); ?>
                                    </label>
                                    <select class="<?php echo $class; ?>" id="bulk-action-selector-top" name="bulk_action_selector">
                                        <option value="0"><?php esc_html_e('Bulk Actions', 'user_activity_log_pro'); ?></option>
                                        <option value="delete"><?php esc_html_e('Delete Permanently', 'user_activity_log_pro'); ?></option>
                                    </select>
                                    <input type="submit" value="<?php esc_html_e('Apply', 'user_activity_log_pro'); ?>" name="bulk_action" class="button action" id="doaction">
                                    <?php
                                    $items_array = $this->items;
                                    if(is_array($items_array) && count($items_array) > 0) {
                                        if (!isset($_REQUEST['usershow']))
                                            $_REQUEST['usershow'] = '';
                                        if (!isset($_REQUEST['showip']))
                                            $_REQUEST['showip'] = '';
                                        if (!isset($_REQUEST['showcountry']))
                                            $_REQUEST['showcountry'] = '';
                                        if (!isset($_REQUEST['showuser_agent']))
                                            $_REQUEST['showuser_agent'] = '';
                                        if (!isset($_REQUEST['s']))
                                            $_REQUEST['s'] = '';
                                        if (!isset($_REQUEST['loginstatus']))
                                            $_REQUEST['loginstatus'] = '';
                                        if (!isset($_REQUEST['timelogin']))
                                            $_REQUEST['timelogin'] = '';
                                        if (!isset($_REQUEST['timelogout']))
                                            $_REQUEST['timelogout'] = '';
                                        if (!isset($_REQUEST['user_role']))
                                            $_REQUEST['user_role'] = '';
                                            
                                    ?>
                                        <a href="<?php echo wp_nonce_url(admin_url("admin.php?page=ualp_settings&export=user_login&username=".$_REQUEST['usershow']."&ip=".$_REQUEST['showip']."&country=".$_REQUEST['showcountry']."&user_agent=".$_REQUEST['showuser_agent']."&txtsearch=".$_REQUEST['s']."&loginstatus=".$_REQUEST['loginstatus']."&timelogin=".$_REQUEST['timelogin']."&timelogout=". $_REQUEST['timelogout']."&user_role=".$_REQUEST['user_role']), "export-action", "export-nonce"); ?>" class="button-primary action">
                                            <?php esc_html_e('Export Logged (CSV)', 'user_activity_log_pro'); ?>
                                        </a><?php
                                    } ?>
                                </div>
                            </div>
                            <?php
                            $this->search_box('Search', 'search');
                            ?>
                        </div>
                    </div><?php
                }
                $this->pagination($which);
            }
        ?>
        </div>
        <?php  
    }
    public function process_bulk_action()
    {
        global $wpdb;
        $table_name = UALP_LOGIN_TABLENAME;
            $ids = isset($_REQUEST['id']) ? $_REQUEST['id'] : array();
            if (is_array($ids)) $ids = implode(',', $ids);

            if (!empty($ids)) {
                $wpdb->query("DELETE FROM $table_name WHERE uacltid IN($ids)");
            }
    }
    public function prepare_items() {
        global $wpdb, $externaldb;
        $_SERVER['REQUEST_URI'] = remove_query_arg('_wp_http_referer', $_SERVER['REQUEST_URI']);
        $items_per_page = $this->get_items_per_page('ualp_user_logged_per_page');
        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = $this->get_column_info();
        $this->process_bulk_action();
        $where = ' WHERE 1=1';
        if (!isset($_REQUEST['order']) || !in_array($_REQUEST['order'], array('desc', 'asc'))) {
            $_REQUEST['order'] = 'desc';
        }
        if (!isset($_REQUEST['orderby']) || !in_array($_REQUEST['orderby'], array('user_agent', 'user_id', 'user_email', 'time_login', 'time_logout', 'ip_address', 'country','time_last_seen','login_status'))) {
            $_REQUEST['orderby'] = 'time_login';
        }
        if (isset($_REQUEST['datefilterlastseen']) && $_REQUEST['datefilterlastseen'] != '') {
            $datefilterlastseen = $_REQUEST['datefilterlastseen'];
            $datefilterlastseen = date('Y-m-d', $datefilterlastseen);
            $where .= ' AND time_last_seen LIKE "%%'.$datefilterlastseen.'%%"';
        }
        if (isset($_REQUEST['datefilterlogout']) && $_REQUEST['datefilterlogout'] != '') {
            $datefilterlogout = $_REQUEST['datefilterlogout'];
            $datefilterlogout = date('Y-m-d', $datefilterlogout);
            $where .= ' AND time_logout LIKE "%%'.$datefilterlogout.'%%"';
        }
        if (isset($_REQUEST['datefilterlogin']) && $_REQUEST['datefilterlogin'] != '') {
            $datefilterlogin = $_REQUEST['datefilterlogin'];
            $datefilterlogin = date('Y-m-d', $datefilterlogin);
            $where .= ' AND time_login LIKE "%%'.$datefilterlogin.'%%"';
        }
        
        if (isset($_REQUEST['loginstatus']) && $_REQUEST['loginstatus'] != '') {
            $loginstatus = $_REQUEST['loginstatus'];   
            $where .= ' AND login_status LIKE "%%'.$loginstatus.'%%"';
        }
        if (isset($_REQUEST['ip_address']) && $_REQUEST['ip_address'] != '') {
            $ip_address = $_REQUEST['ip_address'];
            $where .= ' AND ip_address LIKE "%%'.$ip_address.'%%"';
        }
        if (isset($_REQUEST['user_id']) && $_REQUEST['user_id'] != '') {
            $user_id = $_REQUEST['user_id'];
            $where .= ' AND user_id LIKE "%%'.$user_id.'%%"';
        }
        if (isset($_REQUEST['user_role']) && $_REQUEST['user_role'] != '') {
            $user_role = $_REQUEST['user_role'];
            $where .= ' AND user_role LIKE "%%'.$user_role.'%%"';
        }
        if (isset($_REQUEST['usershow']) && '' !== $_REQUEST['usershow']) {
            $where .= $externaldb->prepare(' AND `user_name` = %s', $_REQUEST['usershow']);
        }
        if (isset($_REQUEST['showip']) && '' !== $_REQUEST['showip']) {
            $where .= $externaldb->prepare(' AND `ip_address` = \'%s\'', $_REQUEST['showip']);
        }
        if (isset($_REQUEST['showcountry']) && '' !== $_REQUEST['showcountry']) {
            $where .= $externaldb->prepare(' AND `country` = \'%s\'', $_REQUEST['showcountry']);
        }
        if (isset($_REQUEST['showuser_agent']) && '' !== $_REQUEST['showuser_agent']) {
            $where .= $externaldb->prepare(' AND `user_agent` = \'%s\'', $_REQUEST['showuser_agent']);
        }
        if (isset($_REQUEST['s']) && $_REQUEST['s'] != '') {
            $where .= ' AND (user_name LIKE \'%%'.$externaldb->esc_like($_REQUEST['s']).'%%\')';
        }
        if (isset($_REQUEST['timelogin']) && in_array($_REQUEST['timelogin'], array('today', 'yesterday', 'week','this-month', 'month','2-month','3-month','6-month','this-year','last-year','custom'))) {
            $get_login_time = $_REQUEST['timelogin'];
            $current_time = current_time('timestamp');
            $start_time = mktime(0, 0, 0, date('m', $current_time), date('d', $current_time), date('Y', $current_time));
            $end_time = mktime(23, 59, 59, date('m', $current_time), date('d', $current_time), date('Y', $current_time));
            if ($get_login_time == 'today') {
                $start_time = $current_time;
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time);

            } elseif ($get_login_time === 'yesterday') {
                $start_time = strtotime('yesterday', $start_time);
                $end_time = $current_time;

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time);

            } elseif ($get_login_time === 'week') {
                $start_time = strtotime('-1 week', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time);

            } elseif ($get_login_time === 'this-month') {
                $start_time = date('Y-m-01');
                $start_time = strtotime($start_time);

                $end_time = date('Y-m-31');
                $end_time = strtotime($end_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time);

            } elseif ($get_login_time === 'month') {
                $start_time = strtotime('-1 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time);

            } elseif ($get_login_time === '2-month') {
                $start_time = strtotime('-2 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time);

            } elseif ($get_login_time === '3-month') {
                $start_time = strtotime('-3 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time);

            } elseif ($get_login_time === '6-month') {
                $start_time = strtotime('-6 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time);

            }elseif ($get_login_time === 'this-year') {
                $start_time = date('Y-01-01');
                $start_time = strtotime($start_time);

                $end_time = date('Y-12-31');
                $end_time = strtotime($end_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time);
            }elseif($get_login_time === 'last-year'){

                $start_time = date('Y-01-01');
                $start_time = strtotime($start_time);
                $start_time = strtotime('-1 year',$start_time);

                $end_time = date('Y-12-31');
                $end_time = strtotime($end_time);
                $end_time = strtotime('-1 year',$end_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_login > "%s" AND time_login < "%s"', $start_time, $end_time);
            } elseif ($get_login_time === 'custom') {
                $custom_start_date = $_REQUEST['login_start_date'];
                $custom_end_date = $_REQUEST['login_end_date'];
                if(isset($custom_start_date) && $custom_start_date != ''){
                    $start_time = strtotime($custom_start_date);
                    $start_time = strtotime('-1 day', $start_time);
                    $start_time = date('Y-m-d', $start_time);
                    $where .= $externaldb->prepare(' AND time_login > "%s"', $start_time);
                }
                if(isset($custom_end_date) && $custom_end_date != ''){
                    $end_time = strtotime($custom_end_date);
                    $end_time = strtotime('+1 day', $end_time);
                    $end_time = date('Y-m-d', $end_time);
                    $where .= $externaldb->prepare(' AND time_login < "%s"', $end_time);
                }
            }
        }
        if (isset($_REQUEST['timelogout']) && in_array($_REQUEST['timelogout'], array('today', 'yesterday', 'week','this-month', 'month','2-month','3-month','6-month','this-year','last-year','custom'))) {
            $get_logout_time = $_REQUEST['timelogout'];
            $current_time = current_time('timestamp');
            $start_time = mktime(0, 0, 0, date('m', $current_time), date('d', $current_time), date('Y', $current_time));
            $end_time = mktime(23, 59, 59, date('m', $current_time), date('d', $current_time), date('Y', $current_time));
            if ($get_logout_time == 'today') {
                $start_time = $current_time;
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time);

            } elseif ($get_logout_time === 'yesterday') {
                $start_time = strtotime('yesterday', $start_time);
                $end_time = $current_time;

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time);

            } elseif ($get_logout_time === 'week') {
                $start_time = strtotime('-1 week', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time);

            } elseif ($get_logout_time === 'this-month') {
                $start_time = date('Y-m-01');
                $start_time = strtotime($start_time);

                $end_time = date('Y-m-31');
                $end_time = strtotime($end_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time);

            } elseif ($get_logout_time === 'month') {
                $start_time = strtotime('-1 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time);

            } elseif ($get_logout_time === '2-month') {
                $start_time = strtotime('-2 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time);

            } elseif ($get_logout_time === '3-month') {
                $start_time = strtotime('-3 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time);

            } elseif ($get_logout_time === '6-month') {
                $start_time = strtotime('-6 month', $start_time);
                $end_time = strtotime('+1 day', $current_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time);

            }elseif ($get_logout_time === 'this-year') {
                $start_time = date('Y-01-01');
                $start_time = strtotime($start_time);

                $end_time = date('Y-12-31');
                $end_time = strtotime($end_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time);
            }elseif($get_logout_time === 'last-year'){

                $start_time = date('Y-01-01');
                $start_time = strtotime($start_time);
                $start_time = strtotime('-1 year',$start_time);

                $end_time = date('Y-12-31');
                $end_time = strtotime($end_time);
                $end_time = strtotime('-1 year',$end_time);

                $start_time = date('Y-m-d', $start_time);
                $end_time = date('Y-m-d', $end_time);
                $where .= $externaldb->prepare(' AND time_logout > "%s" AND time_logout < "%s"', $start_time, $end_time);
            } elseif ($get_logout_time === 'custom') {
                $custom_start_date = $_REQUEST['logout_start_date'];
                $custom_end_date = $_REQUEST['logout_end_date'];
                if(isset($custom_start_date) && $custom_start_date != ''){
                    $start_time = strtotime($custom_start_date);
                    $start_time = strtotime('-1 day', $start_time);
                    $start_time = date('Y-m-d', $start_time);
                    $where .= $externaldb->prepare(' AND time_logout > "%s"', $start_time);
                }
                if(isset($custom_end_date) && $custom_end_date != ''){
                    $end_time = strtotime($custom_end_date);
                    $end_time = strtotime('+1 day', $end_time);
                    $end_time = date('Y-m-d', $end_time);
                    $where .= $externaldb->prepare(' AND time_logout < "%s"', $end_time);
                }
            }
        }
        $offset = ( $this->get_pagenum() - 1 ) * $items_per_page;
        
        $total_items = $externaldb->get_var(
            'SELECT COUNT(`uacltid`) FROM ' . UALP_LOGIN_TABLENAME . $where
        );
        $this->items = $externaldb->get_results($externaldb->prepare(
            'SELECT * FROM '.UALP_LOGIN_TABLENAME . $where . ' order by '.$_REQUEST['orderby'].' '.$_REQUEST['order'].' LIMIT %d, %d', $offset, $items_per_page
        ));
        $this->set_pagination_args(array(
            'total_items' => $total_items,
            'per_page' => $items_per_page,
            'total_pages' => ceil($total_items / $items_per_page)
        ));
    }
    public function no_items() {
        esc_html_e( 'No Logged In User Found.','user_activity_log_pro' );
    }
    public function search_box($text, $input_id) {
        $search_data = isset($_REQUEST['s']) ? sanitize_text_field($_REQUEST['s']) : '';
        $input_id = $input_id . '-search-input';
        ?>
        <p class="search-box">
            <label class="screen-reader-text" for="<?php echo $input_id ?>"><?php echo $text; ?>:</label>
            <input type="search" id="<?php echo $input_id ?>" name="s" placeholder="<?php esc_html_e('User', 'user_activity_log_pro'); ?>" value="<?php echo esc_attr($search_data); ?>" />
            <?php submit_button($text, 'button', false, false, array('uacltid' => 'search-submit')); ?>
        </p>
        <?php
    }
}
