<?php
if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

/*
 * contain all functions for detail log entry
 */

/*
 * add log in detail
 *
 * @param int $uactid log id
 * @param array $update_info Update Info
 */
if(!function_exists('ualpAddActivityLogDetail')) {
    function ualpAddActivityLogDetail($uactid,$update_info) {
        global $wpdb, $externaldb;
        ualpCreateDetailTable();
        ualpCreateDetailExternalTable();
        if(is_array($update_info) && !empty($update_info)) {
            foreach($update_info as $update_info_key => $update_info_value) {
                if(!is_serialized( $update_info_value )) {
                    $update_info_value = maybe_serialize($update_info_value);
                }
                $externaldb->insert(
                    UALP_DETAIL_TABLENAME,
                    array(
                        'uactid' => $uactid,
                        'uactd_key' => $update_info_key,
                        'uactd_value' => $update_info_value
                    )
                );
            }
        }
    }
}

/*
 * for user update
 *
 * @param int $uactid
 * @param array $old_user_data
 * @param array $new_user_data
 * @param string $hook
 */
if(!function_exists('ualpAddActivityLogDetailUserUpdate')) {
    function ualpAddActivityLogDetailUserUpdate($uactid, $old_user_data, $new_user_data, $hook) {
        if($hook == 'insert_user_meta') {
            $user_primary_data = ualpGetUserPrimaryData();
            $user_meta_data = ualpGetUserMetaData();
            $user_all_data = array_merge($user_primary_data,$user_meta_data);
            $user_data_diff = array();
            foreach ($user_all_data as $user_primary_value) {
                $new_user_meta_content = NULL;
                $old_user_meta_content = NULL;
                if(is_array($old_user_data) && !empty($old_user_data)) {
                    if(isset($old_user_data[$user_primary_value])) {
                        $old_user_meta_content = $old_user_data[$user_primary_value];
                    }
                }
                if(is_array($new_user_data) && !empty($new_user_data)) {
                    if(isset($new_user_data[$user_primary_value])) {
                        $new_user_meta_content = $new_user_data[$user_primary_value];
                    }
                }
                if ( sanitize_text_field($old_user_meta_content) != $new_user_meta_content ) {
                    $user_data_diff[$user_primary_value] = array(
                        "old" => sanitize_text_field($old_user_meta_content),
                        "new" => $new_user_meta_content
                    );
                }
            }
            if(is_array($user_data_diff) && !empty($user_data_diff)) {
                foreach ( $user_data_diff as $user_data_diff_key => $user_data_diff_value ) {
                    $user_detail_ary["ualp_user_old_{$user_data_diff_key}"] = $user_data_diff_value["old"];
                    $user_detail_ary["ualp_user_new_{$user_data_diff_key}"] = $user_data_diff_value["new"];
                }
                $user_detail_ary = apply_filters('ualp_data_diff_array',$user_detail_ary);
                ualpAddActivityLogDetail($uactid,$user_detail_ary);
            }

        }
    }
}

/*
 * for post update
 *
 * @param int $uactid
 * @param array $old_post_data
 * @param array $new_post_data
 * @param string $post_type
 */
if(!function_exists('ualpAddActivityLogDetailPostUpdate')) {
    function ualpAddActivityLogDetailPostUpdate($uactid,$old_post_data,$new_post_data,$post_type) {
        $post_full_key_array = ualpGetPrimaryPostData($post_type);
        $post_full_meta_key_array = ualpGetPostMetaData($post_type);
        $post_data_diff = array();
        $post_detail_ary = array();
        $old_post_content = '';

        foreach($post_full_key_array as $post_full_key_single) {
            $new_post_meta_content = NULL;
            $old_post_meta_content = NULL;
            if(is_array($old_post_data) && !empty($old_post_data)) {
                $old_post_content = $old_post_data['post_data']->$post_full_key_single;
            }
            $new_post_content = isset($new_post_data['post_data']->$post_full_key_single) ? $new_post_data['post_data']->$post_full_key_single : null;
            if(!isset($new_post_data)) {
                continue;
            }
            if ( $old_post_content != $new_post_content ) {
                $post_data_diff[$post_full_key_single] = array(
                    "old" => $old_post_content,
                    "new" => $new_post_content
                );
            }
        }
        foreach($post_full_meta_key_array as $post_full_meta_key_single) {
            $new_post_meta_content = NULL;
            $old_post_meta_content = NULL;
            if(!isset($new_post_data)) {
                continue;
            }
            if(is_array($old_post_data) && !empty($old_post_data)) {
                // for support of acf
                if($post_full_meta_key_single == 'field_') {
                    foreach($old_post_data['post_meta'] as $old_field_key=>$old_field_meta) {
                        if (strpos($old_field_key, 'field_') !== false) {
                            $old_post_meta_content = $old_post_data['post_meta'][$old_field_key][0];
                            $new_post_meta_content = $new_post_data['post_meta'][$old_field_key][0];
                            if ( $old_post_meta_content !== $new_post_meta_content ) {
                                $post_data_diff[$old_field_key] = array(
                                    "old" => $old_post_meta_content,
                                    "new" => $new_post_meta_content
                                );
                            }
                        }
                    }
                }
                else if($post_full_meta_key_single == 'rule') {
                    if(isset($old_post_data['post_meta'][$post_full_meta_key_single]) && is_array($old_post_data['post_meta'][$post_full_meta_key_single])) {
                        foreach ($old_post_data['post_meta'][$post_full_meta_key_single] as $s_rule) {
                            if($s_rule != 0){
                                $old_post_meta_content[] = $s_rule;
                            }
                        }
                    }
                }
                else {
                    if(isset($old_post_data['post_meta'][$post_full_meta_key_single][0])) {
                        $old_post_meta_content = $old_post_data['post_meta'][$post_full_meta_key_single][0];
                    }
                }
            }

            if($post_full_meta_key_single == 'rule') {
                if(isset($new_post_data['post_meta'][$post_full_meta_key_single]) && is_array($new_post_data['post_meta'][$post_full_meta_key_single]) && !empty($new_post_data['post_meta'][$post_full_meta_key_single])) {
                    foreach ($new_post_data['post_meta'][$post_full_meta_key_single] as $s_rule) {
                        $new_post_meta_content[] = $s_rule;
                    }
                }
            }
            else if($post_full_meta_key_single != 'field_') {
                $new_post_meta_content = isset($new_post_data['post_meta'][$post_full_meta_key_single][0]) ? $new_post_data['post_meta'][$post_full_meta_key_single][0] : null;
            }
            if ( trim($old_post_meta_content) !== trim($new_post_meta_content) ) {
                if($post_full_meta_key_single != 'field_') {
                    $post_data_diff[$post_full_meta_key_single] = array(
                        "old" => $old_post_meta_content,
                        "new" => $new_post_meta_content
                    );
                }
            }
        }

        if(isset($new_post_data['post_tax']) || isset($old_post_data['post_tax'])) {
            $new_post_meta_content = NULL;
            $old_post_meta_content = NULL;
            $old_post_tax = $old_post_data['post_tax'];
            $new_post_tax = $new_post_data['post_tax'];
            if(isset($new_post_tax) && !empty($new_post_tax)) {
                foreach($new_post_tax as $new_post_tax_key=>$new_post_tax_val) {
                    $array_dif = 'no';
                    if(isset($old_post_tax[$new_post_tax_key]) && !isset($new_post_tax[$new_post_tax_key])) {
                        $new_post_tax[$new_post_tax_key] = '';
                        $array_dif = 'yes';
                    }
                    if(!isset($old_post_tax[$new_post_tax_key]) && isset($new_post_tax[$new_post_tax_key])) {
                        $old_post_tax[$new_post_tax_key] = '';
                        $array_dif = 'yes';
                    }
                    if(isset($old_post_tax[$new_post_tax_key]) && isset($new_post_tax[$new_post_tax_key])) {
                        if($old_post_tax[$new_post_tax_key] !== $new_post_tax[$new_post_tax_key]) {
                            $array_dif = 'yes';
                        }
                    }
                    if($array_dif == 'yes') {
                        $post_data_diff[$new_post_tax_key] = array(
                            "tax_old" => $old_post_tax[$new_post_tax_key],
                            "tax_new" => $new_post_tax[$new_post_tax_key]
                        );
                    }
                }
            }
            if(isset($old_post_tax) && !empty($old_post_tax)) {
                foreach($old_post_tax as $old_post_tax_key=>$old_post_tax_val) {
                    $array_dif = 'no';
                    if(isset($old_post_tax[$old_post_tax_key]) && !isset($new_post_tax[$old_post_tax_key])) {
                        $new_post_tax[$old_post_tax_key] = '';
                        $array_dif = 'yes';
                    }
                    if(!isset($old_post_tax[$old_post_tax_key]) && isset($new_post_tax[$old_post_tax_key])) {
                        $old_post_tax[$old_post_tax_key] = '';
                        $array_dif = 'yes';
                    }
                    if(isset($old_post_tax[$old_post_tax_key]) && isset($new_post_tax[$old_post_tax_key])) {
                        if($old_post_tax[$old_post_tax_key] !== $new_post_tax[$old_post_tax_key]) {
                            $array_dif = 'yes';
                        }
                    }
                    if($array_dif == 'yes') {
                        if(!array_key_exists($old_post_tax_key,$post_data_diff)) {
                            $post_data_diff[$old_post_tax_key] = array(
                                "tax_old" => $old_post_tax[$old_post_tax_key],
                                "tax_new" => $new_post_tax[$old_post_tax_key]
                            );
                        }
                    }
                }
            }
        }
        $post_data_diff = apply_filters('ualp_post_data_diff',$post_data_diff,$post_type);
        //post deta
        if(is_array($post_data_diff) && !empty($post_data_diff)) {
            foreach ( $post_data_diff as $post_data_diff_key => $post_data_diff_value ) {
                if(array_key_exists("tax_old", $post_data_diff_value)) {
                    $post_detail_ary["ualp_post_tax_old_{$post_data_diff_key}"] = $post_data_diff_value["tax_old"];
                    $post_detail_ary["ualp_post_tax_new_{$post_data_diff_key}"] = $post_data_diff_value["tax_new"];
                }
                else {
                    $post_detail_ary["ualp_post_old_{$post_data_diff_key}"] = $post_data_diff_value["old"];
                    $post_detail_ary["ualp_post_new_{$post_data_diff_key}"] = $post_data_diff_value["new"];
                }
            }
        }
        $post_detail_ary = apply_filters('ualp_data_diff_array',$post_detail_ary);
        ualpAddActivityLogDetail($uactid,$post_detail_ary);
    }
}

/*
 * for switch theme
 *
 * @param int $uactid
 * @param array $old_theme
 * @param array $new_theme
 */
if(!function_exists('ualpAddActivityLogDetailSwitchTheme')) {
    function ualpAddActivityLogDetailSwitchTheme($uactid,$old_theme,$new_theme) {
        $post_detail_ary['ualp_old_theme_name'] = $old_theme['name'];
        $post_detail_ary['ualp_old_theme_version'] = $old_theme['version'];
        $post_detail_ary['ualp_new_theme_name'] = $new_theme['name'];
        $post_detail_ary['ualp_new_theme_version'] = $new_theme['version'];
        $post_detail_ary = apply_filters('ualp_data_diff_array',$post_detail_ary,'');
        ualpAddActivityLogDetail($uactid,$post_detail_ary);
    }
}

/*
 * for upgrade theme
 *
 * @param int $uactid
 * @param array $new_theme
 */
if(!function_exists('ualpAddActivityLogDetailUpgradeTheme')) {
    function ualpAddActivityLogDetailUpgradeTheme($uactid,$new_theme) {
        $post_detail_ary['ualp_theme_name'] = $new_theme['name'];
        $post_detail_ary['ualp_theme_version'] = $new_theme['version'];
        $post_detail_ary = apply_filters('ualp_data_diff_array',$post_detail_ary,'');
        ualpAddActivityLogDetail($uactid,$post_detail_ary);
    }
}

/*
 * For customize save
 *
 * @param int $uactid
 * @param object $customizer
 */
if(!function_exists('ualpHookCustomizeSaveDetail')) {
    function ualpHookCustomizeSaveDetail($uactid,$customizer) {
        $customizer->prepare_controls();
        $settings = $customizer->settings();
        $sections = $customizer->sections();
        $controls = $customizer->controls();
        $customized = json_decode(wp_unslash($_REQUEST["customized"]));
        $customize_detail_ary = array();
        foreach ($customized as $setting_id => $posted_values) {
            foreach ($settings as $one_setting) {
                if ($one_setting->id == $setting_id) {
                    $old_value = $one_setting->value();
                    $new_value = $one_setting->post_value();
                    if ($old_value != $new_value) {
                        $customize_detail_ary = array(
                            $one_setting->id."_setting_id" => $one_setting->id,
                            $one_setting->id."_setting_old_value" => $old_value,
                            $one_setting->id."_setting_new_value" => $new_value,
                        );
                        foreach ($controls as $one_control) {
                            foreach ($one_control->settings as $section_control_setting) {
                                if ($section_control_setting->id == $setting_id) {
                                    $customize_detail_ary[$one_control->id."control_id"] = $one_control->id;
                                    $customize_detail_ary[$one_setting->id."control_label"] = $one_control->label;
                                    $customize_detail_ary[$one_setting->id."control_type"] = $one_control->type;
                                }
                            }
                        }
                        $customize_detail_ary = apply_filters('ualp_data_diff_array',$customize_detail_ary,'');
                        ualpAddActivityLogDetail($uactid,$customize_detail_ary);
                    }
                }
            }
        }
    }
}

/*
 * for widget update
 *
 * @param int $uactid
 * @param object $instance
 * @param object $new_instance
 * @param object $old_instance
 * @param object $widget_instance
 */
if(!function_exists('ualpHookWidgetUpdateDetail')) {
    function ualpHookWidgetUpdateDetail($uactid,$instance, $new_instance, $old_instance, $widget_instance){
        $widget_id_base = $widget_instance->id_base;
        $widget_detail_ary = array();
        $widget_detail_ary["ualp_widget_id_base"] = $widget_id_base;
        $widget = false;
        $widget_factory = isset($GLOBALS["wp_widget_factory"]) ? $GLOBALS["wp_widget_factory"] : false;
        if ($widget_factory) {
            foreach ($widget_factory->widgets as $one_widget) {
                if ($one_widget->id_base == $widget_id_base) {
                    $widget = $one_widget;
                }
            }
        }
        if ($widget) {
            $widget_detail_ary["ualp_widget_name_translated"] = $widget->name;
        }
        $sidebar_id = $_POST["sidebar"];
        $widget_detail_ary["ualp_sidebar_id"] = $sidebar_id;
        $sidebar = false;
        $sidebars = isset($GLOBALS['wp_registered_sidebars']) ? $GLOBALS['wp_registered_sidebars'] : false;
        if ($sidebars) {
            if (isset($sidebars[$sidebar_id])) {
                $sidebar = $sidebars[$sidebar_id];
            }
        }
        if ($sidebar) {
            $widget_detail_ary["ualp_sidebar_name_translated"] = $sidebar["name"];
        }
        $widget_detail_ary["ualp_old_instance"] = json_encode($old_instance);
        $widget_detail_ary["ualp_new_instance"] = json_encode($new_instance);
        $widget_detail_ary = apply_filters('ualp_data_diff_array',$widget_detail_ary,'');
        ualpAddActivityLogDetail($uactid,$widget_detail_ary);
    }
}

/*
 * Get the old and new data of setings fields
 *
 * @param int $uactid
 * @param string $oldvalue
 * @param string $_newvalue
 * @param string $obj_type
 * @param string $option
 */
if(!function_exists('ualpAddWordPressSettingsLogDetail')) {
    function ualpAddWordPressSettingsLogDetail($uactid,$oldvalue,$_newvalue,$obj_type,$option = '') {
        $options_detail_ary = array();
        if(is_array($oldvalue) && is_array($_newvalue)) {
            foreach($oldvalue as $old_key=>$old_val) {
                if($option == 'edd_tax_rates') {
                    $old_key = 'edd_tax_'.$old_key;
                }
                $post_data_diff[$old_key]['old'] = $old_val;
            }
            foreach($_newvalue as $new_key=>$new_val) {
                if($option == 'edd_tax_rates') {
                    $new_key = 'edd_tax_'.$new_key;
                }
                $post_data_diff[$new_key]['new'] = $new_val;
            }
            if(is_array($post_data_diff) && !empty($post_data_diff)) {
                foreach ($post_data_diff as $diff_key=>$diff_val) {
                    $old_data = isset($diff_val['old']) ? $diff_val['old'] : '';
                    $new_data = isset($diff_val['new']) ? $diff_val['new'] : '';
                    if($old_data != $new_data){

                        $comment_moderation = array('default_pingback_flag','comments_notify','moderation_notify',
                        'comment_moderation','require_name_email','show_avatars','close_comments_for_old_posts',
                        'thread_comments','comment_registration','comment_whitelist','page_comments');

                        if(in_array($diff_key, $comment_moderation)){
                            if($old_data === '0'){
                                $old_data = 'False';
                            }
                            if($new_data === '0'){
                                $new_data = 'False';
                            }
                            if($old_data === '1'){
                                $old_data = 'True';
                            }
                            if($new_data === '1'){
                                $new_data = 'True';
                            }
                        }
                        if('default_category' === $diff_key || 'default_email_category' === $diff_key ){
                            $old_term_data = get_term_by('id', $old_data, 'category');
                            $new_term_data = get_term_by('id', $new_data, 'category');
                            $old_data = $old_term_data->name;
                            $new_data = $new_term_data->name;
                        }
                        if('default_post_format' === $diff_key){
                            if($old_data === '0'){
                                $old_data = 'Standard';
                            }
                            if($new_data === '0'){
                                $new_data = 'Standard';
                            }
                        }
                        if('page_on_front' === $diff_key || 'page_for_posts' === $diff_key){
                            $old_data = get_the_title($old_data);
                            $new_data = get_the_title($new_data);
                        }
                        $options_detail_ary["ualp_option_old_{$diff_key}"] = $old_data;
                        $options_detail_ary["ualp_option_new_{$diff_key}"] = $new_data;
                    }
                }
            }
        }
        else {
            if($oldvalue != $_newvalue){
                $options_detail_ary["ualp_option_old_{$option}"] = $oldvalue;
                $options_detail_ary["ualp_option_new_{$option}"] = $_newvalue;
            }
        }
        $post_data_diff = apply_filters('ualp_data_diff_array',$options_detail_ary,$obj_type);
        ualpAddActivityLogDetail($uactid,$post_data_diff);
    }
}

if(!function_exists('ualpAddReservationSettingsLogDetail')){
    function ualpAddReservationSettingsLogDetail($uactid,$old_settings,$new_settings){
        $settings = array();
        foreach($old_settings as $key => $val){
            $settings["ualp_option_old_{$key}"] = $val;
        }
        foreach($new_settings as $key => $val){
            $settings["ualp_option_new_{$key}"] = $val;
        }
        ualpAddActivityLogDetail($uactid,$settings);
    }
}
